@@ -7,7 +7,7 @@ h.responseText:null}catch(k){}try{g.binary=h.response}catch(m){}try{f=h.statusTe
 b.handler;b.handler=function(b,f){b.target=f;a.apply(this,arguments)}}}}a.map(e.split(" "),function(a){g(a)});g("focusin","focus"+d);g("focusout","blur"+d)})(jQuery,document,"click mousemove mouseup touchmove touchend","outjsmol");"undefined"==typeof jQuery&&alert("Note -- JSmoljQuery is required for JSmol, but it's not defined.");self.Jmol||(Jmol={});
 Jmol._version||(Jmol=function(a){var h=function(a){return{rear:a++,header:a++,main:a++,image:a++,front:a++,fileOpener:a++,coverImage:a++,dialog:a++,menu:a+9E4,console:a+91E3,consoleImage:a+91001,monitorZIndex:a+99999}},h={_version:"$Date: 2022-06-24 05:54:49 -0500 (Fri, 24 Jun 2022) $",_alertNoBinary:!0,_allowedJmolSize:[25,2048,300],_allowKeyboardFocus:!0,_appletCssClass:"",_appletCssText:"",_fileCache:null,_jarFile:null,_j2sPath:null,_use:null,_j2sLoadMonitorOpacity:90,_applets:{},_asynchronous:!0,
 _ajaxQueue:[],_persistentMenu:!1,_getZOrders:h,_z:h(Jmol.z||9E3),_debugCode:!0,_debugCore:!1,db:{_databasePrefixes:"$=:",_fileLoadScript:";if (_loadScript = '' && defaultLoadScript == '' && _filetype == 'Pdb') { select protein or nucleic;cartoons Only;color structure; select * };",_nciLoadScript:";n = ({molecule=1}.length < {molecule=2}.length ? 2 : 1); select molecule=n;display selected;center selected;",_pubChemLoadScript:"",_DirectDatabaseCalls:{"cactus.nci.nih.gov":null,".x3dna.org":null,"rruff.geo.arizona.edu":null,
-".rcsb.org":null,"ftp.wwpdb.org":null,"pdbe.org":null,"materialsproject.org":null,".ebi.ac.uk":null,"pubchem.ncbi.nlm.nih.gov":null,"www.nmrdb.org/tools/jmol/predict.php":null,$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",$$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf","=":"https://files.rcsb.org/download/%FILE.pdb","*":"https://www.ebi.ac.uk/pdbe/entry-files/download/%FILE.cif","==":"https://files.rcsb.org/ligands/download/%FILE.cif",
+".rcsb.org":null,"chemapps.stolaf.edu/jmol/jsmol/":null,"ftp.wwpdb.org":null,"pdbe.org":null,"materialsproject.org":null,".ebi.ac.uk":null,"pubchem.ncbi.nlm.nih.gov":null,"www.nmrdb.org/tools/jmol/predict.php":null,$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf&get3d=True",$$:"https://cactus.nci.nih.gov/chemical/structure/%FILENCI/file?format=sdf","=":"https://files.rcsb.org/download/%FILE.pdb","*":"https://www.ebi.ac.uk/pdbe/entry-files/download/%FILE.cif","==":"https://files.rcsb.org/ligands/download/%FILE.cif",
 ":":"https://pubchem.ncbi.nlm.nih.gov/rest/pug/compound/%FILE/SDF?record_type=3d"},_restQueryUrl:"http://www.rcsb.org/pdb/rest/search",_restQueryXml:"<orgPdbQuery><queryType>org.pdb.query.simple.AdvancedKeywordQuery</queryType><description>Text Search</description><keywords>QUERY</keywords></orgPdbQuery>",_restReportUrl:"http://www.pdb.org/pdb/rest/customReport?pdbids=IDLIST&customReportColumns=structureId,structureTitle"},_debugAlert:!1,_document:a,_isXHTML:!1,_lastAppletID:null,_mousePageX:null,
 _mouseOwner:null,_serverUrl:"https://your.server.here/jsmol.php",_syncId:(""+Math.random()).substring(3),_touching:!1,_XhtmlElement:null,_XhtmlAppendChild:!1};a=a.location.href.toLowerCase();h._debugCore=0<=a.indexOf("j2sdebugcore");h._httpProto=0==a.indexOf("https")?"https://":"http://";h._isFile=0==a.indexOf("file:");h._isFile&&$.ajaxSetup({mimeType:"text/plain"});h._ajaxTestSite=h._httpProto+"google.com";a=h._isFile||0==a.indexOf("http://localhost")||0==a.indexOf("http://127.");h._tracker=!a&&
 "https://chemapps.stolaf.edu/jmol/JmolTracker.php?id=UA-45940799-1";h._isChrome=0<=navigator.userAgent.toLowerCase().indexOf("chrome");h._isSafari=!h._isChrome&&0<=navigator.userAgent.toLowerCase().indexOf("safari");h._isMsie=void 0!==window.ActiveXObject;h._isEdge=0<=navigator.userAgent.indexOf("Edge/");h._useDataURI=!h._isMsie&&!h._isEdge;window.requestAnimationFrame||(window.requestAnimationFrame=window.setTimeout);for(var e in Jmol)h[e]=Jmol[e];return h}(document,Jmol));
@@ -35,7 +35,7 @@ a),b.type="POST",b.contentType="application/x-www-form-urlencoded")};a._contactS
 a._getElement(b,"select");if(e&&e.options)for(var d=0;d<e.options.length;d++)e[d].value==c&&(e[d].selected=!0)}a.$val(a.$(b,"query"),f)}};a._search=function(b,f,c){1<arguments.length||(f=null);a._setQueryTerm(b,f);f||(f=a.$val(a.$(b,"query")));0==f.indexOf("!")?b._script(f.substring(1)):(f&&(f=f.replace(/\"/g,"")),b._showInfo(!1),a._searchMol(b,f,c,!0))};a._searchMol=function(b,f,c,e){var d;a._isDatabaseCall(f)?(d=f.substring(0,1),f=f.substring(1)):d=b._hasOptions?a.$val(a.$(b,"select")):"$";"="==
 d&&3==f.length&&(f="="+f);var g=d+f;if(f&&!(0>g.indexOf("?")&&g==b._thisJmolModel)){b._thisJmolModel=g;var h;e&&null!=b._viewSet&&null!=(h=a.View.__findView(b._viewSet,{chemID:g}))?a.View.__setView(h,b,!1):("$"==d||":"==d?b._jmolFileType="MOL":"="==d&&(b._jmolFileType="PDB"),b._searchDatabase(f,d,c))}};a._searchDatabase=function(b,f,c,e){b._showInfo(!1);return 0<=f.indexOf("?")?(a._getInfoFromDatabase(b,c,f.split("?")[0]),!0):a.db._DirectDatabaseCalls[c]?(b._loadFile(c+f,e),!0):!1};a._syncBinaryOK=
 "?";a._canSyncBinary=function(b){if(a._isAsync)return!0;if(self.VBArray)return a._syncBinaryOK=!1;if("?"!=a._syncBinaryOK)return a._syncBinaryOK;a._syncBinaryOK=!0;try{var f=new window.XMLHttpRequest;f.open("text",a._ajaxTestSite,!1);f.hasOwnProperty("responseType")?f.responseType="arraybuffer":f.overrideMimeType&&f.overrideMimeType("text/plain; charset=x-user-defined")}catch(c){return System.out.println("JSmolCore.js: synchronous binary file transfer is requested but not available"),a._alertNoBinary&&
-!b&&alert("JSmolCore.js: synchronous binary file transfer is requested but not available"),a._syncBinaryOK=!1}return!0};a._binaryTypes="mmtf .gz .bz2 .jpg .gif .png .zip .jmol .bin .smol .spartan .pmb .mrc .map .ccp4 .dn6 .delphi .omap .pse .dcd .lut .uk/pdbe/densities/".split(" ");a.isBinaryUrl=function(b){for(var f=a._binaryTypes.length;0<=--f;)if(0<=b.indexOf(a._binaryTypes[f]))return!0;return!1};a._getFileData=function(b,f,c){var e=a.isBinaryUrl(b),d=0<=b.indexOf(".gz")&&0<=b.indexOf("rcsb.org");
+!b&&alert("JSmolCore.js: synchronous binary file transfer is requested but not available"),a._syncBinaryOK=!1}return!0};a._binaryTypes="mmtf .bcif .gz .bz2 .jpg .gif .png .zip .jmol .bin .smol .spartan .pmb .mrc .map .ccp4 .dn6 .delphi .omap .pse .dcd .lut .uk/pdbe/densities/".split(" ");a.isBinaryUrl=function(b){for(var f=a._binaryTypes.length;0<=--f;)if(0<=b.indexOf(a._binaryTypes[f]))return!0;return!1};a._getFileData=function(b,f,c){var e=a.isBinaryUrl(b),d=0<=b.indexOf(".gz")&&0<=b.indexOf("rcsb.org");
 d&&(b=b.replace(/\.gz/,""),e=!1);var d=e&&!f&&!a._canSyncBinary(d),g=0<=b.indexOf("?POST?");0==b.indexOf("file:/")&&0!=b.indexOf("file:///")&&(b="file://"+b.substring(5));var h=0>b.indexOf("://")||0==b.indexOf(document.location.protocol)&&0<=b.indexOf(document.location.host),l="https://"==a._httpProto&&0==b.indexOf("http://"),j=a._isDirectCall(b);!j&&0<=b.indexOf("?ALLOWSORIGIN?")&&(j=!0,b=b.replace(/\?ALLOWSORIGIN\?/,""));var k=!h&&a.$supportsIECrossDomainScripting(),m=null;if(l||d||!h&&!j||!f&&
 k)m=a._getRawDataFromServer("_",b,f,f,d,!0);else{b=b.replace(/file:\/\/\/\//,"file://");var n={dataType:e?"binary":"text",async:!!f};g?(n.type="POST",n.url=b.split("?POST?")[0],n.data=b.split("?POST?")[1]):(n.type="GET",n.url=b);f&&(n.success=function(){f(a._xhrReturn(n.xhr))},n.error=function(){f(n.xhr.statusText)});n.xhr=a.$ajax(n);f||(m=a._xhrReturn(n.xhr))}if(!c)return m;null==m&&(m="",e=!1);e&&(e=a._canSyncBinary(!0));return e?a._strToBytes(m):JU.SB.newS(m)};a._xhrReturn=function(b){return!b.responseText&&
 ""!==b.responseText||self.Clazz&&Clazz.instanceOf(b.response,self.ArrayBuffer)?b.response||b.statusText:b.responseText};a._isDirectCall=function(b){if(0<=b.indexOf("?ALLOWSORIGIN?"))return!0;for(var f in a.db._DirectDatabaseCalls)if(0<=f.indexOf(".")&&0<=b.indexOf(f))return!0;return!1};a._cleanFileData=function(b){return 0<=b.indexOf("\r")&&0<=b.indexOf("\n")?b.replace(/\r\n/g,"\n"):0<=b.indexOf("\r")?b.replace(/\r/g,"\n"):b};a._getFileType=function(b){var a=b.substring(0,1);if("$"==a||":"==a)return"MOL";
@@ -66,27 +66,28 @@ var c=f.originalEvent;switch(f.type){case "touchstart":a._touching=!0;break;case
 function(b){var f=function(b){return!b.target||0<=(""+b.target.className).indexOf("swingjs-ui")};a.$bind(b,"mousedown touchstart",function(c){if(f(c))return!0;a._allowKeyboardFocus&&b.focus();a._setMouseOwner(b,!0);c.stopPropagation();var e=c.target["data-UI"];(!e||!e.handleJSEvent(b,501,c))&&c.preventDefault();b.isDragging=!0;if("touchstart"==c.type&&a._gestureUpdate(b,c))return!!e;a._setConsoleDiv(b.applet._console);var d=a._jsGetXY(b,c);d&&(2!=c.button&&a.Swing.hideMenus(b.applet),b.applet._processEvent(501,
 d));return!!e});a.$bind(b,"mouseup touchend",function(c){if(f(c))return!0;a._setMouseOwner(null);c.stopPropagation();var e=c.target["data-UI"];(!e||!e.handleJSEvent(b,502,c))&&c.preventDefault();b.isDragging=!1;if("touchend"==c.type&&a._gestureUpdate(b,c))return!!e;(c=a._jsGetXY(b,c))&&b.applet._processEvent(502,c);return!!e});a.$bind(b,"mousemove touchmove",function(c){if(f(c))return!0;a._allowKeyboardFocus&&b.focus();if(a._mouseOwner&&a._mouseOwner!=b&&a._mouseOwner.isDragging){if(!a._mouseOwner.mouseMove)return!0;
 a._mouseOwner.mouseMove(c);return!1}return a._drag(b,c)});a.$bind(b,"keydown keyup",function(c){if(f(c))return!0;c.stopPropagation();c.preventDefault();var e=a._jsGetXY(b,c),d="keydown"==c.type?401:402;b.applet._processKeyEvent&&b.applet._processKeyEvent(d,e,c);return!0});a._drag=function(b,e){e.stopPropagation();e.preventDefault();if("touchmove"==e.type&&a._gestureUpdate(b,e))return!1;var f=a._jsGetXY(b,e);if(!f)return!1;b.isDragging||(f[2]=0);var d=e.target["data-UI"];b.isdragging&&(!d||d.handleJSEvent(b,
-506,e));b.applet._processEvent(b.isDragging?506:503,f);return!!d};a.$bind(b,"DOMMouseScroll mousewheel",function(c){if(f(c))return!0;c.stopPropagation();c.preventDefault();b.isDragging=!1;var e=c.originalEvent,e=e.detail?e.detail:("mac"==a.featureDetection.os?1:-1)*e.wheelDelta;c=a._jsGetMouseModifiers(c);b.applet._processEvent(507,[0>e?-1:1,0,c]);return!1});a.$bind(b,"contextmenu",function(){return!1});a.$bind(b,"mouseout",function(c){if(f(c))return!0;a._mouseOwner&&!a._mouseOwner.mouseMove&&a._setMouseOwner(null);
-b.applet._appletPanel&&b.applet._appletPanel.startHoverWatcher(!1);a._jsGetXY(b,c);return!1});a.$bind(b,"mouseenter",function(c){if(f(c))return!0;b.applet._appletPanel&&b.applet._appletPanel.startHoverWatcher(!0);if(0===c.buttons||0===c.which){b.isDragging=!1;c=a._jsGetXY(b,c);if(!c)return!1;b.applet._processEvent(504,c);b.applet._processEvent(502,c);return!1}});a.$bind(b,"mousemoveoutjsmol",function(c,e,d){if(f(d))return!0;if(b==a._mouseOwner&&b.isDragging)return a._drag(b,d)});b.applet._is2D&&a.$resize(function(){b.applet&&
-b.applet._resize()});a.$bind("body","mouseup touchend",function(c){if(f(c))return!0;b.applet&&(b.isDragging=!1);a._setMouseOwner(null)})};a._jsUnsetMouse=function(b){b.applet=null;a.$bind(b,"mousedown touchstart mousemove touchmove mouseup touchend DOMMouseScroll mousewheel contextmenu mouseout mouseenter",null);a._setMouseOwner(null)};a.Swing={count:0,menuInitialized:0,menuCounter:0,htDialogs:{}};var k=a.Swing;SwingController=k;k.setDraggable=function(b){b=b.prototype;b.setContainer||(b.setContainer=
-function(b){this.container=b;b.obj=this;this.ignoreMouse=this.isDragging=!1;var c=this;b.bind("mousedown touchstart",function(b){if(c.ignoreMouse)return c.ignoreMouse=!1,!0;a._setMouseOwner(c,!0);c.isDragging=!0;c.pageX=b.pageX;c.pageY=b.pageY;return!1});b.bind("mousemove touchmove",function(b){if(c.isDragging&&a._mouseOwner==c)return c.mouseMove(b),!1});b.bind("mouseup touchend",function(b){c.mouseUp(b);a._setMouseOwner(null)})},b.mouseUp=function(b){if(this.isDragging&&a._mouseOwner==this)return this.pageX0+=
-b.pageX-this.pageX,this.pageY0+=b.pageY-this.pageY,this.isDragging=!1;a._setMouseOwner(null)},b.setPosition=function(){if(null===a._mousePageX){var b=a.$offset(this.applet._id+"_"+(this.applet._is2D?"canvas2d":"canvas"));a._mousePageX=b.left;a._mousePageY=b.top}this.pageX0=a._mousePageX;this.pageY0=a._mousePageY;this.container.css({top:a._mousePageY+"px",left:a._mousePageX+"px"})},b.mouseMove=function(b){if(this.isDragging&&a._mouseOwner==this){this.timestamp=System.currentTimeMillis();var c=this.pageX0+
-(b.pageX-this.pageX);b=this.pageY0+(b.pageY-this.pageY);a._mousePageX=c;a._mousePageY=b;this.container.css({top:b+"px",left:c+"px"})}},b.dragBind=function(b){this.applet._ignoreMouse=!b;this.container.unbind("mousemoveoutjsmol");this.container.unbind("touchmoveoutjsmol");this.container.unbind("mouseupoutjsmol");this.container.unbind("touchendoutjsmol");a._setMouseOwner(null);if(b){var c=this;this.container.bind("mousemoveoutjsmol touchmoveoutjsmol",function(b,a,e){c.mouseMove(e)});this.container.bind("mouseupoutjsmol touchendoutjsmol",
-function(b,a,e){c.mouseUp(e)})}})};k.JSDialog=function(){};k.setDraggable(k.JSDialog);k.getScreenDimensions=function(b){b.width=h(window).width();b.height=h(window).height()};k.dispose=function(b){a.$remove(b.id+"_mover");delete k.htDialogs[b.id];b.container.obj.dragBind(!1)};k.register=function(b,a){b.id=a+ ++k.count;k.htDialogs[b.id]=b};k.setDialog=function(b){a._setMouseOwner(null);a.$remove(b.id);var e=b.id+"_mover",c=a._$(e),d;c[0]?(c.html(b.html),d=c[0].jd):(a.$after("body","<div id='"+e+"' style='position:absolute;left:0px;top:0px;'>"+
-b.html+"</div>"),d=new k.JSDialog,c=a._$(e),b.container=c,d.applet=b.manager.vwr.html5Applet,d.setContainer(c),d.dialog=b,d.setPosition(),d.dragBind(!0),c[0].jd=d);a.$bind("#"+b.id+" .JButton","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JComboBox","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JCheckBox","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JTextField","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+
-b.id+" .JTable","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JScrollPane","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JEditorPane","mousedown touchstart",function(){d.ignoreMouse=!0})};k.setSelected=function(b){a.$prop(b.id,"checked",!!b.selected)};k.setSelectedIndex=function(b){a.$prop(b.id,"selectedIndex",b.selectedIndex)};k.setText=function(b){a.$prop(b.id,"value",b.text)};k.setVisible=function(b){a.$setVisible(b.id,b._visible)};k.setEnabled=
-function(b){a.$setEnabled(b.id,b.enabled)};k.click=function(b,e){var c=k.htDialogs[b.id];if(c){var d=c.toString();if(0<=d.indexOf("JCheck"))c.selected=b.checked;else if(0<=d.indexOf("JCombo"))c.selectedIndex=b.selectedIndex;else if(null!=c.text&&(c.text=b.value,e&&13!=(e.charCode||e.keyCode)))return}d=k.htDialogs[a.$getAncestorDiv(b.id,"JDialog").id];d.manager.actionPerformed(c?c.name:d.registryKey+"/"+b.id)};k.setFront=function(b){var e=b.manager.vwr.html5Applet;b.zIndex!=a._getZ(e,"dialog")&&(b.zIndex=
-a._incrZ(e,"dialog"));b.container&&((b.container[0]||b.container).style.zIndex=b.zIndex)};k.hideMenus=function(b){if(b=b._menus)for(var a in b)b[a]._visible&&k.hideMenu(b[a])};k.windowClosing=function(b){b=k.htDialogs[a.$getAncestorDiv(b.id,"JDialog").id];b.registryKey?b.manager.processWindowClosing(b.registryKey):b.dispose()};a._track=function(b){if(a._tracker){try{var e='<iframe style="display:none" width="0" height="0" frameborder="0" tabindex="-1" src="'+(a._tracker+"&applet="+b._jmolType+"&version="+
-a._version+"&appver="+a.___JmolVersion+"&url="+encodeURIComponent(document.location.href))+'"></iframe>';a.$after("body",e)}catch(c){}delete a._tracker}return b};var m;a.getProfile=function(b){if(self.Clazz&&self.JSON)return m||Clazz._startProfiling(m=0==arguments.length||b),Clazz.getProfile()};a._getInChIKey=function(b,a){0<=a.indexOf("MOL=")&&a.split("MOL=")[1].split('"')};a._getAttr=function(b,a){var c=b.indexOf(a+"=");return 0<=c&&0<=(c=b.indexOf('"',c))?b.substring(c+1,b.indexOf('"',c+1)):null};
-a.User={viewUpdatedCallback:null};a.View={count:0,applets:{},sets:{}};(function(b){b.resetView=function(b,c){debugger;if(c){if(c._viewSet){var e=a.View.applets[c._viewSet];for(b in e)b!=c&&a.View.resetView(b)}}else b&&(b._reset(),a.View.updateView(b))};b.updateView=function(e,c){if(null!=e._viewSet){c||(c={});c.chemID||(e._searchQuery=null);c.data||(c.data="N/A");c.type=e._viewType;if(null==(e._currentView=b.__findView(e._viewSet,c)))e._currentView=b.__createViewSet(e._viewSet,c.chemID,c.viewID||
-c.chemID);e._currentView[c.type].data=c.data;e._currentView[c.type].smiles=e._getSmiles();a.User.viewUpdatedCallback&&a.User.viewUpdatedCallback(e,"updateView");b.__setView(e._currentView,e,!1)}};b.updateFromSync=function(e,c){e._updateMsg=c;var d=a._getAttr(c,"sourceID")||a._getAttr(c,"file");if(d){var g=b.__findView(e._viewSet,{viewID:d});if(null==g)return a.updateView(e,c);g!=e._currentView&&b.__setView(g,e,!0);var h=(d=a._getAttr(c,"atoms"))&&0<=c.indexOf("selectionhalos ON")?eval("["+d+"]"):
-[];setTimeout(function(){e._currentView==g&&b.updateAtomPick(e,h)},10);a.User.viewUpdatedCallback&&a.User.viewUpdatedCallback(e,"updateFromSync")}};b.updateAtomPick=function(b,e){var d=b._currentView;if(null!=d){for(var g in d)"info"!=g&&d[g].applet!=b&&d[g].applet._updateAtomPick(e);a.User.viewUpdatedCallback&&a.User.viewUpdatedCallback(b,"updateAtomPick")}};b.dumpViews=function(a){var e=b.sets[a];if(e){var d="View set "+a+":\n";a=b.applets[a];for(var g in a)d+="\napplet "+a[g]._id+" currentView="+
-(a[g]._currentView?a[g]._currentView.info.viewID:null);for(g=e.length;0<=--g;){a=e[g];var d=d+("\n\n<b>view="+g+" viewID="+a.info.viewID+" chemID="+a.info.chemID+"</b>\n"),h,l;for(l in a)"info"!=l&&(d+="\nview="+g+" type="+l+" applet="+((h=a[l]).applet?h.applet._id:null)+" SMILES="+h.smiles+"\n atomMap="+JSON.stringify(h.atomMap)+"\n data=\n"+h.data+"\n")}return d}};b.__init=function(a){var e=a._viewSet,d=b.applets;d[e]||(d[e]={});d[e][a._viewType]=a};b.__findView=function(a,e){var d=b.sets[a];null==
-d&&(d=b.sets[a]=[]);for(var g=d.length;0<=--g;){var h=d[g];if(e.viewID){if(h.info.viewID==e.viewID)return h}else{if(null!=e.chemID&&e.chemID==h.info.chemID)return h;for(var l in h)if("info"!=l&&(null!=e.data&&null!=h[l].data?e.data==h[l].data:e.type==l))return h}}return null};b.__createViewSet=function(e,c,d){b.count++;c={info:{chemID:c,viewID:d||"model_"+b.count}};for(var g in a._applets)d=a._applets[g],d._viewSet==e&&(c[d._viewType]={applet:d,data:null});b.sets[e].push(c);return c};b.__setView=
-function(b,a,e){for(var d in b)if("info"!=d){var g=b[d],h=g.applet,l=e||null!=h&&"<modified>"==h._molData;if(!(null==h||h==a&&!l)){var j=null==g.data,k=null!=h._currentView;h._currentView=b;if(!k||!(b[d].data==g.data&&!j&!l))if(h._loadModelFromView(b),j)break}}}})(a.View);a.Cache={fileCache:{}};a.Cache.get=function(b){return a.Cache.fileCache[b]};a.Cache.put=function(b,e){a.Cache.fileCache[b]=e};a.Cache.setDragDrop=function(b,e){a.$appEvent(b,e,"dragover",function(b){b=b.originalEvent;b.stopPropagation();
-b.preventDefault();b.dataTransfer.dropEffect="copy"});a.$appEvent(b,e,"drop",function(c){var d=c.originalEvent;d.stopPropagation();d.preventDefault();var g=d.dataTransfer.files[0];if(null==g)try{g=""+d.dataTransfer.getData("text"),(0==g.indexOf("file:/")||0==g.indexOf("http:/")||0==g.indexOf("https:/"))&&b._scriptLoad(g)}catch(h){}else d=new FileReader,d.onloadend=function(d){if(d.target.readyState==FileReader.DONE){var h="cache://DROP_"+g.name;d=Clazz.newByteArray(-1,d.target.result);if("console_input"==
-e)h=String.instantialize(d),a.$(b,e).val(0>h.indexOf("\x00")?h:d.length+" bytes");else{h.endsWith(".spt")||b._appletPanel.cacheFileByName("cache://DROP_*",!1);"JSV"==b._viewType||h.endsWith(".jdx")?a.Cache.put(h,d):b._appletPanel.cachePut(h,d);d=a._jsGetXY(b._canvas,c);var l=[null];d&&(!b._appletPanel.setStatusDragDropped||b._appletPanel.setStatusDragDropped(0,d[0],d[1],h,l))&&b._appletPanel.openFileAsyncSpecialType(h,1,l[0])}}},d.readAsArrayBuffer(g)})}})(Jmol,jQuery);
-Jmol._debugCode=document&&document.location&&0<=document.location.href.indexOf("j2sdebugcode");Jmol._grabberOptions=[["$","NCI(small molecules)"],[":","PubChem(small molecules)"]];Jmol.say=function(a){alert(a)};Jmol._TMApplet=function(a,h,e){this._uniqueId=(""+Math.random()).substring(3);this._id=a;this._is2D=!0;this._isJava=!1;this._ready=!0;this._mouseDown=!1;this._jmolType="Jmol._Canvas2D (TwirlyMol)";if(e)return this;this._createCanvas(a,h);return this};
+506,e));b.applet._processEvent(b.isDragging?506:503,f);return!!d};a.$bind(b,"DOMMouseScroll mousewheel",function(c){if(f(c))return!0;c.stopPropagation();c.preventDefault();b.isDragging=!1;var e=c.originalEvent,e=e.detail?e.detail:("mac"==a.featureDetection.os?1:-1)*e.wheelDelta;c=a._jsGetMouseModifiers(c);b.applet._processEvent(507,[0>e?-1:1,0,c]);return!1});a.$bind(b,"contextmenu",function(){return!1});a.$bind(b,"mouseout",function(c){if(f(c))return!0;a._mouseOwner&&(!a._mouseOwner.mouseMove&&!a._mouseOwner.isDragging)&&
+a._setMouseOwner(null);b.applet._appletPanel&&b.applet._appletPanel.startHoverWatcher(!1);a._jsGetXY(b,c);return!1});a.$bind(b,"mouseenter",function(c){if(f(c))return!0;b.applet._appletPanel&&b.applet._appletPanel.startHoverWatcher(!0);if(0===c.buttons||0===c.which){b.isDragging=!1;c=a._jsGetXY(b,c);if(!c)return!1;b.applet._processEvent(504,c);b.applet._processEvent(502,c);return!1}});a.$bind(b,"mousemoveoutjsmol",function(c,e,d){if(f(d))return!0;if(b==a._mouseOwner&&b.isDragging)return a._drag(b,
+d)});b.applet._is2D&&a.$resize(function(){b.applet&&b.applet._resize()});a.$bind("body","mouseup touchend",function(c){if(f(c))return!0;b.applet&&(b.isDragging=!1);a._setMouseOwner(null)})};a._jsUnsetMouse=function(b){b.applet=null;a.$bind(b,"mousedown touchstart mousemove touchmove mouseup touchend DOMMouseScroll mousewheel contextmenu mouseout mouseenter",null);a._setMouseOwner(null)};a.Swing={count:0,menuInitialized:0,menuCounter:0,htDialogs:{}};var k=a.Swing;SwingController=k;k.setDraggable=function(b){b=
+b.prototype;b.setContainer||(b.setContainer=function(b){this.container=b;b.obj=this;this.ignoreMouse=this.isDragging=!1;var c=this;b.bind("mousedown touchstart",function(b){if(c.ignoreMouse)return c.ignoreMouse=!1,!0;a._setMouseOwner(c,!0);c.isDragging=!0;c.pageX=b.pageX;c.pageY=b.pageY;return!1});b.bind("mousemove touchmove",function(b){if(c.isDragging&&a._mouseOwner==c)return c.mouseMove(b),!1});b.bind("mouseup touchend",function(b){c.mouseUp(b);a._setMouseOwner(null)})},b.mouseUp=function(b){if(this.isDragging&&
+a._mouseOwner==this)return this.pageX0+=b.pageX-this.pageX,this.pageY0+=b.pageY-this.pageY,this.isDragging=!1;a._setMouseOwner(null)},b.setPosition=function(){if(null===a._mousePageX){var b=a.$offset(this.applet._id+"_"+(this.applet._is2D?"canvas2d":"canvas"));a._mousePageX=b.left;a._mousePageY=b.top}this.pageX0=a._mousePageX;this.pageY0=a._mousePageY;this.container.css({top:a._mousePageY+"px",left:a._mousePageX+"px"})},b.mouseMove=function(b){if(this.isDragging&&a._mouseOwner==this){this.timestamp=
+System.currentTimeMillis();var c=this.pageX0+(b.pageX-this.pageX);b=this.pageY0+(b.pageY-this.pageY);a._mousePageX=c;a._mousePageY=b;this.container.css({top:b+"px",left:c+"px"})}},b.dragBind=function(b){this.applet._ignoreMouse=!b;this.container.unbind("mousemoveoutjsmol");this.container.unbind("touchmoveoutjsmol");this.container.unbind("mouseupoutjsmol");this.container.unbind("touchendoutjsmol");a._setMouseOwner(null);if(b){var c=this;this.container.bind("mousemoveoutjsmol touchmoveoutjsmol",function(b,
+a,e){c.mouseMove(e)});this.container.bind("mouseupoutjsmol touchendoutjsmol",function(b,a,e){c.mouseUp(e)})}})};k.JSDialog=function(){};k.setDraggable(k.JSDialog);k.getScreenDimensions=function(b){b.width=h(window).width();b.height=h(window).height()};k.dispose=function(b){a.$remove(b.id+"_mover");delete k.htDialogs[b.id];b.container.obj.dragBind(!1)};k.register=function(b,a){b.id=a+ ++k.count;k.htDialogs[b.id]=b};k.setDialog=function(b){a._setMouseOwner(null);a.$remove(b.id);var e=b.id+"_mover",
+c=a._$(e),d;c[0]?(c.html(b.html),d=c[0].jd):(a.$after("body","<div id='"+e+"' style='position:absolute;left:0px;top:0px;'>"+b.html+"</div>"),d=new k.JSDialog,c=a._$(e),b.container=c,d.applet=b.manager.vwr.html5Applet,d.setContainer(c),d.dialog=b,d.setPosition(),d.dragBind(!0),c[0].jd=d);a.$bind("#"+b.id+" .JButton","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JComboBox","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JCheckBox","mousedown touchstart",
+function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JTextField","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JTable","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JScrollPane","mousedown touchstart",function(){d.ignoreMouse=!0});a.$bind("#"+b.id+" .JEditorPane","mousedown touchstart",function(){d.ignoreMouse=!0})};k.setSelected=function(b){a.$prop(b.id,"checked",!!b.selected)};k.setSelectedIndex=function(b){a.$prop(b.id,"selectedIndex",b.selectedIndex)};
+k.setText=function(b){a.$prop(b.id,"value",b.text)};k.setVisible=function(b){a.$setVisible(b.id,b._visible)};k.setEnabled=function(b){a.$setEnabled(b.id,b.enabled)};k.click=function(b,e){var c=k.htDialogs[b.id];if(c){var d=c.toString();if(0<=d.indexOf("JCheck"))c.selected=b.checked;else if(0<=d.indexOf("JCombo"))c.selectedIndex=b.selectedIndex;else if(null!=c.text&&(c.text=b.value,e&&13!=(e.charCode||e.keyCode)))return}d=k.htDialogs[a.$getAncestorDiv(b.id,"JDialog").id];d.manager.actionPerformed(c?
+c.name:d.registryKey+"/"+b.id)};k.setFront=function(b){var e=b.manager.vwr.html5Applet;b.zIndex!=a._getZ(e,"dialog")&&(b.zIndex=a._incrZ(e,"dialog"));b.container&&((b.container[0]||b.container).style.zIndex=b.zIndex)};k.hideMenus=function(b){if(b=b._menus)for(var a in b)b[a]._visible&&k.hideMenu(b[a])};k.windowClosing=function(b){b=k.htDialogs[a.$getAncestorDiv(b.id,"JDialog").id];b.registryKey?b.manager.processWindowClosing(b.registryKey):b.dispose()};a._track=function(b){if(a._tracker){try{var e=
+'<iframe style="display:none" width="0" height="0" frameborder="0" tabindex="-1" src="'+(a._tracker+"&applet="+b._jmolType+"&version="+a._version+"&appver="+a.___JmolVersion+"&url="+encodeURIComponent(document.location.href))+'"></iframe>';a.$after("body",e)}catch(c){}delete a._tracker}return b};var m;a.getProfile=function(b){if(self.Clazz&&self.JSON)return m||Clazz._startProfiling(m=0==arguments.length||b),Clazz.getProfile()};a._getInChIKey=function(b,a){0<=a.indexOf("MOL=")&&a.split("MOL=")[1].split('"')};
+a._getAttr=function(b,a){var c=b.indexOf(a+"=");return 0<=c&&0<=(c=b.indexOf('"',c))?b.substring(c+1,b.indexOf('"',c+1)):null};a.User={viewUpdatedCallback:null};a.View={count:0,applets:{},sets:{}};(function(b){b.resetView=function(b,c){debugger;if(c){if(c._viewSet){var e=a.View.applets[c._viewSet];for(b in e)b!=c&&a.View.resetView(b)}}else b&&(b._reset(),a.View.updateView(b))};b.updateView=function(e,c){if(null!=e._viewSet){c||(c={});c.chemID||(e._searchQuery=null);c.data||(c.data="N/A");c.type=e._viewType;
+if(null==(e._currentView=b.__findView(e._viewSet,c)))e._currentView=b.__createViewSet(e._viewSet,c.chemID,c.viewID||c.chemID);e._currentView[c.type].data=c.data;e._currentView[c.type].smiles=e._getSmiles();a.User.viewUpdatedCallback&&a.User.viewUpdatedCallback(e,"updateView");b.__setView(e._currentView,e,!1)}};b.updateFromSync=function(e,c){e._updateMsg=c;var d=a._getAttr(c,"sourceID")||a._getAttr(c,"file");if(d){var g=b.__findView(e._viewSet,{viewID:d});if(null==g)return a.updateView(e,c);g!=e._currentView&&
+b.__setView(g,e,!0);var h=(d=a._getAttr(c,"atoms"))&&0<=c.indexOf("selectionhalos ON")?eval("["+d+"]"):[];setTimeout(function(){e._currentView==g&&b.updateAtomPick(e,h)},10);a.User.viewUpdatedCallback&&a.User.viewUpdatedCallback(e,"updateFromSync")}};b.updateAtomPick=function(b,e){var d=b._currentView;if(null!=d){for(var g in d)"info"!=g&&d[g].applet!=b&&d[g].applet._updateAtomPick(e);a.User.viewUpdatedCallback&&a.User.viewUpdatedCallback(b,"updateAtomPick")}};b.dumpViews=function(a){var e=b.sets[a];
+if(e){var d="View set "+a+":\n";a=b.applets[a];for(var g in a)d+="\napplet "+a[g]._id+" currentView="+(a[g]._currentView?a[g]._currentView.info.viewID:null);for(g=e.length;0<=--g;){a=e[g];var d=d+("\n\n<b>view="+g+" viewID="+a.info.viewID+" chemID="+a.info.chemID+"</b>\n"),h,l;for(l in a)"info"!=l&&(d+="\nview="+g+" type="+l+" applet="+((h=a[l]).applet?h.applet._id:null)+" SMILES="+h.smiles+"\n atomMap="+JSON.stringify(h.atomMap)+"\n data=\n"+h.data+"\n")}return d}};b.__init=function(a){var e=a._viewSet,
+d=b.applets;d[e]||(d[e]={});d[e][a._viewType]=a};b.__findView=function(a,e){var d=b.sets[a];null==d&&(d=b.sets[a]=[]);for(var g=d.length;0<=--g;){var h=d[g];if(e.viewID){if(h.info.viewID==e.viewID)return h}else{if(null!=e.chemID&&e.chemID==h.info.chemID)return h;for(var l in h)if("info"!=l&&(null!=e.data&&null!=h[l].data?e.data==h[l].data:e.type==l))return h}}return null};b.__createViewSet=function(e,c,d){b.count++;c={info:{chemID:c,viewID:d||"model_"+b.count}};for(var g in a._applets)d=a._applets[g],
+d._viewSet==e&&(c[d._viewType]={applet:d,data:null});b.sets[e].push(c);return c};b.__setView=function(b,a,e){for(var d in b)if("info"!=d){var g=b[d],h=g.applet,l=e||null!=h&&"<modified>"==h._molData;if(!(null==h||h==a&&!l)){var j=null==g.data,k=null!=h._currentView;h._currentView=b;if(!k||!(b[d].data==g.data&&!j&!l))if(h._loadModelFromView(b),j)break}}}})(a.View);a.Cache={fileCache:{}};a.Cache.get=function(b){return a.Cache.fileCache[b]};a.Cache.put=function(b,e){a.Cache.fileCache[b]=e};a.Cache.setDragDrop=
+function(b,e){a.$appEvent(b,e,"dragover",function(b){b=b.originalEvent;b.stopPropagation();b.preventDefault();b.dataTransfer.dropEffect="copy"});a.$appEvent(b,e,"drop",function(c){var d=c.originalEvent;d.stopPropagation();d.preventDefault();var g=d.dataTransfer.files[0];if(null==g)try{g=""+d.dataTransfer.getData("text"),(0==g.indexOf("file:/")||0==g.indexOf("http:/")||0==g.indexOf("https:/"))&&b._scriptLoad(g)}catch(h){}else d=new FileReader,d.onloadend=function(d){if(d.target.readyState==FileReader.DONE){var h=
+"cache://DROP_"+g.name;d=Clazz.newByteArray(-1,d.target.result);if("console_input"==e)h=String.instantialize(d),a.$(b,e).val(0>h.indexOf("\x00")?h:d.length+" bytes");else{h.endsWith(".spt")||b._appletPanel.cacheFileByName("cache://DROP_*",!1);"JSV"==b._viewType||h.endsWith(".jdx")?a.Cache.put(h,d):b._appletPanel.cachePut(h,d);d=a._jsGetXY(b._canvas,c);var l=[null];d&&(!b._appletPanel.setStatusDragDropped||b._appletPanel.setStatusDragDropped(0,d[0],d[1],h,l))&&b._appletPanel.openFileAsyncSpecialType(h,
+1,l[0])}}},d.readAsArrayBuffer(g)})}})(Jmol,jQuery);Jmol._debugCode=document&&document.location&&0<=document.location.href.indexOf("j2sdebugcode");Jmol._grabberOptions=[["$","NCI(small molecules)"],[":","PubChem(small molecules)"]];Jmol.say=function(a){alert(a)};
+Jmol._TMApplet=function(a,h,e){this._uniqueId=(""+Math.random()).substring(3);this._id=a;this._is2D=!0;this._isJava=!1;this._ready=!0;this._mouseDown=!1;this._jmolType="Jmol._Canvas2D (TwirlyMol)";if(e)return this;this._createCanvas(a,h);return this};
 Jmol._TMApplet._getApplet=function(a,h,e){if(!Jmol.featureDetection.allowHTML5)return null;e||(e=!1);h||(h={});Jmol._addDefaultInfo(h,{color:"#FFFFFF",width:300,height:300,addSelectionOptions:!1,serverURL:"http://your.server.here/jsmol.php",defaultModel:"",readyFunction:null,use:"HTML5",bondWidth:5,shadeAtoms:!1,zoomScaling:1.5,pinchScaling:2,mouseDragFactor:0.5,touchDragFactor:0.15,multipleBondSpacing:4,spinRateX:0,spinRateY:0.5,spinFPS:20,spin:!1,noscript:!0,debug:!1});h=new Jmol._TMApplet(a,h,
 e);return e?h:Jmol._registerApplet(a,h)};Jmol.getTMApplet=Jmol._TMApplet._getApplet;
 (function(a){a._CPK="#FF1493 #FFFFFF #D9FFFF #CC80FF #C2FF00 #FFB5B5 #909090 #3050F8 #FF0D0D #90E050 #B3E3F5 #AB5CF2 #8AFF00 #BFA6A6 #F0C8A0 #FF8000 #FFFF30 #1FF01F #80D1E3 #8F40D4 #3DFF00 #E6E6E6 #BFC2C7 #A6A6AB #8A99C7 #9C7AC7 #E06633 #F090A0 #50D050 #C88033 #7D80B0 #C28F8F #668F8F #BD80E3 #FFA100 #A62929 #5CB8D1 #702EB0 #00FF00 #94FFFF #94E0E0 #73C2C9 #54B5B5 #3B9E9E #248F8F #0A7D8C #006985 #C0C0C0 #FFD98F #A67573 #668080 #9E63B5 #D47A00 #940094 #429EB0 #57178F #00C900".split(" ");a._elem="X H He Li Be B C N O F Ne Na Mg Al Si P S Cl Ar K Ca Sc Ti V Cr Mn Fe Co Ni Cu Zn Ga Ge As Se Br Kr Rb Sr Y Zr Nb Mo Tc Ru Rh Pd Ag Cd In Sn Sb Te I Xe Cs Ba La Ce Pr Nd Pm Sm Eu Gd Tb Dy Ho Er Tm Yb Lu Hf Ta W Re Os Ir Pt Au Hg Tl Pb Bi Po At Rn Fr Ra Ac Th Pa U Np Pu Am Cm Bk Cf Es".split(" ");
