@@ -6,4 +6,4 @@ function(){
 return  new J.adapter.readers.cif.Cif2DataParser().set(this, null, this.debugging);
 });
 });
-;//5.0.1-v2 Fri Jan 26 13:42:49 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
