@@ -29,7 +29,10 @@ Clazz.overrideMethod(c$, "initSubclass",
 function(){
 this.setIsPDB();
 this.mident = JU.M4.newM4(null);
-this.isMMCIF = true;
+if (!this.filteredPrecision) {
+this.precision = 3;
+this.filteredPrecision = true;
+}this.isMMCIF = true;
 if (this.isDSSP1) this.asc.setInfo("isDSSP1", Boolean.TRUE);
 if (this.htParams.containsKey("isMutate")) this.asc.setInfo("isMutate", Boolean.TRUE);
 this.doSetBonds = this.checkFilterKey("ADDBONDS");
@@ -643,8 +646,8 @@ c$.structRefFields =  Clazz.newArray(-1, ["_struct_ref_seq_dif_mon_id", "_struct
 c$.chemCompFields =  Clazz.newArray(-1, ["_chem_comp_id", "_chem_comp_name"]);
 c$.structConfFields =  Clazz.newArray(-1, ["*_conf_type_id", "*_beg_auth_asym_id", "*_beg_auth_seq_id", "*_pdbx_beg_pdb_ins_code", "*_end_auth_asym_id", "*_end_auth_seq_id", "*_pdbx_end_pdb_ins_code", "*_id", "*_pdbx_pdb_helix_id", "*_pdbx_pdb_helix_class"]);
 c$.structSheetRangeFields =  Clazz.newArray(-1, ["*_sheet_id", "*_beg_auth_asym_id", "*_beg_auth_seq_id", "*_pdbx_beg_pdb_ins_code", "*_end_auth_asym_id", "*_end_auth_seq_id", "*_pdbx_end_pdb_ins_code", "*_id"]);
-c$.structSiteFields =  Clazz.newArray(-1, ["*_site_id", "*_auth_comp_id", "*_auth_asym_id", "*_auth_seq_id", "*_label_alt_id"]);
+c$.structSiteFields =  Clazz.newArray(-1, ["*_site_id", "*_auth_comp_id", "*_auth_asym_id", "*_auth_seq_id", "*_pdbx_auth_ins_code"]);
 c$.structConnFields =  Clazz.newArray(-1, ["*_ptnr1_auth_asym_id", "*_ptnr1_auth_seq_id", "*_ptnr1_auth_comp_id", "*_ptnr1_label_atom_id", "*_pdbx_ptnr1_label_alt_id", "*_ptnr1_symmetry", "*_ptnr2_auth_asym_id", "*_ptnr2_auth_seq_id", "*_ptnr2_auth_comp_id", "*_ptnr2_label_atom_id", "*_pdbx_ptnr2_label_alt_id", "*_ptnr2_symmetry", "*_conn_type_id", "*_pdbx_value_order"]);
 c$.chemCompBondFields =  Clazz.newArray(-1, ["*_comp_id", "*_atom_id_1", "*_atom_id_2", "*_value_order", "*_pdbx_aromatic_flag"]);
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
