@@ -535,6 +535,7 @@ var atoms = asc.atoms;
 var pt =  new JU.P3();
 var bs = asc.getBSAtoms(-1);
 var i0 = this.cr.asc.getLastAtomSetAtomIndex();
+var packing = this.cr.getPackingRangeValue(0.001);
 for (var i = bs.nextSetBit(i0); i >= 0; i = bs.nextSetBit(i + 1)) {
 var a = atoms[i];
 var isOK = (!this.isCommensurate || this.modAverage || a.foccupancy >= 0.5);
@@ -544,7 +545,7 @@ if (a.vib != null) pt.add(a.vib);
 this.getSymmetry(a).toCartesian(pt, false);
 sym.toFractional(pt, false);
 this.cr.fixFloatPt(pt, 100000.0);
-isOK = asc.xtalSymmetry.isWithinCell(3, pt, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, 0.001);
+isOK = asc.xtalSymmetry.isWithinCell(3, pt, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, packing);
 }if (isOK) {
 this.cr.fixFloatPt(a, 100000.0);
 } else {
@@ -592,4 +593,4 @@ if (a != null) lattvecs.addLast(a);
 return true;
 }, "JU.Lst,~S");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
