@@ -170,4 +170,4 @@ if (f == null) JU.Logger.error("Exponent for " + code + " not found");
 return  new J.quantum.SlaterData(iAtom, x, y, z, r, zeta, 1);
 }, "~N,~S,~S");
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
