@@ -185,4 +185,4 @@ JU.Logger.info("Molecular dipole for model " + this.asc.atomSetCount + " = " + d
 this.asc.setCurrentModelInfo("dipole", dipole);
 }});
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
