@@ -404,4 +404,4 @@ for (var i = 0; i < this.modelAtomCount; i++) this.setAtomCoordScaled(atoms[i +
 
 }, "~S,~B,~B");
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
