@@ -396,4 +396,4 @@ if (charge != 0) name += "<sup>" + Math.abs(charge) + (charge > 0 ? "+" : charge
 }return name;
 }, "JM.Atom");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
