@@ -186,4 +186,4 @@ c$.$DC_LIST = "xx    yy    zz    xy    xz    yz";
 c$.$FS_LIST = "NOT IMPLEMENTED IN THIS READER";
 c$.$FC_LIST = "xxx   yyy   zzz   yyx   xxy   xxz   zzx   zzy   yyz   xyz";
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
