@@ -62,4 +62,4 @@ this.asc.addBond( new J.adapter.smarter.Bond(atomIndex1, atomIndex2, order));
 }
 }, "~N");
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
