@@ -67,4 +67,4 @@ this.asc.atoms[i + this.baseAtomIndex].partialCharge = Float.parseFloat(this.lin
 }
 });
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
