@@ -2,4 +2,4 @@ Clazz.declarePackage("J.adapter.readers.simple");
 Clazz.load(["J.adapter.readers.simple.FoldingXyzReader"], "J.adapter.readers.simple.TinkerReader", null, function(){
 var c$ = Clazz.declareType(J.adapter.readers.simple, "TinkerReader", J.adapter.readers.simple.FoldingXyzReader);
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
