@@ -69,4 +69,4 @@ if (!ignore[j]) this.asc.addVibrationVector(i + (lineBaseFreqCount + j) * ac, x,
 }
 });
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
