@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.adapter.readers.xml");
-Clazz.load(["J.adapter.readers.xml.XmlReader", "J.adapter.smarter.Atom", "$.Bond", "java.util.ArrayList", "$.HashMap", "$.Stack"], "J.adapter.readers.xml.XmlCdxReader", ["JU.BS", "$.Lst", "$.PT", "J.api.JmolAdapter", "JU.Edge", "$.Logger"], function(){
+Clazz.load(["J.adapter.readers.xml.XmlReader", "J.adapter.smarter.Atom", "$.Bond", "java.util.HashMap", "$.Stack", "JU.Lst"], "J.adapter.readers.xml.XmlCdxReader", ["JU.BS", "$.PT", "J.api.JmolAdapter", "JU.Edge", "$.Logger"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.minX = 3.4028235E38;
 this.minY = 3.4028235E38;
@@ -26,7 +26,7 @@ Clazz.instantialize(this, arguments);}, J.adapter.readers.xml, "XmlCdxReader", J
 Clazz.prepareFields (c$, function(){
 this.fragments =  new java.util.Stack();
 this.nodes =  new java.util.Stack();
-this.nostereo =  new java.util.ArrayList();
+this.nostereo =  new JU.Lst();
 this.objectsByID =  new java.util.HashMap();
 });
 Clazz.makeConstructor(c$, 
@@ -185,8 +185,8 @@ return null;
 var node1 = this.asc.atoms[b.atomIndex1];
 var node2 = this.asc.atoms[b.atomIndex2];
 if (order == 1057) {
-if (!this.nostereo.contains(node1)) this.nostereo.add(node1);
-if (!this.nostereo.contains(node2)) this.nostereo.add(node2);
+if (!this.nostereo.contains(node1)) this.nostereo.addLast(node1);
+if (!this.nostereo.contains(node2)) this.nostereo.addLast(node2);
 }if (node1.hasMultipleAttachments) {
 node1.attachedAtom = node2;
 return b;
@@ -440,4 +440,4 @@ return "[CDBond " + this.id + " id1=" + this.id1 + " id2=" + this.id2 + Clazz.su
 /*eoif4*/})();
 };
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
