@@ -569,4 +569,4 @@ bs.andNot(this.deleteAtoms);
 }});
 c$.unitCellParamTags =  Clazz.newArray(-1, ["a", "b", "c", "alpha", "beta", "gamma"]);
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
