@@ -809,4 +809,4 @@ return false;
 c$.crtypes =  Clazz.newArray(-1, ["??", "nuclei", "bonds", "rings", "cages"]);
 c$.smap =  Clazz.newIntArray(-1, [2, 3, 4, 11, 5, 6, 7, 12, 8, 9, 10, 13]);
 });
-;//5.0.1-v2 Thu Jan 25 23:20:00 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
