@@ -13,7 +13,6 @@ Clazz.superConstructor (this, J.adapter.readers.xtal.PWmatReader, []);
 });
 Clazz.overrideMethod(c$, "initializeReader", 
 function(){
-if (!this.filteredPrecision) this.precision = 12;
 this.doApplySymmetry = true;
 });
 Clazz.overrideMethod(c$, "checkLine", 
@@ -212,4 +211,4 @@ if (!this.haveMagnetic && this.asc.ac > 0) {
 this.setProperties("pwm_magnetic",  Clazz.newFloatArray (this.asc.ac, 0), this.nAtoms);
 }});
 });
-;//5.0.1-v2 Thu Jan 25 23:19:59 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
