@@ -155,6 +155,10 @@ this.next =  Clazz.newIntArray (1, 0);
 this.highprecision0 = JV.Viewer.isHighPrecision;
 this.loadNote =  new JU.SB();
 });
+Clazz.defineMethod(c$, "getPackingRangeValue", 
+function(def){
+return (this.packingRange != null ? this.packingRange.floatValue() : def != 0 ? def : 0.02);
+}, "~N");
 Clazz.defineMethod(c$, "setup", 
 function(fullPath, htParams, readerOrDocument){
 this.setupASCR(fullPath, htParams, readerOrDocument);
@@ -442,9 +446,12 @@ this.isConcatenated = this.htParams.containsKey("concatenate");
 });
 Clazz.defineMethod(c$, "parsePrecision", 
 function(s){
+if (!this.filteredPrecision) {
 var pt = s.indexOf('.') + 1;
-if (pt >= 0 && !this.filteredPrecision) this.precision = Math.max(this.precision, s.length - pt);
-return this.parseFloatStr(s);
+if (pt >= 0) {
+var n = s.indexOf('(');
+this.precision = Math.max(this.precision, (n < 0 ? s.length : n) - pt);
+}}return this.parseFloatStr(s);
 }, "~S");
 Clazz.defineMethod(c$, "setLowPrecision", 
 function(){
@@ -483,7 +490,7 @@ if (this.fileCoordinatesAreFractional) {
 for (var i = this.asc.ac, n = this.asc.getLastAtomSetAtomIndex(); --i >= n; ) {
 this.symmetry.twelfthify(this.asc.atoms[i]);
 }
-}this.appendLoadNote("Precision set to " + this.precision + (this.packingRange == null ? "" : "; packing set to " + this.packingRange));
+}this.appendLoadNote("Precision set to " + this.precision + "; packing set to " + (this.packingRange == null ? 0.02 : this.packingRange.floatValue()));
 });
 Clazz.defineMethod(c$, "initializeSymmetryOptions", 
 function(){
@@ -528,6 +535,7 @@ this.unitCellParams =  Clazz.newFloatArray (27, 0);
 for (var i = 27; --i >= 0; ) this.unitCellParams[i] = NaN;
 
 this.unitCellParams[25] = this.latticeScaling;
+this.unitCellParams[26] = this.cellSlop;
 this.symmetry = null;
 }if (!this.ignoreFileSpaceGroupName) this.sgName = "unspecified!";
 this.doCheckUnitCell = false;
@@ -652,7 +660,7 @@ Clazz.defineMethod(c$, "getSymmetry",
 function(){
 if (!this.iHaveUnitCell) return null;
 if (this.symmetry == null) {
-this.getNewSymmetry().setUnitCell(this.unitCellParams, false, this.cellSlop);
+this.getNewSymmetry().setUnitCellFromParams(this.unitCellParams, false, this.cellSlop);
 this.checkUnitCellOffset();
 }if (this.symmetry == null) this.iHaveUnitCell = false;
  else this.symmetry.setSpaceGroupName(this.sgName);
@@ -884,7 +892,7 @@ atom.x = atom.x * this.fileScaling.x + this.fileOffset.x;
 atom.y = atom.y * this.fileScaling.y + this.fileOffset.y;
 atom.z = atom.z * this.fileScaling.z + this.fileOffset.z;
 }if (mustFractionalize) {
-if (!this.symmetry.haveUnitCell()) this.symmetry.setUnitCell(this.unitCellParams, false, NaN);
+if (!this.symmetry.haveUnitCell()) this.symmetry.setUnitCellFromParams(this.unitCellParams, false, NaN);
 this.symmetry.toFractional(atom, false);
 this.iHaveFractionalCoordinates = true;
 }if (this.floatifyJavaDouble && this.fileCoordinatesAreFractional) this.fixFloatPt(atom, 100000.0);
@@ -1313,4 +1321,4 @@ function(pt, prec){
 if (this.floatifyJavaDouble) JU.PT.fixPtFloats(pt, prec);
 }, "JU.P3,~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
