@@ -12,7 +12,6 @@ this.doNormalize = true;
 this.doPackUnitCell = false;
 this.trajectoryUnitCells = null;
 this.unitCellParams = null;
-this.baseUnitCell = null;
 this.latticeCells = null;
 this.unitCellTranslations = null;
 this.symmetryRange = 0;
@@ -96,7 +95,7 @@ this.trajectoryUnitCells =  new JU.Lst();
 this.asc.setInfo("unitCells", this.trajectoryUnitCells);
 }this.trajectoryUnitCells.addLast(this.unitCellParams);
 }this.asc.setGlobalBoolean(2);
-this.getSymmetry().setUnitCell(this.unitCellParams, false, this.unitCellParams[26]);
+this.getSymmetry().setUnitCellFromParams(this.unitCellParams, false, this.unitCellParams[26]);
 if (unitCellOffset != null) {
 this.symmetry.setOffsetPt(unitCellOffset);
 this.asc.setCurrentModelInfo("unitCellOffset", unitCellOffset);
@@ -129,7 +128,7 @@ doApplySymmetry = readerSymmetry.createSpaceGroup(this.acr.desiredSpaceGroupInde
 } else {
 this.acr.doPreSymmetry();
 readerSymmetry = null;
-}this.packingRange = (this.acr.packingRange == null ? 0.02 : this.acr.packingRange.floatValue());
+}this.packingRange = this.acr.getPackingRangeValue(0);
 if (doApplySymmetry) {
 if (readerSymmetry != null) this.setSpaceGroupFrom(readerSymmetry);
 this.applySymmetryLattice();
@@ -178,6 +177,7 @@ this.asc.setCurrentModelInfo("unitcell_conventional", this.symmetry.getConventio
 this.asc.setCurrentModelInfo("latticeType", this.acr.latticeType);
 var range = this.acr.fillRange;
 if ((typeof(range)=='string')) {
+this.setUnitCellSafely();
 var type = range;
 if (type.equals("conventional")) {
 range = this.symmetry.getConventionalUnitCell(this.acr.latticeType, this.acr.primitiveToCrystal);
@@ -221,7 +221,7 @@ this.setUnitCellSafely();
 this.adjustRangeMinMax(oabc);
 if (this.sym2 == null) {
 this.sym2 =  new JS.Symmetry();
-this.sym2.getUnitCelld(this.acr.fillRange, false, null);
+this.sym2.getUnitCell(this.acr.fillRange, false, null);
 }this.applyAllSymmetry(this.acr.ms, bsAtoms);
 pt0 =  new JU.P3();
 var atoms = this.asc.atoms;
@@ -293,7 +293,35 @@ if (!this.acr.noPack && (!this.applySymmetryToBonds || !this.acr.doPackUnitCell)
 this.setMinMax(this.ndims, kcode, maxX, maxY, maxZ);
 }if (this.acr.forcePacked || this.acr.doPackUnitCell || this.acr.noPack) {
 this.trimToUnitCell(iAtomFirst);
-}});
+}this.fixSuperCellAtomSites(bsAtoms);
+});
+Clazz.defineMethod(c$, "fixSuperCellAtomSites", 
+function(bsAtoms){
+var n = bsAtoms.cardinality();
+var baseAtoms =  new Array(n);
+var nbase = 0;
+var slop2 = 0.000001;
+slop2 *= slop2;
+for (var i = bsAtoms.nextSetBit(0); i >= 0; i = bsAtoms.nextSetBit(i + 1)) {
+var a = this.asc.atoms[i];
+var p =  new J.adapter.smarter.Atom();
+p.setT(a);
+p.atomSerial = a.atomSite;
+p.atomSite = a.atomSite;
+this.symmetry.unitize(p);
+var found = false;
+for (var ib = 0; ib < nbase; ib++) {
+var b = baseAtoms[ib];
+if (p.atomSerial == b.atomSerial && p.distanceSquared(b) < slop2) {
+found = true;
+a.atomSite = b.atomSite;
+break;
+}}
+if (!found) {
+a.atomSite = p.atomSite = nbase;
+baseAtoms[nbase++] = p;
+}}
+}, "JU.BS");
 Clazz.defineMethod(c$, "setMinMax", 
 function(dim, kcode, maxX, maxY, maxZ){
 this.minXYZ =  new JU.P3i();
@@ -526,7 +554,6 @@ this.asc.setCurrentModelInfo("presymmetryAtomCount", Integer.$valueOf(n));
 this.asc.setCurrentModelInfo("latticeDesignation", sym.getLatticeDesignation());
 this.asc.setCurrentModelInfo("unitCellRange", unitCells);
 this.asc.setCurrentModelInfo("unitCellTranslations", this.unitCellTranslations);
-this.baseUnitCell = this.unitCellParams;
 this.unitCellParams = null;
 this.reset();
 }, "J.adapter.smarter.MSInterface,JU.BS");
@@ -589,8 +616,9 @@ sym.toUnitCellRnd(c, this.ptOffset);
 pttemp.setT(c);
 sym.toFractional(pttemp, false);
 this.acr.fixFloatPt(pttemp, 100000.0);
-if (!this.isWithinCell(this.ndims, pttemp, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, this.packingRange)) continue;
-}if (checkSymmetryMinMax) this.setSymmetryMinMax(c);
+if (!this.isWithinCell(this.ndims, pttemp, this.minXYZ0.x, this.maxXYZ0.x, this.minXYZ0.y, this.maxXYZ0.y, this.minXYZ0.z, this.maxXYZ0.z, this.packingRange)) {
+continue;
+}}if (checkSymmetryMinMax) this.setSymmetryMinMax(c);
 var special = null;
 if (checkDistance) {
 if (checkSymmetryRange && (c.x < this.rminx || c.y < this.rminy || c.z < this.rminz || c.x > this.rmaxx || c.y > this.rmaxy || c.z > this.rmaxz)) continue;
@@ -999,7 +1027,7 @@ return this.nVib;
 });
 Clazz.defineMethod(c$, "scaleFractionalVibs", 
 function(){
-var params = this.getBaseSymmetry().getUnitCellParams();
+var params = this.acr.unitCellParams;
 var ptScale = JU.P3.new3(1 / params[0], 1 / params[1], 1 / params[2]);
 var i0 = this.asc.getAtomSetAtomIndex(this.asc.iSet);
 for (var i = this.asc.ac; --i >= i0; ) {
@@ -1012,13 +1040,6 @@ Clazz.defineMethod(c$, "getBaseSymmetry",
 function(){
 return (this.baseSymmetry == null ? this.symmetry : this.baseSymmetry);
 });
-Clazz.defineMethod(c$, "finalizeUnitCell", 
-function(ptSupercell){
-if (ptSupercell != null && this.baseUnitCell != null) {
-this.baseUnitCell[22] = Math.max(1, Clazz.floatToInt(ptSupercell.x));
-this.baseUnitCell[23] = Math.max(1, Clazz.floatToInt(ptSupercell.y));
-this.baseUnitCell[24] = Math.max(1, Clazz.floatToInt(ptSupercell.z));
-}}, "JU.P3");
 c$.mident = null;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Sun Feb 25 18:15:09 CST 2024
