@@ -22,7 +22,7 @@ try {
 var mi = this.vwr.ms.at[bs.nextSetBit(0)].mi;
 var uc = this.vwr.getCurrentUnitCell();
 this.haveUnitCell = (uc != null);
-if (!this.haveUnitCell) uc = this.vwr.getSymTemp().setUnitCell(null, false, 0.00001);
+if (!this.haveUnitCell) uc = this.vwr.getSymTemp().setUnitCellFromParams(null, false, 0.00001);
 this.slop = uc.getPrecision();
 this.isHighPrecision = (this.slop == 1.0E-12);
 this.precision = Clazz.doubleToInt(-Math.log10(this.slop));
@@ -205,4 +205,4 @@ return (this.oc == null ? "" : this.oc.toString());
 });
 c$.fset0 = JU.P3.new3(555, 555, 1);
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
