@@ -52,7 +52,7 @@ if (this.uc == null) {
 this.uc = this.vwr.getSymTemp();
 var bb = this.vwr.getBoundBoxCornerVector();
 var len = Math.round(bb.length() * 2);
-this.uc.setUnitCell( Clazz.newFloatArray(-1, [len, len, len, 90, 90, 90]), false, 1.0E-12);
+this.uc.setUnitCellFromParams( Clazz.newFloatArray(-1, [len, len, len, 90, 90, 90]), false, 1.0E-12);
 }var abc = this.uc.getUnitCellVectors();
 var f = "%18.10p%18.10p%18.10p\n";
 this.oc.append(JU.PT.sprintf(f, "p",  Clazz.newArray(-1, [abc[1]])));
@@ -183,4 +183,4 @@ function(){
 return (this.oc == null ? "" : this.oc.toString());
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
