@@ -50,4 +50,4 @@ c$.SLOPF = 0.0000010;
 c$.twelfths =  Clazz.newArray(-1, ["0.000000000000", "0.083333333333", "0.166666666667", "0.250000000000", "0.333333333333", "0.416666666667", "0.500000000000", "0.583333333333", "0.666666666667", "0.750000000000", "0.833333333333", "0.916666666667", "1.000000000000"]);
 c$.twelfthsF =  Clazz.newArray(-1, ["0.0000000", "0.0833333", "0.1666667", "0.2500000", "0.3333333", "0.4166667", "0.5000000", "0.5833333", "0.6666667", "0.7500000", "0.8333333", "0.9166667", "1.0000000"]);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
