@@ -2,4 +2,4 @@ Clazz.declarePackage("J.api");
 (function(){
 var c$ = Clazz.declareType(J.api, "JmolAdapterStructureIterator", null);
 })();
-;//5.0.1-v2 Fri Jan 26 13:42:08 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
