@@ -1,3 +1,3 @@
 Clazz.declarePackage("J.api");
 Clazz.declareInterface(J.api, "JmolScriptEvaluator");
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
