@@ -58,11 +58,11 @@ if (menu != null) (menu).disposeMenu();
 }, "J.api.SC");
 Clazz.defineMethod(c$, "itemStateChanged", 
 function(e){
-this.popup.menuCheckBoxCallback(e.getSource());
+if (this.popup != null) this.popup.menuCheckBoxCallback(e.getSource());
 }, "java.awt.event.ItemEvent");
 Clazz.defineMethod(c$, "actionPerformed", 
 function(e){
-this.popup.menuClickCallback(e.getSource(), e.getActionCommand());
+if (this.popup != null) this.popup.menuClickCallback(e.getSource(), e.getActionCommand());
 }, "java.awt.event.ActionEvent");
 Clazz.overrideMethod(c$, "getButtonGroup", 
 function(){
@@ -90,4 +90,4 @@ this.menuClearListeners(popupMenu);
 this.popup = null;
 }, "J.api.SC");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
