@@ -224,4 +224,4 @@ this.output(" V2 " + this.triad(ptC));
 this.outputTextureCode();
 }, "JU.T3,JU.T3,JU.T3,~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
