@@ -136,4 +136,4 @@ if (radius < 1) radius = 1;
 this.outputEllipsoid(center, radius, coef, colix);
 }, "JU.P3,~A,~N,~N,~N,~N,~N,JU.M3,~A,JU.M4,~A");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
