@@ -328,4 +328,4 @@ this.gdata.plotText(x, y, z, this.gdata.getColorArgbOrGray(colix), 0, text, font
 this.outputComment("end text " + this.nText + ": " + text);
 }, "~N,~N,~N,~N,~S,JU.Font");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
