@@ -600,4 +600,4 @@ this.argbEndcap = shadesEndcap[this.endcapShadeIndex];
 this.endCapHidden = (this.endcaps == 1);
 }, "~B,~B");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
