@@ -20,9 +20,9 @@ Clazz.overrideMethod(c$, "compare",
 function(a, b){
 return (a == null || b == null ? 0 : a.z > b.z ? -1 : a.z < b.z ? 1 : 0);
 }, "J.g3d.TextString,J.g3d.TextString");
-Clazz.defineMethod(c$, "toString", 
+Clazz.overrideMethod(c$, "toString", 
 function(){
-return Clazz.superCall(this, J.g3d.TextString, "toString", []) + " " + this.text;
+return this.asString() + " " + this.text;
 });
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
