@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.i18n");
-Clazz.load(null, "J.i18n.Resource", ["java.util.Hashtable", "JU.PT", "JU.Logger", "JV.Viewer"], function(){
+Clazz.load(null, "J.i18n.Resource", ["java.util.Hashtable", "JU.PT", "$.Rdr", "J.translation.PO", "JU.Logger", "JV.FileManager"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.resource = null;
 this.resourceMap = null;
@@ -11,14 +11,19 @@ if (className == null) this.resourceMap = resource;
 }, "~O,~S");
 c$.getResource = Clazz.defineMethod(c$, "getResource", 
 function(vwr, className, name){
-var poData = null;
-if (vwr != null && (JV.Viewer.isJS || vwr.isApplet)) {
-var fname = JV.Viewer.appletIdiomaBase + "/" + name + ".po";
-JU.Logger.info("Loading language resource " + fname);
-poData = vwr.getFileAsString3(fname, false, "gt");
+try {
+var br = JV.FileManager.getBufferedReaderForResource(vwr,  new J.translation.PO(), "J/translation/", (className.indexOf("Applet") >= 0 ? "JmolApplet/" : "Jmol/") + name + ".po");
+var data =  new Array(1);
+JU.Rdr.readAllAsString(br, 2147483647, false, data, 0);
+var poData = data[0];
+return J.i18n.Resource.getResourceFromPO(poData);
+} catch (e) {
+if (Clazz.exceptionOf(e,"java.io.IOException")){
+return null;
 } else {
-{
-}}return J.i18n.Resource.getResourceFromPO(poData);
+throw e;
+}
+}
 }, "JV.Viewer,~S,~S");
 Clazz.defineMethod(c$, "getString", 
 function(string){
@@ -79,4 +84,4 @@ if (line.indexOf("\\\"") >= 0) line = JU.PT.rep(line, "\\\"", "\"");
 return JU.PT.rep(line.substring(line.indexOf("\"") + 1, line.lastIndexOf("\"")), "\\n", "\n");
 }, "~S");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
