@@ -198,4 +198,4 @@ System.out.println("CifDensityReader checkSum=" + this.checkSum);
 Clazz.superCall(this, J.jvxl.readers.BCifDensityReader, "closeReader", []);
 });
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
