@@ -59,4 +59,4 @@ this.voxelData = null;
 if (this.dataMin > this.params.cutoff) this.params.cutoff = 2 * this.dataMin;
 }, "~B");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
