@@ -202,4 +202,4 @@ function(){
 return (this.isBinary ? this.binarydoc.readFloat() : this.parseFloatStr(this.nextToken()));
 });
 });
-;//5.0.1-v2 Fri Jan 26 13:48:25 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
