@@ -124,4 +124,4 @@ JU.Logger.info("PyMOLMeshReader rmsd=" + rmsd + " mean=" + mean);
 return this.params.sigma * rmsd + mean;
 });
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
