@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.modelkit");
-Clazz.load(["JU.Vibration", "JU.BS", "$.P3", "J.i18n.GT"], "J.modelkit.ModelKit", ["java.util.Arrays", "$.Hashtable", "JU.Lst", "$.Measure", "$.PT", "$.Quat", "$.SB", "$.V3", "JM.AtomCollection", "$.ModelSet", "JS.SV", "JU.BSUtil", "$.Edge", "$.Elements", "$.Escape", "$.Logger", "$.SimpleUnitCell", "JV.Viewer"], function(){
+Clazz.load(["JU.Vibration", "JU.BS", "$.P3", "J.i18n.GT"], "J.modelkit.ModelKit", ["java.util.Arrays", "$.Hashtable", "JU.Lst", "$.M4", "$.Measure", "$.PT", "$.Quat", "$.SB", "$.V3", "JM.ModelSet", "JS.SV", "JU.BSUtil", "$.Edge", "$.Elements", "$.Escape", "$.Logger", "$.SimpleUnitCell", "JV.Viewer"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.vwr = null;
 this.menu = null;
@@ -27,7 +27,6 @@ this.addXtalHydrogens = true;
 this.clickToSetElement = true;
 this.autoBond = false;
 this.centerPoint = null;
-this.spherePoint = null;
 this.pickAtomAssignType = "C";
 this.pickBondAssignType = 'p';
 this.viewOffset = null;
@@ -43,8 +42,6 @@ this.lastOffset = "0 0 0";
 this.a0 = null;
 this.a3 = null;
 this.constraint = null;
-this.xtalHoverLabel = null;
-this.atomIndexSphere = -1;
 this.atomConstraints = null;
 this.minBasisAtoms = null;
 this.modelSyms = null;
@@ -95,8 +92,8 @@ this.resetBondFields();
 this.allOperators = null;
 this.currentModelIndex = -999;
 this.iatom0 = 0;
-this.atomIndexSphere = this.centerAtomIndex = this.secondAtomIndex = -1;
-this.centerPoint = this.spherePoint = null;
+this.centerAtomIndex = this.secondAtomIndex = -1;
+this.centerPoint = null;
 this.symop = null;
 this.setDefaultState(0);
 });
@@ -226,7 +223,6 @@ this.setDefaultState(1);
 this.centerPoint = value;
 this.lastCenter = this.centerPoint.x + " " + this.centerPoint.y + " " + this.centerPoint.z;
 this.centerAtomIndex = (Clazz.instanceOf(this.centerPoint,"JM.Atom") ? (this.centerPoint).i : -1);
-this.atomIndexSphere = -1;
 this.secondAtomIndex = -1;
 this.processAtomClick(this.centerAtomIndex);
 return null;
@@ -315,13 +311,6 @@ if (!Double.isNaN(d)) {
 J.modelkit.ModelKit.notImplemented("setProperty: distance");
 this.centerDistance = d;
 }return Double.$valueOf(this.centerDistance);
-}if (key === "point") {
-if (value != null) {
-J.modelkit.ModelKit.notImplemented("setProperty: point");
-this.setDefaultState(2);
-this.spherePoint = value;
-this.atomIndexSphere = (Clazz.instanceOf(this.spherePoint,"JM.Atom") ? (this.spherePoint).i : -1);
-}return this.spherePoint;
 }if (key === "addconstraint") {
 J.modelkit.ModelKit.notImplemented("setProperty: addConstraint");
 return null;
@@ -595,7 +584,7 @@ this.bondHoverLabel = text;
 } else if (mode === "atomMenu") {
 this.atomHoverLabel = text;
 } else if (mode === "xtalMenu") {
-this.xtalHoverLabel = this.atomHoverLabel = text;
+this.atomHoverLabel = text;
 }}, "~S,~S");
 Clazz.defineMethod(c$, "getElementFromUser", 
 function(){
@@ -676,7 +665,7 @@ this.vwr.ms.makeConnections2(0.1, 1.8, 1, 1073741904, bsA, bs, null, false, fals
 return atomicNumber;
 }, "~N,~S,~B,~B,~B,JU.BS");
 Clazz.defineMethod(c$, "cmdAssignSpaceGroup", 
-function(bs, name, mi){
+function(bs, name){
 var isITA = name.startsWith("ITA/");
 if (isITA) {
 name = name.substring(4);
@@ -689,7 +678,7 @@ var isDefined = (name.length > 0);
 this.clearAtomConstraints();
 try {
 if (bs != null && bs.isEmpty()) return "";
-var bsAtoms = (mi < 0 ? this.vwr.getThisModelAtoms() : this.vwr.getModelUndeletedAtomsBitSet(mi));
+var bsAtoms = this.vwr.getThisModelAtoms();
 var bsCell = (isP1 ? bsAtoms : JS.SV.getBitSet(this.vwr.evaluateExpressionAsVariable("{within(unitcell)}"), true));
 if (bs == null) {
 bs = bsAtoms;
@@ -697,10 +686,10 @@ bs = bsAtoms;
 bsAtoms.and(bs);
 if (!isP1) bsAtoms.and(bsCell);
 }var noAtoms = bsAtoms.isEmpty();
-if (mi < 0) mi = (noAtoms && this.vwr.am.cmi < 0 ? 0 : noAtoms ? this.vwr.am.cmi : this.vwr.ms.at[bsAtoms.nextSetBit(0)].getModelIndex());
+var mi = (noAtoms && this.vwr.am.cmi < 0 ? 0 : noAtoms ? this.vwr.am.cmi : this.vwr.ms.at[bsAtoms.nextSetBit(0)].getModelIndex());
 this.vwr.ms.getModelAuxiliaryInfo(mi).remove("spaceGroupInfo");
 var sym = this.vwr.getOperativeSymmetry();
-if (sym == null) sym = this.vwr.getSymTemp().setUnitCell( Clazz.newFloatArray(-1, [10, 10, 10, 90, 90, 90]), false, NaN);
+if (sym == null) sym = this.vwr.getSymTemp().setUnitCellFromParams( Clazz.newFloatArray(-1, [10, 10, 10, 90, 90, 90]), false, NaN);
 var m = sym.getUnitCellMultiplier();
 if (m != null && m.z == 1) {
 m.z = 0;
@@ -709,7 +698,8 @@ var oabc;
 var ita;
 var basis;
 var sg = null;
-var sgInfo = (noAtoms && !isDefined ? null : this.vwr.findSpaceGroup(isDefined ? null : bsAtoms, isDefined ? (isITA ? "ITA/" + name : name) : null, sym.getUnitCellParams(), false, true));
+var origin = sym.getUnitCellVectors()[0];
+var sgInfo = (noAtoms && !isDefined ? null : this.vwr.findSpaceGroup(isDefined ? null : bsAtoms, isDefined ? (isITA ? "ITA/" + name : name) : null, sym.getUnitCellParams(), origin, false, true, false));
 if (sgInfo == null) {
 if (isITA) {
 return "No International Tables setting found!";
@@ -730,9 +720,9 @@ sym.setSpaceGroupTo(sg == null ? ita : sg);
 sym.setSpaceGroupName(name);
 if (basis == null) basis = sym.removeDuplicates(this.vwr.ms, bsAtoms, true);
 this.vwr.ms.setSpaceGroup(mi, sym, basis);
-var pt = JU.SimpleUnitCell.ptToIJK(supercell, 1);
-JM.ModelSet.setUnitCellOffset(sym, pt, 0);
-if (noAtoms) {
+if (supercell != null) {
+JM.ModelSet.setUnitCellOffset(sym, JU.SimpleUnitCell.ptToIJK(supercell, 1), 0);
+}if (noAtoms) {
 this.appRunScript("unitcell on; center unitcell;axes unitcell; axes on;set perspectivedepth false;moveto 0 axis c1;draw delete;show spacegroup");
 }return name + " basis=" + basis;
 } catch (e) {
@@ -743,7 +733,7 @@ return e.getMessage();
 throw e;
 }
 }
-}, "JU.BS,~S,~N");
+}, "JU.BS,~S");
 Clazz.defineMethod(c$, "cmdAssignDeleteAtoms", 
 function(bs){
 this.clearAtomConstraints();
@@ -1094,7 +1084,7 @@ bs.or(bsEquiv);
 var list = uc.getEquivPoints(null, p, packing);
 for (var j = 0, n = list.size(); j < n; j++) {
 for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
-if (this.vwr.ms.at[i].distanceSquared(list.get(j)) < 0.001) {
+if (this.vwr.ms.at[i].distanceSquared(list.get(j)) < 0.000001) {
 vConnections.addLast(this.vwr.ms.at[i]);
 bs.clear(i);
 }}
@@ -1317,11 +1307,11 @@ var site = 0;
 var pf = null;
 if (pts != null && pts.length == 1) {
 pf = JU.P3.newP(pts[0]);
-sym.toFractional(pf, true);
+sym.toFractional(pf, false);
 isPoint = true;
 }for (var i = bsM.nextSetBit(0); i >= 0; i = bsM.nextSetBit(i + 1)) {
 var p = JU.P3.newP(this.vwr.ms.at[i]);
-sym.toFractional(p, true);
+sym.toFractional(p, false);
 if (pf != null && pf.distanceSquared(p) < 1.96E-6) {
 site = this.vwr.ms.at[i].getAtomSite();
 if (type == null || pts == null) type = this.vwr.ms.at[i].getElementSymbolIso(true);
@@ -1383,34 +1373,79 @@ n += this.cmdAssignMoveAtoms(bs, bsFixed, bsModelAtoms, i, pts[ip++], null, true
 }
 return n;
 }var nAtoms = bsSelected.cardinality();
-if (bsSelected.intersects(bsFixed) || nAtoms > 1 && (this.constraint != null || sym.getSpaceGroupOperationCount() > 1)) {
+if (bsSelected.intersects(bsFixed)) {
 p.x = NaN;
 return 0;
-}if (nAtoms > 1) {
+}this.addOccupiedAtoms(bsSelected);
+nAtoms = bsSelected.cardinality();
+if (nAtoms == 1) {
+var bsMoved = this.moveConstrained(iatom, bsFixed, bsModelAtoms, p, true, allowProjection, null);
+return (bsMoved == null ? 0 : bsMoved.cardinality());
+}var p1 = JU.P3.newP(p);
+p.x = NaN;
+if (this.moveConstrained(iatom, bsFixed, bsModelAtoms, p1, false, true, null) == null) {
 return 0;
-}var bsOcc =  new JU.BS();
-var checkOcc = false;
-var a = this.vwr.ms.at[iatom];
-if (!checkOcc || this.vwr.ms.getOccupancyFloat(a.i) == 100) {
-bsOcc.set(a.i);
-} else {
-this.vwr.getAtomsNearPt(0.0001, a, bsOcc);
-for (var i = bsOcc.nextSetBit(0); i >= 0; i = bsOcc.nextSetBit(i + 1)) {
-if (this.vwr.ms.getOccupancyFloat(i) == 100) bsOcc.clear(i);
+}var pd = JU.P3.newP(p1);
+pd.sub(this.vwr.ms.at[iatom]);
+var maxSite = 0;
+for (var i = bsSelected.nextSetBit(0); i >= 0; i = bsSelected.nextSetBit(i + 1)) {
+var s = this.vwr.ms.at[i].getAtomSite();
+if (s > maxSite) maxSite = s;
 }
-}var isOccSet = (bsOcc.cardinality() > 1);
-if ((n = this.moveConstrained(iatom, bsFixed, bsModelAtoms, p, !isOccSet, allowProjection)) == 0 || Float.isNaN(p.x) || !isOccSet) {
-this.vwr.setStatusAtomMoved(false, bsOcc);
-return n;
-}for (var i = bsOcc.nextSetBit(0); i >= 0; i = bsOcc.nextSetBit(i + 1)) {
-iatom = (this.constraint == null ? this.getBasisAtom(i).i : i);
-n += this.assignMoveAtom(iatom, p, bsFixed, bsModelAtoms);
-}
-this.vwr.setStatusAtomMoved(true, bsOcc);
-return n;
+var sites =  Clazz.newIntArray (maxSite, 0);
+pts =  new Array(maxSite);
+var apos0 = this.vwr.ms.saveAtomPositions();
+var apos =  new Array(bsSelected.cardinality());
+var bsMoved =  new JU.BS();
+for (var ip = 0, i = bsSelected.nextSetBit(0); i >= 0; i = bsSelected.nextSetBit(i + 1), ip++) {
+p1.setT(this.vwr.ms.at[i]);
+p1.add(pd);
+apos[ip] = JU.P3.newP(p1);
+var s = this.vwr.ms.at[i].getAtomSite() - 1;
+if (sites[s] == 0) {
+if (this.moveConstrained(i, bsFixed, bsModelAtoms, p1, false, true, bsMoved) == null) {
+return 0;
+}p1.sub(this.vwr.ms.at[i]);
+p1.sub(pd);
+pts[s] = JU.P3.newP(p1);
+sites[s] = i + 1;
+}}
+bsMoved.clearAll();
+for (var i = sites.length; --i >= 0; ) {
+var ia = sites[i] - 1;
+if (ia >= 0) {
+p1.setT(this.vwr.ms.at[ia]);
+p1.add(pd);
+if (this.moveConstrained(ia, bsFixed, bsModelAtoms, p1, true, true, bsMoved) == null) {
+bsMoved = null;
+break;
+}}}
+n = (bsMoved == null ? 0 : bsMoved.cardinality());
+if (n == 0) {
+this.vwr.ms.restoreAtomPositions(apos0);
+return 0;
+}return (this.checkAtomPositions(apos0, apos, bsSelected) ? n : 0);
 }, "JU.BS,JU.BS,JU.BS,~N,JU.P3,~A,~B");
+Clazz.defineMethod(c$, "addOccupiedAtoms", 
+function(bsSelected){
+var bs =  new JU.BS();
+for (var iatom = bsSelected.nextSetBit(0); iatom >= 0; iatom = bsSelected.nextSetBit(iatom + 1)) {
+var a = this.vwr.ms.at[iatom];
+if (this.vwr.ms.getOccupancyFloat(a.i) == 100) {
+bsSelected.set(a.i);
+} else {
+bs.clearAll();
+this.vwr.ms.getAtomsWithin(0.0001, a, bs, a.mi);
+for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
+if (this.vwr.ms.getOccupancyFloat(i) == 100) {
+bs.clear(i);
+bsSelected.clear(i);
+}}
+bsSelected.or(bs);
+}}
+}, "JU.BS");
 Clazz.defineMethod(c$, "assignMoveAtom", 
-function(iatom, pt, bsFixed, bsModelAtoms){
+function(iatom, pt, bsFixed, bsModelAtoms, bsMoved){
 if (Float.isNaN(pt.x) || iatom < 0) return 0;
 var bs = JU.BSUtil.newAndSetBit(iatom);
 if (bsModelAtoms == null) bsModelAtoms = this.vwr.getThisModelAtoms();
@@ -1436,7 +1471,8 @@ var points =  new Array(n);
 var ia0 = bseq.nextSetBit(0);
 if (!this.fillPointsForMove(sym, bseq, ia0, a, pt, points)) {
 return 0;
-}var mi = this.vwr.ms.at[ia0].mi;
+}bsMoved.or(bseq);
+var mi = this.vwr.ms.at[ia0].mi;
 this.vwr.sm.setStatusStructureModified(ia0, mi, 3, "dragatom", n, bseq);
 for (var k = 0, ia = bseq.nextSetBit(0); ia >= 0; ia = bseq.nextSetBit(ia + 1)) {
 var p = points[k++];
@@ -1454,7 +1490,7 @@ throw e;
 } finally {
 this.setMKState(state);
 }
-}, "~N,JU.P3,JU.BS,JU.BS");
+}, "~N,JU.P3,JU.BS,JU.BS,JU.BS");
 Clazz.defineMethod(c$, "getSym", 
 function(iatom){
 var modelIndex = this.vwr.ms.at[iatom].mi;
@@ -1471,27 +1507,26 @@ function(sg, bseq, i0, a, pt, points){
 var d = a.distance(pt);
 var fa = JU.P3.newP(a);
 var fb = JU.P3.newP(pt);
-sg.toFractional(fa, true);
-sg.toFractional(fb, true);
+sg.toFractional(fa, false);
+sg.toFractional(fb, false);
 for (var k = 0, i = i0; i >= 0; i = bseq.nextSetBit(i + 1)) {
 var p = JU.P3.newP(this.vwr.ms.at[i]);
 var p0 = JU.P3.newP(p);
-sg.toFractional(p, true);
-System.out.println(fa + " " + p);
+sg.toFractional(p, false);
 var m = sg.getTransform(fa, p, false);
 if (m == null) {
 return false;
 }var p2 = JU.P3.newP(fb);
 m.rotTrans(p2);
-sg.toCartesian(p2, true);
+sg.toCartesian(p2, false);
 if (Math.abs(d - p0.distance(p2)) > 0.001) return false;
 points[k++] = p2;
 }
 fa.setT(points[0]);
-sg.toFractional(fa, true);
+sg.toFractional(fa, false);
 for (var k = points.length; --k >= 0; ) {
 fb.setT(points[k]);
-sg.toFractional(fb, true);
+sg.toFractional(fb, false);
 var m = sg.getTransform(fa, fb, false);
 if (m == null) {
 return false;
@@ -1527,16 +1562,18 @@ return (c != null && (!ignoreGeneral || c.type != 7));
 }, "~N,~B,~B");
 Clazz.defineMethod(c$, "moveMinConstrained", 
 function(iatom, p, bsAtoms){
-return this.moveConstrained(iatom, null, bsAtoms, p, true, true);
+var bsMoved = this.moveConstrained(iatom, null, bsAtoms, p, true, true, null);
+return (bsMoved == null ? 0 : bsMoved.cardinality());
 }, "~N,JU.P3,JU.BS");
 Clazz.defineMethod(c$, "moveConstrained", 
-function(iatom, bsFixed, bsModelAtoms, ptNew, doAssign, allowProjection){
-var n = 0;
+function(iatom, bsFixed, bsModelAtoms, ptNew, doAssign, allowProjection, bsMoved){
 var sym = this.getSym(iatom);
 if (sym == null) {
-return 0;
-}var a = this.vwr.ms.at[iatom];
+return null;
+}if (bsMoved == null) bsMoved = JU.BSUtil.newAndSetBit(iatom);
+var a = this.vwr.ms.at[iatom];
 var c = this.constraint;
+var minv = null;
 if (c == null) {
 c = this.setConstraint(sym, iatom, J.modelkit.ModelKit.GET_CREATE);
 if (c.type == 6) {
@@ -1549,27 +1586,37 @@ if (m == null) {
 System.err.println("ModelKit - null matrix for " + iatom + " " + a + " to " + b);
 iatom = -1;
 } else {
-iatom = b.i;
+if (!doAssign) {
+minv = JU.M4.newM4(m);
+minv.invert();
+}iatom = b.i;
 var p = JU.P3.newP(ptNew);
-sym.toFractional(p, true);
+sym.toFractional(p, false);
 m.rotTrans(p);
-sym.toCartesian(p, true);
-ptNew.set(p.x, p.y, p.z);
+sym.toCartesian(p, false);
+ptNew.setT(p);
 }}if (iatom >= 0) c.constrain(b, ptNew, allowProjection);
 }} else {
 c.constrain(a, ptNew, allowProjection);
-}if (iatom >= 0 && !Float.isNaN(ptNew.x)) {
-if (!doAssign) return 1;
-n = this.assignMoveAtom(iatom, ptNew, bsFixed, bsModelAtoms);
+}if (iatom >= 0 && !Double.isNaN(ptNew.x)) {
+if (!doAssign) {
+if (minv != null) {
+var p = JU.P3.newP(ptNew);
+sym.toFractional(p, false);
+minv.rotTrans(p);
+sym.toCartesian(p, false);
+ptNew.setP(p);
+}return bsMoved;
+}if (this.assignMoveAtom(iatom, ptNew, bsFixed, bsModelAtoms, bsMoved) == 0) bsMoved = null;
 }ptNew.x = NaN;
-return n;
-}, "~N,JU.BS,JU.BS,JU.P3,~B,~B");
+return bsMoved;
+}, "~N,JU.BS,JU.BS,JU.P3,~B,~B,JU.BS");
 c$.getTransform = Clazz.defineMethod(c$, "getTransform", 
 function(sym, a, b){
 var fa = JU.P3.newP(a);
-sym.toFractional(fa, true);
+sym.toFractional(fa, false);
 var fb = JU.P3.newP(b);
-sym.toFractional(fb, true);
+sym.toFractional(fb, false);
 return sym.getTransform(fa, fb, true);
 }, "J.api.SymmetryInterface,JM.Atom,JM.Atom");
 Clazz.defineMethod(c$, "setConstraint", 
@@ -1650,7 +1697,7 @@ var p =  new JU.P3();
 var i0 = bsAtoms.nextSetBit(0);
 var sg = this.getSym(i0);
 var bsAU =  new JU.BS();
-var bsAtoms2 =  new JU.BS();
+var bsToMove =  new JU.BS();
 for (var i = i0; i >= 0; i = bsAtoms.nextSetBit(i + 1)) {
 var bai = this.getBasisAtom(i).i;
 if (bsAU.get(bai)) {
@@ -1658,14 +1705,10 @@ continue;
 }if (this.setConstraint(sg, bai, J.modelkit.ModelKit.GET_CREATE).type == 6) {
 return 0;
 }bsAU.set(bai);
-bsAtoms2.set(i);
+bsToMove.set(i);
 }
 var nAtoms = bsAtoms.cardinality();
-var apos0 =  new Array(this.vwr.ms.at.length);
-for (var i = apos0.length; --i >= 0; ) {
-var a = this.vwr.ms.at[i];
-if (!JM.AtomCollection.isDeleted(a)) apos0[i] = JU.P3.newP(a);
-}
+var apos0 = this.vwr.ms.saveAtomPositions();
 var m = JU.Quat.newVA(JU.V3.newVsub(points[1], points[0]), endDegrees).getMatrix();
 var vt =  new JU.V3();
 var apos =  new Array(nAtoms);
@@ -1681,25 +1724,26 @@ if (Double.isNaN(p.x)) return 0;
 nAtoms = 0;
 var bsFixed = this.vwr.getMotionFixedAtoms(i0);
 var bsModelAtoms = this.vwr.getModelUndeletedAtomsBitSet(this.vwr.ms.at[i0].mi);
-for (var ip = 0, i = i0; i >= 0; i = bsAtoms2.nextSetBit(i + 1), ip++) {
-if (bsAtoms2.get(i)) {
-nAtoms += this.assignMoveAtom(i, apos[ip], bsFixed, bsModelAtoms);
-}}
+var bsMoved =  new JU.BS();
+for (var ip = 0, i = i0; i >= 0; i = bsToMove.nextSetBit(i + 1), ip++) {
+nAtoms += this.assignMoveAtom(i, apos[ip], bsFixed, bsModelAtoms, bsMoved);
+}
+var bs = JU.BSUtil.copy(bsAtoms);
+bs.andNot(bsToMove);
+return (this.checkAtomPositions(apos0, apos, bs) ? nAtoms : 0);
+}, "JU.BS,~A,~N");
+Clazz.defineMethod(c$, "checkAtomPositions", 
+function(apos0, apos, bs){
 var ok = true;
-for (var ip = 0, i = bsAtoms.nextSetBit(0); i >= 0; i = bsAtoms.nextSetBit(i + 1), ip++) {
-if (!bsAtoms2.get(i)) {
-if (this.vwr.ms.at[i].distance(apos[ip]) > 0.0001) {
+for (var ip = 0, i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1), ip++) {
+if (this.vwr.ms.at[i].distanceSquared(apos[ip]) > 0.00000001) {
 ok = false;
 break;
-}}}
-if (!ok) {
-for (var i = apos0.length; --i >= 0; ) {
-var a = this.vwr.ms.at[i];
-if (!JM.AtomCollection.isDeleted(a)) a.setT(apos0[i]);
-}
-return 0;
-}return nAtoms;
-}, "JU.BS,~A,~N");
+}}
+if (ok) return true;
+this.vwr.ms.restoreAtomPositions(apos0);
+return false;
+}, "~A,~A,JU.BS");
 c$.getText = Clazz.defineMethod(c$, "getText", 
 function(key){
 switch (("invSter delAtom dragBon dragAto dragMin dragMol dragMMo incChar decChar rotBond bondTo0 bondTo1 bondTo2 bondTo3 incBond decBond").indexOf(key.substring(0, 7))) {
@@ -1802,6 +1846,43 @@ this.vwr.deleteModels(this.vwr.ms.mc - 1, null);
 this.vwr.setSelectionSet(this.minSelectionSaved);
 this.vwr.setCurrentModelIndex(this.minBasisModel);
 });
+Clazz.defineMethod(c$, "checkMovedAtoms", 
+function(bsFixed, bsAtoms, apos0){
+var i0 = bsAtoms.nextSetBit(0);
+var n = bsAtoms.cardinality();
+var apos =  new Array(n);
+try {
+var atoms = this.vwr.ms.at;
+for (var ip = 0, i = i0; i >= 0; i = bsAtoms.nextSetBit(i + 1)) {
+apos[ip++] = JU.P3.newP(atoms[i]);
+atoms[i].setT(apos0[i]);
+}
+var maxSite = 0;
+for (var i = i0; i >= 0; i = bsAtoms.nextSetBit(i + 1)) {
+var s = this.vwr.ms.at[i].getAtomSite();
+if (s > maxSite) maxSite = s;
+}
+var sites =  Clazz.newIntArray (maxSite, 0);
+var p1 =  new JU.P3();
+var bsModelAtoms = this.vwr.getModelUndeletedAtomsBitSet(this.vwr.ms.at[i0].mi);
+var bsMoved =  new JU.BS();
+for (var ip = 0, i = i0; i >= 0; i = bsAtoms.nextSetBit(i + 1), ip++) {
+p1.setT(apos[ip]);
+var s = this.vwr.ms.at[i].getAtomSite() - 1;
+if (sites[s] == 0) {
+sites[s] = i + 1;
+bsMoved = this.moveConstrained(i, bsFixed, bsModelAtoms, p1, true, false, bsMoved);
+if (bsMoved == null) {
+n = 0;
+break;
+}}}
+return (n != 0 && this.checkAtomPositions(apos0, apos, bsAtoms) ? n : 0);
+} finally {
+if (n == 0) {
+this.vwr.ms.restoreAtomPositions(apos0);
+bsAtoms.clearAll();
+}}
+}, "JU.BS,JU.BS,~A");
 /*if3*/;(function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.oldVib = null;
@@ -1888,8 +1969,6 @@ this.pt = null;
 this.offset = null;
 this.plane = null;
 this.unitVector = null;
-this.points = null;
-this.value = 0;
 Clazz.instantialize(this, arguments);}, J.modelkit.ModelKit, "Constraint", null);
 Clazz.makeConstructor(c$, 
 function(pt, type, params){
@@ -1908,18 +1987,6 @@ break;
 case 5:
 this.plane = params[0];
 break;
-case 1:
-this.value = (params[0]).doubleValue();
-this.points =  Clazz.newArray(-1, [params[1], null]);
-break;
-case 2:
-this.value = (params[0]).doubleValue();
-this.points =  Clazz.newArray(-1, [params[1], params[2], null]);
-break;
-case 3:
-this.value = (params[0]).doubleValue();
-this.points =  Clazz.newArray(-1, [params[1], params[2], params[3], null]);
-break;
 default:
 throw  new IllegalArgumentException();
 }
@@ -1965,4 +2032,4 @@ c$.GET = 0;
 c$.GET_CREATE = 1;
 c$.GET_DELETE = 2;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
