@@ -647,4 +647,4 @@ c$.nf = java.text.NumberFormat.getInstance();
 J.quantum.NMRNoeMatrix.nf.setMinimumFractionDigits(4);
 J.quantum.NMRNoeMatrix.nf.setMaximumFractionDigits(4);
 }});
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
