@@ -2,4 +2,4 @@ Clazz.declarePackage("J.quantum");
 Clazz.load(["J.quantum.QuantumCalculation"], "J.quantum.QuantumPlaneCalculation", null, function(){
 var c$ = Clazz.declareType(J.quantum, "QuantumPlaneCalculation", J.quantum.QuantumCalculation);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
