@@ -106,4 +106,4 @@ g3d.drawRect(x + 3, y + 3, z - 1, zSlab, boxWidth - 6, boxHeight - 6);
 g3d.drawRect(x + 1, y + 1, z - 1, zSlab, boxWidth - 2, boxHeight - 2);
 }}, "J.api.JmolRendererInterface,~N,~N,~N,~N,~N,~N,~N,~N,~B");
 });
-;//5.0.1-v2 Mon Jan 22 14:59:02 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:43:24 CST 2024
