@@ -23,4 +23,4 @@ if (!checkPass2 || this.setBioColix(cA) || this.setBioColix(cB)) this.drawSegmen
 }}
 }, "J.shapebio.BioShape");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
