@@ -324,4 +324,4 @@ var width = Clazz.floatToInt(this.isExport ? mad : this.vwr.tm.scaleToScreen(Cla
 this.g3d.fillCylinderXYZ(colixA, colixB, 3, width, xA, yA, zA, xB, yB, zB);
 }}, "JM.Atom,JM.Atom,~N,~N,~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
