@@ -55,4 +55,4 @@ this.g3d.fillTriangle3CNBits(this.facePt1, this.colix, p1, this.facePt2, this.co
 }
 }, "JU.BS");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
