@@ -2,4 +2,4 @@ Clazz.declarePackage("J.rendersurface");
 Clazz.load(["J.rendersurface.IsosurfaceRenderer"], "J.rendersurface.LcaoCartoonRenderer", null, function(){
 var c$ = Clazz.declareType(J.rendersurface, "LcaoCartoonRenderer", J.rendersurface.IsosurfaceRenderer);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
