@@ -92,9 +92,10 @@ t.pointerPt = (value == null ? null : value);
 t.pointer = (value == null ? 0 : 1);
 }return;
 }if ("xyz" === propertyName) {
-if (this.currentObject != null && this.vwr.getBoolean(603979845)) {
+if (this.currentObject != null) {
+if (this.vwr.getBoolean(603979845)) {
 this.currentObject.setScalePixelsPerMicron(this.vwr.getScalePixelsPerAngstrom(false) * 10000);
-this.currentObject.setXYZ(value, true);
+}this.currentObject.setXYZ(value, true);
 }}if ("scale" === propertyName) {
 if (this.currentObject != null) {
 (this.currentObject).setScale((value).floatValue());
@@ -207,4 +208,4 @@ lst2.addLast(lst);
 return lst2;
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 05:22:14 CST 2024
