@@ -74,6 +74,10 @@ this.currentMesh = null;
 }, "J.shape.MeshCollection");
 Clazz.overrideMethod(c$, "initShape", 
 function(){
+this.setMeshColor();
+});
+Clazz.defineMethod(c$, "setMeshColor", 
+function(){
 this.colix = 5;
 this.color = 0xFFFFFFFF;
 });
@@ -464,4 +468,4 @@ map.put("type", this.myType);
 }return map;
 }, "JU.T3,~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
