@@ -56,12 +56,7 @@ function(rd, bsSelected){
 Clazz.defineMethod(c$, "setPropS", 
 function(propertyName, value, bsSelected){
 if (propertyName === "setProperties") {
-if (bsSelected == null) bsSelected = this.vwr.bsA();
-var propertyList = value;
-while (propertyList.size() > 0) {
-var data = propertyList.removeItemAt(0);
-this.setProperty((data[0]).intern(), data[1], bsSelected);
-}
+this.setProperties(value);
 return;
 }if (propertyName === "translucentLevel") {
 this.translucentLevel = (value).floatValue();
@@ -169,5 +164,20 @@ function(s, cmd){
 if (cmd.length == 0) return;
 s.append("  ").append(cmd).append(";\n");
 }, "JU.SB,~S");
+Clazz.defineMethod(c$, "setProperties", 
+function(value){
+var bsSelected = this.vwr.bsA();
+if (Clazz.instanceOf(value,"JU.Lst")) {
+var propertyList = value;
+while (propertyList.size() > 0) {
+var data = propertyList.removeItemAt(0);
+this.setProperty((data[0]).intern(), data[1], bsSelected);
+}
+} else {
+var data = (value);
+for (var i = 0, n = data.length; i < n; i++) {
+this.setProperty((data[i][0]).intern(), data[i][1], bsSelected);
+}
+}}, "~O");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 05:22:14 CST 2024
