@@ -1,10 +1,10 @@
 Clazz.declarePackage("J.shapebio");
 Clazz.load(["J.shapebio.Rockets"], "J.shapebio.Cartoon", null, function(){
 var c$ = Clazz.declareType(J.shapebio, "Cartoon", J.shapebio.Rockets);
-Clazz.defineMethod(c$, "initShape", 
+Clazz.overrideMethod(c$, "initShape", 
 function(){
-Clazz.superCall(this, J.shapebio.Cartoon, "initShape", []);
+this.setTurn();
 this.madDnaRna = 1000;
 });
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
