@@ -2,4 +2,4 @@ Clazz.declarePackage("J.shapebio");
 Clazz.load(["J.shapebio.BioShapeCollection"], "J.shapebio.Ribbons", null, function(){
 var c$ = Clazz.declareType(J.shapebio, "Ribbons", J.shapebio.BioShapeCollection);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
