@@ -4,4 +4,4 @@ var c$ = Clazz.decorateAsClass(function(){
 this.isMesh = false;
 Clazz.instantialize(this, arguments);}, J.shapebio, "Strands", J.shapebio.BioShapeCollection);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
