@@ -75,9 +75,9 @@ this.currentMesh = this.thisMesh;
 this.setPropMC(propertyName, value, bs);
 this.thisMesh = this.currentMesh;
 }, "~S,~O,JU.BS");
-Clazz.defineMethod(c$, "initShape", 
+Clazz.overrideMethod(c$, "initShape", 
 function(){
-Clazz.superCall(this, J.shapespecial.Draw, "initShape", []);
+this.setMeshColor();
 this.myType = "draw";
 });
 Clazz.overrideMethod(c$, "setProperty", 
@@ -1248,4 +1248,4 @@ Clazz.defineEnumConstant(c$, "LINE_SEGMENT", 11, [20, "lineSegment"]);
 Clazz.defineEnumConstant(c$, "POLYGON", 12, [21, "polygon"]);
 /*eoif2*/})();
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
