@@ -76,7 +76,9 @@ return;
 if (!this.iHaveCenterBitSet && bs != null && !bs.isEmpty()) {
 this.centers = bs;
 this.iHaveCenterBitSet = true;
-}this.deletePolyhedra();
+}var info = this.info;
+this.deletePolyhedra();
+this.info = info;
 this.buildPolyhedra();
 return;
 }if ("thisID" === propertyName) {
@@ -142,6 +144,8 @@ this.bondedOnly = true;
 return;
 }if ("info" === propertyName) {
 this.info = value;
+var o = this.info.get("id");
+if (o != null) this.thisID = (Clazz.instanceOf(o,"JS.SV") ? (o).asString() : o.toString());
 this.centers = (this.info.containsKey("center") ? null : JU.BSUtil.newAndSetBit((this.info.get("atomIndex")).intValue));
 this.iHaveCenterBitSet = (this.centers != null);
 return;
@@ -176,7 +180,7 @@ var cvalue = (isPhase ? (value)[1] : value);
 var colixEdge = (isPhase ? JU.C.getColix(((value)[0]).intValue()) : 0);
 var colix = JU.C.getColixO(isPhase ? cvalue : value);
 var p;
-var bs1 = this.findPolyBS(bs);
+var bs1 = this.findPolyBS(bs, false);
 for (var i = bs1.nextSetBit(0); i >= 0; i = bs1.nextSetBit(i + 1)) {
 p = this.polyhedrons[i];
 if (p.id == null) {
@@ -191,7 +195,7 @@ propertyName = "color";
 }if (propertyName.indexOf("translucency") == 0) {
 var isTranslucent = (value.equals("translucent"));
 if (this.thisID != null) {
-var bs1 = this.findPolyBS(bs);
+var bs1 = this.findPolyBS(bs, false);
 var p;
 for (var i = bs1.nextSetBit(0); i >= 0; i = bs1.nextSetBit(i + 1)) {
 p = this.polyhedrons[i];
@@ -270,19 +274,19 @@ this.center.scale(1 / n);
 }, "~A,~A");
 Clazz.defineMethod(c$, "pointsPolyhedra", 
 function(bs, pointScale){
-bs = this.findPolyBS(this.thisID == null ? bs : null);
+bs = this.findPolyBS(this.thisID == null ? bs : null, false);
 for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) this.polyhedrons[i].pointScale = pointScale;
 
 }, "JU.BS,~N");
 Clazz.defineMethod(c$, "scalePolyhedra", 
 function(scale){
-var bs = this.findPolyBS(null);
+var bs = this.findPolyBS(null, false);
 for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) this.polyhedrons[i].scale = scale;
 
 }, "~N");
 Clazz.defineMethod(c$, "offsetPolyhedra", 
 function(value){
-var bs = this.findPolyBS(null);
+var bs = this.findPolyBS(null, false);
 for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) this.polyhedrons[i].setOffset(JU.P3.newP(value));
 
 }, "JU.P3");
@@ -294,7 +298,14 @@ return -1;
 }, "~S");
 Clazz.overrideMethod(c$, "getProperty", 
 function(property, i){
-var info = this.polyhedrons[i].getInfo(this.vwr, property);
+if ("list".equals(property)) {
+var sb =  new JU.SB();
+for (i = 0; i < this.polyhedronCount; i++) {
+sb.appendI(i + 1);
+this.polyhedrons[i].list(sb);
+}
+return sb.toString();
+}var info = this.polyhedrons[i].getInfo(this.vwr, property);
 return (property.equalsIgnoreCase("info") ? info : info.get(property));
 }, "~S,~N");
 Clazz.overrideMethod(c$, "getPropertyData", 
@@ -309,23 +320,23 @@ return (i >= 0);
 }if (property === "checkID") {
 return this.checkID(id);
 }if (property === "getAtomsWithin") {
-p = this.findPoly(id, iatom, true);
+p = this.findPoly(id, iatom, true, false);
 if (p == null) return false;
 data[2] = this.getAtomsWithin(p, (data[1]).floatValue());
 return true;
 }if (property === "info") {
-p = this.findPoly(id, iatom, true);
+p = this.findPoly(id, iatom, true, false);
 if (p == null) return false;
 data[1] = p.getInfo(this.vwr, "info");
 return true;
 }if (property === "syminfo") {
-p = this.findPoly(id, iatom, true);
+p = this.findPoly(id, iatom, true, false);
 if (p == null) return false;
 p.getSymmetry(this.vwr, true);
 data[1] = p.getInfo(this.vwr, "info");
 return true;
 }if (property === "points") {
-p = this.findPoly(id, iatom, false);
+p = this.findPoly(id, iatom, false, false);
 if (p == null) return false;
 data[1] = p.vertices;
 return true;
@@ -343,7 +354,7 @@ return true;
 var mat = data[1];
 if (mat == null) return false;
 var bsMoved = data[0];
-var bs = this.findPolyBS(bsMoved);
+var bs = this.findPolyBS(bsMoved, false);
 for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) this.polyhedrons[i].move(mat, bsMoved);
 
 return true;
@@ -404,7 +415,8 @@ for (var i = p.nVertices; --i >= 0; ) {
 var d = vertices[i].distance(center);
 if (d > maxDistance) maxDistance = d;
 }
-var bsAtoms = JU.BSUtil.copy(this.vwr.getAtomsNearPt(maxDistance + offset, center, null));
+var bsAtoms =  new JU.BS();
+this.vwr.ms.getAtomsWithin(maxDistance + offset, center, bsAtoms, p.modelIndex);
 var atoms = this.ms.at;
 for (var i = bsAtoms.nextSetBit(0); i >= 0; i = bsAtoms.nextSetBit(i + 1)) {
 for (var f = faces.length; --f >= 0; ) {
@@ -418,27 +430,35 @@ return bsAtoms;
 Clazz.defineMethod(c$, "checkID", 
 function(thisID){
 this.thisID = thisID;
-return (!this.findPolyBS(null).isEmpty());
+return (!this.findPolyBS(null, false).isEmpty());
 }, "~S");
 Clazz.defineMethod(c$, "findPoly", 
-function(id, iatom, allowCollapsed){
+function(id, iatom, allowCollapsed, andDelete){
 for (var i = this.polyhedronCount; --i >= 0; ) {
 var p = this.polyhedrons[i];
-if (p.id == null ? p.centralAtom.i == iatom : p.id.equalsIgnoreCase(id)) return (allowCollapsed || !this.polyhedrons[i].collapsed ? this.polyhedrons[i] : null);
-}
+if (p.id == null ? p.centralAtom.i == iatom : p.id.equalsIgnoreCase(id)) {
+if (andDelete) {
+this.polyhedronCount--;
+for (; i < this.polyhedronCount; i++) this.polyhedrons[i] = this.polyhedrons[i + 1];
+
+}return (allowCollapsed || !this.polyhedrons[i].collapsed ? this.polyhedrons[i] : null);
+}}
 return null;
-}, "~S,~N,~B");
+}, "~S,~N,~B,~B");
 Clazz.defineMethod(c$, "findPolyBS", 
-function(bsCenters){
+function(bsCenters, isAll){
 var bs = this.bsPolys;
 bs.clearAll();
+if (isAll) {
+bs.setBits(0, this.polyhedronCount);
+} else {
 var p;
 for (var i = this.polyhedronCount; --i >= 0; ) {
 p = this.polyhedrons[i];
 if (p.id == null ? bsCenters != null && bsCenters.get(p.centralAtom.i) : this.isMatch(p.id)) bs.set(i);
 }
-return bs;
-}, "JU.BS");
+}return bs;
+}, "JU.BS,~B");
 Clazz.defineMethod(c$, "isMatch", 
 function(id){
 return this.thisID != null && JU.PT.isMatch(id.toLowerCase(), this.thisID.toLowerCase(), true, true);
@@ -464,7 +484,7 @@ Clazz.defineMethod(c$, "deletePolyhedra",
 function(){
 var newCount = 0;
 var pid = J.c.PAL.pidOf(null);
-var bs = this.findPolyBS(this.centers);
+var bs = this.findPolyBS(this.centers, false);
 for (var i = 0; i < this.polyhedronCount; ++i) {
 var p = this.polyhedrons[i];
 if (bs.get(i)) {
@@ -478,7 +498,7 @@ this.polyhedronCount = newCount;
 });
 Clazz.defineMethod(c$, "setVisible", 
 function(visible){
-var bs = this.findPolyBS(this.centers);
+var bs = this.findPolyBS(this.centers, false);
 var atoms = this.ms.at;
 for (var i = bs.nextSetBit(0); i >= 0; i = bs.nextSetBit(i + 1)) {
 var p = this.polyhedrons[i];
@@ -489,17 +509,15 @@ if (p.centralAtom != null) atoms[p.centralAtom.i].setShapeVisibility(this.vf, vi
 Clazz.defineMethod(c$, "buildPolyhedra", 
 function(){
 var p = null;
-if (this.centers == null) return;
-if (this.thisID != null) {
+if (this.info == null && this.centers == null && (this.center == null || this.nPoints == 0)) return;
+if (this.info != null && this.info.containsKey("id")) {
+p =  new J.shapespecial.Polyhedron().setInfo(this.vwr, this.info, this.ms.at);
+} else if (this.thisID != null) {
 if (JU.PT.isWild(this.thisID)) return;
 if (this.center != null) {
 if (this.nPoints == 0) this.setPointsFromBitset();
 p = this.validatePolyhedron(this.center, this.nPoints);
-}} else if (this.info != null && this.info.containsKey("id")) {
-var o = this.info.get("id");
-this.thisID = (Clazz.instanceOf(o,"JS.SV") ? (o).asString() : o.toString());
-p =  new J.shapespecial.Polyhedron().setInfo(this.vwr, this.info, this.ms.at);
-}if (p != null) {
+}}if (p != null) {
 this.addPolyhedron(p);
 return;
 }var useBondAlgorithm = (this.radius == 0 || this.bondedOnly);
@@ -964,4 +982,4 @@ return s.toString();
 c$.randomPoint = JU.P3.new3(3141, 2718, 1414);
 c$.MAX_DISTANCE_TO_PLANE = 0.1;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
