@@ -1,5 +1,5 @@
 Clazz.declarePackage("J.shapespecial");
-Clazz.load(null, "J.shapespecial.Polyhedron", ["java.util.Hashtable", "JU.AU", "$.BS", "$.Lst", "$.Measure", "$.P3", "$.V3", "J.api.Interface", "JS.SV", "JU.C", "$.Elements", "$.Escape", "$.Logger", "$.Normix", "$.Point3fi"], function(){
+Clazz.load(null, "J.shapespecial.Polyhedron", ["java.util.Hashtable", "JU.AU", "$.BS", "$.Lst", "$.Measure", "$.P3", "$.PT", "$.V3", "J.api.Interface", "JS.SV", "JU.C", "$.Elements", "$.Escape", "$.Logger", "$.Normix", "$.Point3fi"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.info = null;
 this.id = null;
@@ -33,6 +33,7 @@ this.scale = 1;
 this.pointScale = 0;
 this.faceTriangles = null;
 this.elemNos = null;
+this.v0 = null;
 Clazz.instantialize(this, arguments);}, J.shapespecial, "Polyhedron", null);
 /*LV!1824 unnec constructor*/Clazz.defineMethod(c$, "set", 
 function(id, modelIndex, atomOrPt, points, nPoints, vertexCount, triangles, triangleCount, faces, faceTriangles, normals, bsFlat, collapsed, distanceRef, pointScale){
@@ -105,6 +106,8 @@ needTriangles = true;
 o = lst.get(i);
 this.vertices[i] = (isSV ? JS.SV.ptValue(o) : o);
 }
+o = info.get("explodeOffset");
+if (o != null) this.setZeroOffset((o).floatValue());
 o = info.get("elemNos");
 if (o != null) {
 lst = (isSV ? (o).getList() : o);
@@ -139,6 +142,7 @@ JU.Measure.getNormalThroughPoints(this.vertices[a[0]], this.vertices[a[1]], this
 }
 o = info.get("bsFlat");
 this.bsFlat = (o == null ?  new JU.BS() : isSV ? JS.SV.getBitSet(o, false) : o);
+if (info.containsKey("volume")) info.put("volume", this.getVolume());
 } catch (e) {
 if (Clazz.exceptionOf(e, Exception)){
 return null;
@@ -360,5 +364,27 @@ this.offset = v;
 for (var i = this.vertices.length; --i >= 0; ) this.vertices[i].add(value);
 
 }, "JU.P3");
+Clazz.defineMethod(c$, "setZeroOffset", 
+function(value){
+if (this.id == null || this.center == null || value == 0) return;
+var d = this.center.length();
+if (d < 0.0001) return;
+var v = JU.P3.newP(this.center);
+v.scale(value / d);
+this.setOffset(v);
+}, "~N");
+Clazz.defineMethod(c$, "list", 
+function(sb){
+if (this.id == null) {
+sb.append(" atomIndex:" + this.centralAtom.i);
+sb.append(" atomName:" + this.centralAtom.getAtomName());
+sb.append(" element:" + this.centralAtom.getElementSymbol());
+} else {
+sb.append(" id:" + this.id);
+sb.append("; center:" + JU.PT.sprintf("{%6.3p %6.3p %6.3p}", "p",  Clazz.newArray(-1, [this.center]))).append("; visible:" + this.visible);
+}sb.append("; model:" + this.modelIndex).append("; vertices:" + this.nVertices).append("; faces:" + this.faces.length).append("; volume:" + JU.PT.formatD(this.getVolume().doubleValue(), 1, 3, false, false));
+if (this.scale != 1) sb.append("; scale:" + this.scale);
+sb.append("\n");
+}, "JU.SB");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
