@@ -21,4 +21,4 @@ Clazz.superCall(this, J.shapespecial.Vectors, "setSizeRD2", [i, rd, isVisible]);
 if (rd != null && rd.factorType === J.atomdata.RadiusData.EnumType.SCREEN) this.mads[i] = -this.mads[i];
 }, "~N,J.atomdata.RadiusData,~B");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
