@@ -543,4 +543,4 @@ cp.xVdwClash = ((x / 2));
 }}, "JU.ContactPair,~N,~N,~N,~N");
 c$.rdVDW =  new J.atomdata.RadiusData(null, 1, J.atomdata.RadiusData.EnumType.FACTOR, J.c.VDW.AUTO);
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
