@@ -218,4 +218,4 @@ this.lcaoReverseColor = lc.lcaoReverseColor;
 Clazz.superCall(this, J.shapesurface.LcaoCartoon, "merge", [shape]);
 }, "J.shape.MeshCollection");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
