@@ -193,4 +193,4 @@ if ((check & 2) != 0) this.outputEdge(iB, iC, color);
 if ((check & 4) != 0) this.outputEdge(iC, iA, color);
 }, "~N,~N,~N,~N,~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
