@@ -7,4 +7,4 @@ Clazz.superCall(this, J.shapesurface.Plot3D, "initShape", []);
 this.myType = "plot3d";
 });
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
