@@ -46,12 +46,10 @@ this.sc = null;
 {
 setTimeout(function() { eval.resumeEval(sc); }, 1);
 }});
-Clazz.defineMethod(c$, "start", 
+Clazz.overrideMethod(c$, "start", 
 function(){
-if (this.isJS) {
+{
 this.run();
-} else {
-Clazz.superCall(this, J.thread.JmolThread, "start", []);
 }});
 Clazz.overrideMethod(c$, "run", 
 function(){
@@ -112,4 +110,4 @@ return Clazz.superCall(this, J.thread.JmolThread, "toString", []) + "[" + this.$
 });
 c$.threadIndex = 0;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
