@@ -3,9 +3,8 @@ Clazz.load(["java.lang.Enum", "JM.BioPolymer"], "JM.AlphaPolymer", ["JU.Measure"
 var c$ = Clazz.decorateAsClass(function(){
 this.pt0 = 0;
 Clazz.instantialize(this, arguments);}, JM, "AlphaPolymer", JM.BioPolymer);
-Clazz.makeConstructor(c$, 
+Clazz.defineMethod(c$, "setPoly", 
 function(monomers, pt0){
-Clazz.superConstructor (this, JM.AlphaPolymer, []);
 this.pt0 = pt0;
 this.set(monomers);
 this.hasStructure = true;
@@ -182,4 +181,4 @@ Clazz.defineEnumConstant(c$, "RIGHT_TURN", 5, []);
 /*eoif2*/})();
 c$.dsspTypes =  Clazz.newArray(-1, ["H", null, "H", "S", "H", null, "T"]);
 });
-;//5.0.1-v2 Wed Jan 24 13:43:33 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
