@@ -5,7 +5,7 @@ this.structureList = null;
 Clazz.instantialize(this, arguments);}, JM, "AminoPolymer", JM.AlphaPolymer);
 Clazz.makeConstructor(c$, 
 function(monomers, pt0){
-Clazz.superConstructor(this, JM.AminoPolymer, [monomers, pt0]);
+this.setPoly(monomers, pt0);
 this.type = 1;
 for (var i = 0; i < this.monomerCount; ++i) if (!(monomers[i]).hasOAtom()) return;
 
@@ -127,7 +127,7 @@ var distOH = Math.sqrt(distOH2);
 var distCH = Math.sqrt(distCH2);
 var distCN = Math.sqrt(distCN2);
 var distON = Math.sqrt(distON2);
-var energy = JM.HBond.getEnergy(distOH, distCH, distCN, distON);
+var energy = JM.HBond.calcEnergy(distOH, distCH, distCN, distON);
 var isHbond = (energy < -500 && (!checkDistances || distCN > distCH && distOH <= 3.0));
 return (!isHbond && checkDistances || energy < -9900 ? 0 : energy);
 }, "JU.P3,JU.P3,JM.AminoMonomer,~B");
@@ -242,4 +242,4 @@ function(structureList){
 this.structureList = structureList;
 }, "java.util.Map");
 });
-;//5.0.1-v2 Wed Jan 24 13:43:13 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
