@@ -7,9 +7,9 @@ this.bioPolymers = null;
 this.isMutated = false;
 this.defaultStructure = null;
 Clazz.instantialize(this, arguments);}, JM, "BioModel", JM.Model);
-Clazz.makeConstructor(c$, 
+Clazz.defineMethod(c$, "setBioModel", 
 function(modelSet, modelIndex, trajectoryBaseIndex, jmolData, properties, auxiliaryInfo){
-Clazz.superConstructor (this, JM.BioModel, []);
+this.setupArrays();
 this.vwr = modelSet.vwr;
 this.set(modelSet, modelIndex, trajectoryBaseIndex, jmolData, properties, auxiliaryInfo);
 this.isBioModel = true;
@@ -17,6 +17,7 @@ this.vwr.getJBR().getBioModelSet(modelSet);
 this.clearBioPolymers();
 modelSet.am[modelIndex] = this;
 this.pdbID = auxiliaryInfo.get("name");
+return this;
 }, "JM.ModelSet,~N,~N,~S,java.util.Properties,java.util.Map");
 Clazz.defineMethod(c$, "addBioPolymer", 
 function(polymer){
@@ -297,4 +298,4 @@ function(dssrData, dataType){
 if (this.auxiliaryInfo.containsKey("dssr")) this.vwr.getAnnotationParser(true).getAtomicDSSRData(this.ms, this.modelIndex, dssrData, dataType);
 }, "~A,~S");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
