@@ -27,9 +27,6 @@ Clazz.instantialize(this, arguments);}, JM, "BioPolymer", null, JM.Structure);
 Clazz.prepareFields (c$, function(){
 this.unitVectorX = JU.V3.new3(1, 0, 0);
 });
-Clazz.makeConstructor(c$, 
-function(){
-});
 Clazz.defineMethod(c$, "set", 
 function(monomers){
 this.monomers = monomers;
@@ -334,4 +331,4 @@ function(){
 return "[Polymer type " + this.type + " n=" + this.monomerCount + " " + (this.monomerCount > 0 ? this.monomers[0] + " " + this.monomers[this.monomerCount - 1] : "") + "]";
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
