@@ -3,9 +3,8 @@ Clazz.load(["JM.BioPolymer"], "JM.CarbohydratePolymer", null, function(){
 var c$ = Clazz.declareType(JM, "CarbohydratePolymer", JM.BioPolymer);
 Clazz.makeConstructor(c$, 
 function(monomers){
-Clazz.superConstructor (this, JM.CarbohydratePolymer, []);
 this.set(monomers);
 this.type = 3;
 }, "~A");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
