@@ -265,10 +265,6 @@ Clazz.defineMethod(c$, "getCrossLinkVector",
 function(vReturn, crosslinkCovalent, crosslinkHBond){
 return false;
 }, "JU.Lst,~B,~B");
-Clazz.defineMethod(c$, "isConnectedPrevious", 
-function(){
-return false;
-});
 Clazz.defineMethod(c$, "getNitrogenAtom", 
 function(){
 return null;
@@ -336,4 +332,4 @@ c$.standardGroupList = null;
 c$.group3Names =  new Array(128);
 c$.specialAtomNames = null;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 05:22:14 CST 2024
