@@ -9,14 +9,14 @@ Clazz.superConstructor(this, JM.HBond, [atom1, atom2, order, mad, colix]);
 this.energy = energy;
 if (JU.Logger.debugging) JU.Logger.debug("HBond energy = " + energy + " #" + this.getIdentity());
 }, "JM.Atom,JM.Atom,~N,~N,~N,~N");
-Clazz.defineMethod(c$, "getEnergy", 
+Clazz.overrideMethod(c$, "getEnergy", 
 function(){
 return this.energy;
 });
-c$.getEnergy = Clazz.defineMethod(c$, "getEnergy", 
+c$.calcEnergy = Clazz.defineMethod(c$, "calcEnergy", 
 function(distAH, distCH, distCD, distAD){
 var energy = Math.round(-27888.0 / distAH - -27888.0 / distAD + -27888.0 / distCD - -27888.0 / distCH);
 return energy;
 }, "~N,~N,~N,~N");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
