@@ -19,4 +19,4 @@ this.axisB = JU.P3.newP(points[this.nRes]);
 JU.Measure.projectOntoAxis(this.axisB, this.axisA, this.axisUnitVector, this.vectorProjection);
 });
 });
-;//5.0.1-v2 Wed Jan 24 13:43:13 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
