@@ -12,4 +12,4 @@ Clazz.superConstructor (this, JM.MinAngle, []);
 this.data = data;
 }, "~A");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
