@@ -24,7 +24,6 @@ this.jbr = null;
 this.groups = null;
 this.groupCount = 0;
 this.modulationTUV = null;
-this.isSupercell = false;
 this.noH = false;
 this.htAtomMap = null;
 this.chainOf = null;
@@ -127,7 +126,6 @@ this.adapterTrajectoryCount = (this.isTrajectory ? this.ms.trajectory.steps.size
 this.ms.someModelsHaveSymmetry = this.ms.getMSInfoB(JV.JC.getBoolName(1));
 this.someModelsHaveUnitcells = this.ms.getMSInfoB(JV.JC.getBoolName(2));
 this.someModelsAreModulated = this.ms.getMSInfoB(JV.JC.getBoolName(9));
-this.isSupercell = this.ms.getMSInfoB(JV.JC.getBoolName(7));
 this.ms.someModelsHaveFractionalCoordinates = this.ms.getMSInfoB(JV.JC.getBoolName(1));
 if (this.merging) {
 this.ms.haveBioModels = new Boolean (this.ms.haveBioModels | this.modelSet0.haveBioModels).valueOf();
@@ -224,11 +222,7 @@ for (var i = models[this.baseModelIndex].firstAtomIndex; i < ac; i++) if (atoms[
 this.freeze();
 this.finalizeShapes();
 this.vwr.setModelSet(this.ms);
-if (this.isSupercell && this.appendNew) {
-for (var i = this.baseModelIndex; i < this.ms.mc; i++) {
-this.vwr.assignSpaceGroup(null, "P1", i);
-}
-}this.setAtomProperties();
+this.setAtomProperties();
 if (adapter != null) adapter.finish(asc);
 if (this.modelSet0 != null) {
 this.modelSet0.releaseModelSet();
@@ -1056,4 +1050,4 @@ break;
 return null;
 }, "JV.Viewer,JM.ModelSet,~N,~O,JU.BS");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
