@@ -360,4 +360,4 @@ function(){
 return "[" + this.getGroup3() + "-" + this.getSeqcodeString() + " " + this.getStructure() + "]";
 });
 });
-;//5.0.1-v2 Wed Jan 24 13:42:02 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
