@@ -5,7 +5,8 @@ this.isDssrSet = false;
 Clazz.instantialize(this, arguments);}, JM, "NucleicPolymer", JM.PhosphorusPolymer);
 Clazz.makeConstructor(c$, 
 function(monomers){
-Clazz.superConstructor(this, JM.NucleicPolymer, [monomers]);
+this.set(monomers);
+this.hasStructure = true;
 this.type = 2;
 this.hasWingPoints = true;
 }, "~A");
@@ -85,4 +86,4 @@ return 1;
 }, "JU.Lst,JM.Atom,JM.Atom");
 c$.htGroup1 = null;
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
