@@ -77,4 +77,4 @@ return this.getHelixData2(tokType, qType, mStep);
 c$.phosphorusOffsets =  Clazz.newByteArray(-1, [0]);
 c$.MAX_ADJACENT_PHOSPHORUS_DISTANCE = 8.0;
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
