@@ -21,6 +21,10 @@ this.resMap = null;
 Clazz.instantialize(this, arguments);}, JM, "ProteinStructure", null, JM.Structure);
 Clazz.makeConstructor(c$, 
 function(){
+this.incrementID();
+});
+Clazz.defineMethod(c$, "incrementID", 
+function(){
 this.id = ++JM.ProteinStructure.ids;
 });
 Clazz.defineMethod(c$, "setupPS", 
@@ -150,4 +154,4 @@ return "[" + this.id + " " + this.type + (this.subtype == null ? "" : " " + this
 c$.ids = 0;
 c$.globalStrucNo = 1000;
 });
-;//5.0.1-v2 Wed Jan 24 13:43:13 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
