@@ -6,6 +6,7 @@ this.heightUnitVector = null;
 Clazz.instantialize(this, arguments);}, JM, "Sheet", JM.ProteinStructure);
 Clazz.overrideConstructor(c$, 
 function(apolymer, monomerIndex, monomerCount, subtype){
+this.incrementID();
 this.setupPS(apolymer, J.c.STR.SHEET, monomerIndex, monomerCount);
 this.subtype = subtype;
 }, "JM.AlphaPolymer,~N,~N,J.c.STR");
@@ -67,4 +68,4 @@ ptC.ave(vW, vH);
 ptC.sub2(pt, ptC);
 }, "~N,~N,JU.P3,JU.V3,JU.V3,JU.P3,~N");
 });
-;//5.0.1-v2 Wed Jan 24 13:43:13 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
