@@ -181,12 +181,6 @@ this.textHeight = this.lines.length * this.lineHeight;
 this.boxWidth = this.textWidth + (this.fontScale >= 2 ? 16 : 8);
 this.boxHeight = this.textHeight + (this.fontScale >= 2 ? 16 : 8);
 });
-Clazz.defineMethod(c$, "getPymolXYOffset", 
-function(x, width, ppa){
-var f = (x < -1 ? -1 : x > 1 ? 0 : (x - 1) / 2);
-var offset = (x < -1 || x > 1 ? x + (x < 0 ? 1 : -1) : 0);
-return f * width + offset * ppa;
-}, "~N,~N,~N");
 Clazz.defineMethod(c$, "setPosition", 
 function(scalePixelsPerMicron, imageFontScaling, isAbsolute, boxXY){
 if (boxXY == null) boxXY = this.boxXY;
@@ -211,7 +205,8 @@ this.yAdj = this.ascent - this.lineHeight + this.xAdj;
 if (!this.isEcho || this.pymolOffset != null) {
 boxXY[0] = this.movableX;
 boxXY[1] = this.movableY;
-if (this.pymolOffset != null && this.pymolOffset[0] != 2 && this.pymolOffset[0] != 3) {
+var isAng = !this.isPymolOffsetPixels();
+if (this.pymolOffset != null && isAng) {
 var pixelsPerAngstrom = this.vwr.tm.scaleToScreen(this.z, 1000);
 var pz = this.pymolOffset[3];
 var dz = (pz < 0 ? -1 : 1) * Math.max(pz == 0 ? 0.5 : 0, Math.abs(pz) - 1) * pixelsPerAngstrom;
@@ -250,6 +245,12 @@ if (this.adjustForWindow) this.setBoxOffsetsInWindow(0, this.isEcho ? 0 : 16 * t
 this.y0 = this.boxY + this.yAdj;
 if (this.isMeasure && this.align != 8) this.y0 += this.ascent + (this.lines.length - 1) / 2 * this.lineHeight;
 }, "~N,~N,~B,~A");
+Clazz.defineMethod(c$, "getPymolXYOffset", 
+function(x, width, ppa){
+var f = (x < -1 ? -1 : x > 1 ? 0 : (x - 1) / 2);
+var offset = (x < -1 || x > 1 ? x + (x < 0 ? 1 : -1) : 0);
+return f * width + offset * ppa;
+}, "~N,~N,~N");
 Clazz.defineMethod(c$, "setPos", 
 function(scale){
 var xLeft;
@@ -484,21 +485,35 @@ y <<= 1;
 }, "~B,~N,~N,JU.BS");
 Clazz.defineMethod(c$, "getPymolScreenOffset", 
 function(atomPt, screen, zSlab, pTemp, sppm){
-var mode = this.pymolOffset[0];
-if (atomPt != null && (Math.abs(mode) % 2) == 1) pTemp.setT(atomPt);
+var isPixel = this.isPymolOffsetPixels();
+var isRelative = this.isPymolOffsetRelative();
+if (atomPt != null && isRelative) pTemp.setT(atomPt);
  else pTemp.set(0, 0, 0);
 pTemp.add3(this.pymolOffset[4], this.pymolOffset[5], this.pymolOffset[6]);
 this.vwr.tm.transformPtScr(pTemp, screen);
-if (mode == 2 || mode == 3) {
+if (isPixel) {
 screen.x += this.pymolOffset[1];
 screen.y += this.pymolOffset[2];
 screen.z += this.pymolOffset[3];
 }this.setXYZs(screen.x, screen.y, screen.z, zSlab);
-this.setScalePixelsPerMicron(sppm);
 }, "JU.P3,JU.P3i,~N,JU.P3,~N");
+Clazz.defineMethod(c$, "isPymolOffsetRelative", 
+function(){
+var mode = (this.pymolOffset == null ? -1 : Clazz.floatToInt(this.pymolOffset[0]));
+return ((mode & 1) == 1);
+});
+Clazz.defineMethod(c$, "isPymolOffsetPixels", 
+function(){
+var mode = (this.pymolOffset == null ? -1 : Clazz.floatToInt(this.pymolOffset[0]));
+return (mode != -1 && ((mode & 2) == 2));
+});
+Clazz.defineMethod(c$, "getStateText", 
+function(){
+return (this.doFormatText ? JU.PT.rep(this.text, "@{", "\\@{") : this.text);
+});
 Clazz.overrideMethod(c$, "toString", 
 function(){
 return this.textUnformatted;
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:43:23 CST 2024
