@@ -7,4 +7,4 @@ this.setupPS(apolymer, J.c.STR.TURN, monomerIndex, monomerCount);
 this.subtype = J.c.STR.TURN;
 }, "JM.AlphaPolymer,~N,~N");
 });
-;//5.0.1-v2 Wed Jan 24 13:43:13 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
