@@ -913,7 +913,7 @@ while (oldParent.parent != null && oldParent.parent.atoms[0] != null) {
 if (JU.Logger.debuggingHigh) this.b$["JS.CIPChirality"].logInfo("path:" + oldParent.parent + "->" + oldParent);
 path.addLast(oldParent = oldParent.parent);
 }
-if (oldParent.parent != null && newParent != null) path.add(oldParent.parent);
+if (oldParent.parent != null && newParent != null) path.addLast(oldParent.parent);
 path.addLast(null);
 for (var i = 0, n = path.size(); i < n; i++) {
 oldParent = path.get(i);
@@ -983,4 +983,4 @@ return (this.isDuplicate ? "(" + this.atom.getAtomName() + "." + this.rootDistan
 };
 c$.ruleNames =  Clazz.newArray(-1, ["", "1a", "1b", "2", "3", "4a", "4b", "4c", "5", "6"]);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
