@@ -1842,7 +1842,9 @@ ptLastChar = ichT;
 }
 ++ichT;
 }
-if (allowSpace) ichT = ptLastChar + 1;
+if (isVariable && (ptSpace < 0 || ptSpace > ptLastChar)) {
+return false;
+}if (allowSpace) ichT = ptLastChar + 1;
  else if (ptSpace > 0) ichT = ptSpace;
 if (isVariable && (!allowSpace || ptSpace < 0 && parenpt <= 0 && ichT - this.ichToken > 1)) {
 return false;
@@ -2088,4 +2090,4 @@ JU.Logger.error(this.errorMessage);
 }return false;
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 05:22:14 CST 2024
