@@ -1011,7 +1011,7 @@ allowScale = false;
 tickInfo.type = str;
 if (this.tokAt(this.iToken + 1) == 1287653388) tickInfo.tickLabelFormats = this.stringParameterSet(this.iToken + 2);
 if (!allowScale) return tickInfo;
-if (this.tokAt(this.iToken + 1) == 536875009) {
+if (this.tokAt(this.iToken + 1) == 536875059) {
 if (this.isFloatParameter(this.iToken + 2)) {
 var f = this.floatParameter(this.iToken + 2);
 tickInfo.scale = JU.P3.new3(f, f, f);
@@ -1137,4 +1137,4 @@ return (--n < 0 || n >= params.length ? null : (params[n] = JS.SV.getVariable(pa
 return (n == -2147483648 ? v : --n < 0 || n >= list.size() ? JS.SV.newV(7,  new JU.Lst()) : list.get(n));
 }, "~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
