@@ -188,14 +188,14 @@ var map = this.getSmilesMatches(smiles2, smiles1, null, null, isSmiles ? 1 : 163
 if (map.length == 0) return NaN;
 ptsA.addLast(p1.get("center"));
 var a = p1.get("vertices");
-for (var i = 0, n = a.length; i < n; i++) ptsA.add(a[map[i + 1] - 1]);
+for (var i = 0, n = a.length; i < n; i++) ptsA.addLast(a[map[i + 1] - 1]);
 
 ptsB.addLast(p2.get("center"));
 a = p2.get("vertices");
-for (var i = 0, n = a.length; i < n; i++) ptsB.add(a[i]);
+for (var i = 0, n = a.length; i < n; i++) ptsB.addLast(a[i]);
 
 J.api.Interface.getInterface("JU.Eigen", this.e.vwr, "script");
 return JU.Measure.getTransformMatrix4(ptsA, ptsB, m, null);
 }, "~N,~N,~B,JU.M4");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
