@@ -930,4 +930,4 @@ JS.SmilesParser.extractFlags(pattern, ret);
 return ret[0];
 }, "~S");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
