@@ -16,7 +16,9 @@ Clazz.makeConstructor(c$,
 function(){
 });
 Clazz.defineMethod(c$, "findSpaceGroup", 
-function(vwr, atoms0, xyzList, unitCellParams, uc, asString, isAssign){
+function(vwr, atoms0, xyzList, unitCellParams, origin, uc, asString, isAssign, checkSupercell){
+var slop = uc.getPrecision();
+this.slop = (!Float.isNaN(slop) ? slop : unitCellParams != null ? unitCellParams[26] : true ? 1.0E-12 : 1.0E-4);
 var oabc = null;
 var cartesians = vwr.ms.at;
 var isg = 0;
@@ -32,7 +34,7 @@ var n = 0;
 var nChecked = 0;
 var scaling = JU.P3.new3(1, 1, 1);
 var sg = null;
-var setNew = (isAssign && xyzList != null && this.nAtoms == 0 && (uc == null || uc.getSpaceGroup() == null || "P1".equals((uc.getSpaceGroup()).getName())));
+var setNew = (isAssign && xyzList != null && this.nAtoms == 0 && (uc.getSpaceGroup() == null || "P1".equals((uc.getSpaceGroup()).getName())));
 var name;
 var basis;
 if (xyzList != null && xyzList.toUpperCase().startsWith("ITA/")) {
@@ -89,12 +91,14 @@ case 104:
 sg.axisChoice = axis;
 break;
 }
-}}if (setNew) {
+}}var isSupercell = false;
+if (setNew) {
 if (sg == null && (sg = JS.SpaceGroup.determineSpaceGroupNA(xyzList, unitCellParams)) == null && (sg = JS.SpaceGroup.createSpaceGroupN(xyzList)) == null) return null;
 uc = this.createCompatibleUnitCell(sg, unitCellParams);
 basis =  new JU.BS();
 name = sg.asString();
 oabc = uc.getUnitCellVectors();
+if (origin != null) oabc[0].setT(origin);
 } else {
 try {
 if (JS.SpaceGroupFinder.bsOpGroups == null) JS.SpaceGroupFinder.loadData(vwr, this);
@@ -102,11 +106,13 @@ if (xyzList != null) {
 var ret = this.getGroupsWithOps(xyzList, unitCellParams, isAssign);
 if (!isAssign || ret == null) return ret;
 sg = ret;
-uc.setUnitCell(unitCellParams, false, 1.0E-12);
+uc.setUnitCellFromParams(unitCellParams, false, slop);
 }oabc = uc.getUnitCellVectors();
 uc = uc.getUnitCellMultiplied();
-this.slop = uc.getPrecision();
-this.filterGroups(bsGroups, uc.getUnitCellParams());
+if (origin != null) {
+oabc[0].setT(origin);
+uc.setOffsetPt(origin);
+}this.filterGroups(bsGroups, uc.getUnitCellParams());
 this.atoms =  new Array(bsAtoms.cardinality());
 System.out.println("bsAtoms = " + bsAtoms);
 for (var p = 0, i = bsAtoms.nextSetBit(0); i >= 0; i = bsAtoms.nextSetBit(i + 1), p++) {
@@ -118,12 +124,12 @@ var bsPoints = JU.BSUtil.newBitSet2(0, this.nAtoms);
 var uc0 = uc;
 this.nAtoms = bsPoints.cardinality();
 uc0 = uc;
-var isSupercell = false;
 if (this.nAtoms > 0) {
 for (var i = bsPoints.nextSetBit(0); i >= 0; i = bsPoints.nextSetBit(i + 1)) {
 uc.unitize(this.atoms[i]);
 }
 this.removeDuplicates(bsPoints);
+if (checkSupercell) {
 uc = this.checkSupercell(vwr, uc, bsPoints, 1, scaling);
 uc = this.checkSupercell(vwr, uc, bsPoints, 2, scaling);
 uc = this.checkSupercell(vwr, uc, bsPoints, 3, scaling);
@@ -132,7 +138,7 @@ if (isSupercell) {
 if (scaling.x != 1) System.out.println("supercell found; a scaled by 1/" + scaling.x);
 if (scaling.y != 1) System.out.println("supercell found; b scaled by 1/" + scaling.y);
 if (scaling.z != 1) System.out.println("supercell found; c scaled by 1/" + scaling.z);
-}}n = bsPoints.cardinality();
+}}}n = bsPoints.cardinality();
 bsAtoms =  new JU.BS();
 var newAtoms =  new Array(n);
 for (var p = 0, i = bsPoints.nextSetBit(0); i >= 0; i = bsPoints.nextSetBit(i + 1)) {
@@ -141,8 +147,7 @@ newAtoms[p++] = a;
 if (isSupercell) {
 a.setT(this.toFractional(cartesians[a.index], uc));
 uc.unitize(a);
-}bsAtoms.set(this.atoms[i].index);
-}
+}}
 this.atoms = newAtoms;
 this.nAtoms = n;
 System.out.println("bsAtoms(within cell) = " + bsAtoms);
@@ -259,19 +264,19 @@ bs1.andNot(targets);
 if (!isAssign) this.dumpBasis(JS.SpaceGroupFinder.bsGroupOps[isg], bs1, bsPoints0);
 map.put("name", name);
 map.put("basis", basis);
-map.put("supercell", scaling);
-oabc[1].scale(scaling.x);
-oabc[2].scale(scaling.y);
-oabc[3].scale(scaling.z);
+if (isSupercell) map.put("supercell", scaling);
+oabc[1].scale(1 / scaling.x);
+oabc[2].scale(1 / scaling.y);
+oabc[3].scale(1 / scaling.z);
 map.put("unitcell", oabc);
 if (isAssign) map.put("sg", sg);
 return map;
-}, "JV.Viewer,JU.BS,~S,~A,J.api.SymmetryInterface,~B,~B");
+}, "JV.Viewer,JU.BS,~S,~A,JU.T3,J.api.SymmetryInterface,~B,~B,~B");
 Clazz.defineMethod(c$, "createCompatibleUnitCell", 
 function(sg, params){
 var newParams =  Clazz.newFloatArray (6, 0);
 JS.UnitCell.createCompatibleUnitCell(sg, params, newParams, false);
-var sym =  new JS.Symmetry().setUnitCell(newParams, false, NaN);
+var sym =  new JS.Symmetry().setUnitCellFromParams(newParams, false, NaN);
 sym.setSpaceGroupTo(sg);
 return sym;
 }, "JS.SpaceGroup,~A");
@@ -318,17 +323,17 @@ var isTet = false;
 var isTri = false;
 var isRhombo = false;
 var isCubic = false;
-var absame = this.approx0(params[0] - params[1]);
-var bcsame = this.approx0(params[1] - params[2]);
+var absame = this.approx001(params[0] - params[1]);
+var bcsame = this.approx001(params[1] - params[2]);
 if (params[3] == 90) {
 if (params[4] == 90) {
 if (absame && params[0] != params[1]) System.out.println("OHOH");
-isTri = (absame && this.approx0(params[5] - 120));
+isTri = (absame && this.approx001(params[5] - 120));
 if (params[5] == 90) {
 isCubic = (absame && params[1] == params[2]);
 isTet = (!isCubic && absame);
 isOrtho = (!isCubic && !isTet);
-}}} else if (absame && bcsame && this.approx0(params[3] - params[4]) && this.approx0(params[4] - params[5])) {
+}}} else if (absame && bcsame && this.approx001(params[3] - params[4]) && this.approx001(params[4] - params[5])) {
 isRhombo = true;
 }bsGroups.setBits(0, 2);
 var i0 = 2;
@@ -358,6 +363,10 @@ break;
 }
 bsGroups.setBits(i0, i);
 }, "JU.BS,~A");
+Clazz.defineMethod(c$, "approx001", 
+function(d){
+return Math.abs(d) < 0.001;
+}, "~N");
 c$.scanTo = Clazz.defineMethod(c$, "scanTo", 
 function(i, num){
 for (; ; i++) {
@@ -430,6 +439,7 @@ if (bsPoints.isEmpty()) return uc;
 var minF = 2147483647;
 var maxF = -2147483648;
 var counts =  Clazz.newIntArray (101, 0);
+var nAtoms = bsPoints.cardinality();
 for (var i = bsPoints.nextSetBit(0); i >= 0; i = bsPoints.nextSetBit(i + 1)) {
 var a = this.atoms[i];
 var type = a.typeAndOcc;
@@ -451,7 +461,7 @@ if (this.approx0(f = this.pt.z) || !this.approx0(this.pt.x) || !this.approx0(thi
 break;
 }
 var n = this.approxInt(1 / f);
-if (n == 0 || Clazz.doubleToInt(this.nAtoms / n) != 1 * this.nAtoms / n || n > 100) continue;
+if (n == 0 || Clazz.doubleToInt(nAtoms / n) != 1 * nAtoms / n || n > 100) continue;
 if (n > maxF) maxF = n;
 if (n < minF) minF = n;
 counts[n]++;
@@ -459,7 +469,7 @@ counts[n]++;
 }
 var n = maxF;
 while (n >= minF) {
-if (counts[n] > 0 && counts[n] == Clazz.doubleToInt((n - 1) * this.nAtoms / n)) {
+if (counts[n] > 0 && counts[n] == Clazz.doubleToInt((n - 1) * nAtoms / n)) {
 break;
 }--n;
 }
@@ -477,7 +487,7 @@ case 3:
 scaling.z = n;
 break;
 }
-uc = vwr.getSymTemp().getUnitCelld(oabc, false, "scaled");
+uc = vwr.getSymTemp().getUnitCell(oabc, false, "scaled");
 var f = 0;
 for (var i = bsPoints.nextSetBit(0); i >= 0; i = bsPoints.nextSetBit(i + 1)) {
 switch (abc) {
@@ -495,7 +505,7 @@ if (f != 0) {
 this.atoms[i] = null;
 bsPoints.clear(i);
 }}
-this.nAtoms = bsPoints.cardinality();
+nAtoms = bsPoints.cardinality();
 return uc;
 }, "JV.Viewer,J.api.SymmetryInterface,JU.BS,~N,JU.P3");
 Clazz.defineMethod(c$, "approx0", 
@@ -624,4 +634,4 @@ c$.opXYZ = null;
 c$.ops = null;
 c$.rdr = null;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
