@@ -209,7 +209,7 @@ function(modelIndex, modelAuxiliaryInfo, unitCellParams){
 this.symmetryInfo =  new JS.SymmetryInfo();
 var params = this.symmetryInfo.setSymmetryInfo(modelAuxiliaryInfo, unitCellParams, null);
 if (params != null) {
-this.setUnitCell(params, modelAuxiliaryInfo.containsKey("jmolData"), NaN);
+this.setUnitCellFromParams(params, modelAuxiliaryInfo.containsKey("jmolData"), NaN);
 this.unitCell.moreInfo = modelAuxiliaryInfo.get("moreUnitCellInfo");
 modelAuxiliaryInfo.put("infoUnitCell", this.getUnitCellAsArray(false));
 this.setOffsetPt(modelAuxiliaryInfo.get("unitCellOffset"));
@@ -222,7 +222,7 @@ Clazz.overrideMethod(c$, "haveUnitCell",
 function(){
 return (this.unitCell != null);
 });
-Clazz.defineMethod(c$, "setUnitCell", 
+Clazz.overrideMethod(c$, "setUnitCellFromParams", 
 function(unitCellParams, setRelative, slop){
 if (unitCellParams == null) unitCellParams =  Clazz.newFloatArray(-1, [1, 1, 1, 90, 90, 90]);
 this.unitCell = JS.UnitCell.fromParams(unitCellParams, setRelative, slop);
@@ -361,13 +361,6 @@ this.unitCell = JS.UnitCell.fromOABC(oabc, setRelative);
 if (name != null) this.unitCell.name = name;
 return this;
 }, "~A,~B,~S");
-Clazz.overrideMethod(c$, "getUnitCelld", 
-function(oabc, setRelative, name){
-if (oabc == null) return null;
-this.unitCell = JS.UnitCell.fromOABC(oabc, setRelative);
-if (name != null) this.unitCell.name = name;
-return this;
-}, "~A,~B,~S");
 Clazz.overrideMethod(c$, "isSupercell", 
 function(){
 return this.unitCell.isSupercell();
@@ -434,7 +427,7 @@ var info = modelSet.getModelAuxiliaryInfo(modelSet.vwr.am.cmi);
 if (info != null) sgName = info.get("spaceGroup");
 }var cellInfo = null;
 if (cellParams != null) {
-cellInfo =  new JS.Symmetry().setUnitCell(cellParams, false, NaN);
+cellInfo =  new JS.Symmetry().setUnitCellFromParams(cellParams, false, NaN);
 }return this.getDesc(modelSet).getSpaceGroupInfo(this, modelIndex, sgName, 0, null, null, null, 0, -1, isFull, isForModel, 0, cellInfo, null);
 }, "JM.ModelSet,~S,~N,~B,~A");
 Clazz.overrideMethod(c$, "fcoord", 
@@ -455,6 +448,7 @@ return this.unitCell.getFractionalOrigin();
 });
 Clazz.overrideMethod(c$, "getState", 
 function(ms, modelIndex, commands){
+var isAssigned = (ms.getInfo(modelIndex, "spaceGroupAssigned") != null);
 var pt = this.getFractionalOffset();
 var loadUC = false;
 if (pt != null && (pt.x != 0 || pt.y != 0 || pt.z != 0)) {
@@ -464,11 +458,11 @@ loadUC = true;
 if (ptm != null) {
 commands.append("; set unitcell ").append(JU.SimpleUnitCell.escapeMultiplier(ptm));
 loadUC = true;
-}var isAssigned = (ms.getInfo(modelIndex, "spaceGroupAssigned") != null);
-var sg = ms.getInfo(modelIndex, "spaceGroup");
+}var sg = ms.getInfo(modelIndex, "spaceGroup");
 if (isAssigned && sg != null) {
 commands.append("\n UNITCELL " + JU.Escape.e(ms.getUnitCell(modelIndex).getUnitCellVectors()));
 commands.append("\n MODELKIT SPACEGROUP " + JU.PT.esc(sg));
+commands.append("\n UNITCELL " + JU.Escape.e(ms.getUnitCell(modelIndex).getUnitCellVectors()));
 loadUC = true;
 }return loadUC;
 }, "JM.ModelSet,~N,JU.SB");
@@ -564,14 +558,14 @@ Clazz.overrideMethod(c$, "getUnitCellInfoMap",
 function(){
 return (this.unitCell == null ? null : this.unitCell.getInfo());
 });
-Clazz.defineMethod(c$, "setUnitCell", 
+Clazz.overrideMethod(c$, "setUnitCell", 
 function(uc){
 this.unitCell = JS.UnitCell.cloneUnitCell((uc).unitCell);
 }, "J.api.SymmetryInterface");
 Clazz.overrideMethod(c$, "findSpaceGroup", 
-function(vwr, atoms, xyzList, unitCell, asString, isAssign){
-return (J.api.Interface.getInterface("JS.SpaceGroupFinder", vwr, "eval")).findSpaceGroup(vwr, atoms, xyzList, unitCell, this, asString, isAssign);
-}, "JV.Viewer,JU.BS,~S,~A,~B,~B");
+function(vwr, atoms, xyzList, unitCellParams, origin, asString, isAssign, checkSupercell){
+return (J.api.Interface.getInterface("JS.SpaceGroupFinder", vwr, "eval")).findSpaceGroup(vwr, atoms, xyzList, unitCellParams, origin, this, asString, isAssign, checkSupercell);
+}, "JV.Viewer,JU.BS,~S,~A,JU.T3,~B,~B,~B");
 Clazz.overrideMethod(c$, "setSpaceGroupTo", 
 function(sg){
 this.symmetryInfo = null;
@@ -622,7 +616,7 @@ var n = pts.size();
 var tofractional = (flags.indexOf("tofractional") >= 0);
 if (flags.indexOf("fromfractional") < 0) {
 for (var i = 0; i < pts.size(); i++) {
-this.toFractional(pts.get(i), true);
+this.toFractional(pts.get(i), false);
 }
 }flags += ",fromfractional,tofractional";
 var check0 = (nIgnored > 0 ? 0 : n);
@@ -641,7 +635,7 @@ this.unitCell.getEquivPoints(pts.get(i), flags, ops, pts, check0, n0);
 for (var i = n - nIgnored; --i >= 0; ) pts.removeItemAt(nIgnored);
 
 if (!tofractional) {
-for (var i = pts.size(); --i >= nIgnored; ) this.toCartesian(pts.get(i), true);
+for (var i = pts.size(); --i >= nIgnored; ) this.toCartesian(pts.get(i), false);
 
 }}, "JU.Lst,~N,~S");
 Clazz.overrideMethod(c$, "getInvariantSymops", 
@@ -654,7 +648,7 @@ var p0 =  new JU.P3();
 var nops = ops.length;
 for (var i = 1; i < nops; i++) {
 p.setT(pt);
-this.unitCell.toFractional(p, true);
+this.unitCell.toFractional(p, false);
 this.unitCell.unitize(p);
 p0.setT(p);
 ops[i].rotTrans(p);
@@ -682,10 +676,10 @@ if (sg == null) sg = JS.SpaceGroup.getSpaceGroupFromITAName(this.symmetryInfo.in
 }if (sg == null || sg.intlTableNumber == null) {
 return "?";
 }if (p == null) {
-p = JU.P3.new3(0.45999998, 0.3285714, 0.25555554);
+p = JU.P3.new3(0.45999998, 0.38333333, 0.2875);
 } else {
 p = JU.P3.newP(p);
-this.unitCell.toFractional(p, true);
+this.unitCell.toFractional(p, false);
 this.unitCell.unitize(p);
 }if (JS.Symmetry.wyckoffFinder == null) {
 JS.Symmetry.wyckoffFinder = J.api.Interface.getInterface("JS.WyckoffFinder", null, "symmetry");
@@ -695,7 +689,7 @@ var mode = (letter == null ? -1 : letter.equalsIgnoreCase("coord") ? -2 : letter
 if (mode != 0) {
 return w.getStringInfo(this.unitCell, p, mode);
 }if (w.findPositionFor(p, letter) == null) return null;
-this.unitCell.toCartesian(p, true);
+this.unitCell.toCartesian(p, false);
 return p;
 } catch (e) {
 if (Clazz.exceptionOf(e, Exception)){
@@ -826,4 +820,4 @@ c$.itaData = null;
 c$.allDataITA = null;
 c$.listDataITA = null;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 09:31:48 CST 2024
