@@ -206,15 +206,14 @@ if (!op.isFinalized) op.doFinalize();
 var matrixOnly = (bsInfo.cardinality() == 1 && bsInfo.get(10));
 var isTimeReversed = (op.timeReversal == -1);
 if (scaleFactor == 0) scaleFactor = 1;
-JS.SymmetryDesc.ptemp.set(0, 0, 0);
 JS.SymmetryDesc.vtrans.set(0, 0, 0);
 var plane = null;
-var pta00 = (ptFrom == null || Float.isNaN(ptFrom.x) ?  new JU.P3() : ptFrom);
+var pta00 = (ptFrom == null || Double.isNaN(ptFrom.x) ? uc.getCartesianOffset() : ptFrom);
 if (ptTarget != null) {
 JS.SymmetryDesc.pta01.setT(pta00);
 JS.SymmetryDesc.pta02.setT(ptTarget);
-uc.toFractional(JS.SymmetryDesc.pta01, true);
-uc.toFractional(JS.SymmetryDesc.pta02, true);
+uc.toFractional(JS.SymmetryDesc.pta01, false);
+uc.toFractional(JS.SymmetryDesc.pta02, false);
 op.rotTrans(JS.SymmetryDesc.pta01);
 JS.SymmetryDesc.ptemp.setT(JS.SymmetryDesc.pta01);
 uc.unitize(JS.SymmetryDesc.pta01);
@@ -258,8 +257,9 @@ var vt1 = JU.V3.newVsub(pt1, pt0);
 var vt2 = JU.V3.newVsub(pt2, pt0);
 var vt3 = JU.V3.newVsub(pt3, pt0);
 JS.SymmetryOperation.approx6Pt(JS.SymmetryDesc.vtrans);
-JS.SymmetryDesc.vtemp.cross(vt1, vt2);
-var haveInversion = (JS.SymmetryDesc.vtemp.dot(vt3) < 0);
+var vtemp =  new JU.V3();
+vtemp.cross(vt1, vt2);
+var haveInversion = (vtemp.dot(vt3) < 0);
 if (haveInversion) {
 pt1.sub2(pt0, vt1);
 pt2.sub2(pt0, vt2);
@@ -314,15 +314,15 @@ ptref.add(d);
 pa1.scaleAdd2(0.5, d, pta00);
 if (ptref.distance(pt0) > 0.1) {
 trans = JU.V3.newVsub(pt0, ptref);
-JS.SymmetryDesc.setFractional(uc, trans, JS.SymmetryDesc.ptemp, null);
-ftrans.setT(JS.SymmetryDesc.ptemp);
+ftrans.setT(trans);
+uc.toFractional(ftrans, true);
 } else {
 trans = null;
-}JS.SymmetryDesc.vtemp.setT(ax1);
-JS.SymmetryDesc.vtemp.normalize();
-w = -JS.SymmetryDesc.vtemp.x * pa1.x - JS.SymmetryDesc.vtemp.y * pa1.y - JS.SymmetryDesc.vtemp.z * pa1.z;
-plane = JU.P4.new4(JS.SymmetryDesc.vtemp.x, JS.SymmetryDesc.vtemp.y, JS.SymmetryDesc.vtemp.z, w);
-margin = (Math.abs(w) < 0.01 && JS.SymmetryDesc.vtemp.x * JS.SymmetryDesc.vtemp.y > 0.4 ? 1.30 : 1.05);
+}vtemp.setT(ax1);
+vtemp.normalize();
+w = -vtemp.x * pa1.x - vtemp.y * pa1.y - vtemp.z * pa1.z;
+plane = JU.P4.new4(vtemp.x, vtemp.y, vtemp.z, w);
+margin = (Math.abs(w) < 0.01 && vtemp.x * vtemp.y > 0.4 ? 1.30 : 1.05);
 isRotation = false;
 haveInversion = false;
 isMirrorPlane = true;
@@ -332,12 +332,12 @@ haveInversion = false;
 break;
 }
 if (f != 0) {
-JS.SymmetryDesc.vtemp.sub2(pta00, pa1);
-JS.SymmetryDesc.vtemp.add(pt0);
-JS.SymmetryDesc.vtemp.sub(pa1);
-JS.SymmetryDesc.vtemp.sub(d);
-JS.SymmetryDesc.vtemp.scale(f);
-pa1.add(JS.SymmetryDesc.vtemp);
+vtemp.sub2(pta00, pa1);
+vtemp.add(pt0);
+vtemp.sub(pa1);
+vtemp.sub(d);
+vtemp.scale(f);
+pa1.add(vtemp);
 ipt =  new JU.P3();
 ipt.scaleAdd2(0.5, d, pa1);
 ptinv =  new JU.P3();
@@ -353,7 +353,7 @@ trans.setT(JS.SymmetryDesc.ptemp);
 JS.SymmetryDesc.approx0(ax1);
 if (isRotation) {
 var ptr =  new JU.P3();
-JS.SymmetryDesc.vtemp.setT(ax1);
+vtemp.setT(ax1);
 var ang2 = ang1;
 var p0;
 if (haveInversion) {
@@ -364,8 +364,8 @@ p0 = pt0;
 ptr.setT(pa1);
 } else {
 p0 = pt0;
-ptr.scaleAdd2(0.5, JS.SymmetryDesc.vtemp, pa1);
-}JS.SymmetryDesc.ptemp.add2(pa1, JS.SymmetryDesc.vtemp);
+ptr.scaleAdd2(0.5, vtemp, pa1);
+}JS.SymmetryDesc.ptemp.add2(pa1, vtemp);
 ang2 = Math.round(JU.Measure.computeTorsion(pta00, pa1, JS.SymmetryDesc.ptemp, p0, true));
 if (JS.SymmetryOperation.approx(ang2) != 0) {
 ang1 = ang2;
@@ -383,7 +383,7 @@ uc.toFractional(JS.SymmetryDesc.ptemp, false);
 info1 = "Ci: " + JS.SymmetryDesc.strCoord(op, JS.SymmetryDesc.ptemp, op.isBio);
 type = "inversion center";
 } else if (isRotation) {
-var screwtype = (isccw == null || haveInversion || pitch1 == 0 ? "" : isccw === Boolean.TRUE ? "(+)" : "(-)");
+var screwtype = (isccw == null ? "" : isccw === Boolean.TRUE ? "(+)" : "(-)");
 if (haveInversion) {
 info1 = (Clazz.doubleToInt(360 / ang)) + "-bar" + screwtype + " axis";
 } else if (pitch1 != 0) {
@@ -416,11 +416,11 @@ info1 += "|at " + JS.SymmetryDesc.strCoord(op, JS.SymmetryDesc.ptemp, op.isBio);
 }if (isTimeReversed) {
 info1 += "|time-reversed";
 type += " (time-reversed)";
-}}var isOK = true;
+}}var isRightHand = true;
 var isScrew = (isRotation && !haveInversion && pitch1 != 0);
 if (!isScrew) {
-isOK = JS.SymmetryDesc.checkHandedness(uc, ax1);
-if (!isOK) {
+isRightHand = JS.SymmetryDesc.checkHandedness(uc, ax1);
+if (!isRightHand) {
 ang1 = -ang1;
 if (ang1 < 0) ang1 = 360 + ang1;
 ax1.scale(-1);
@@ -448,7 +448,7 @@ if (isRotation) {
 color = "red";
 ang = ang1;
 var scale = 1;
-JS.SymmetryDesc.vtemp.setT(ax1);
+vtemp.setT(ax1);
 if (haveInversion) {
 color = "purple";
 }var wp = "";
@@ -461,51 +461,50 @@ opType = drawid + "screw";
 color = (isccw === Boolean.TRUE ? "orange" : isccw === Boolean.FALSE ? "yellow" : order == 4 ? "lightgray" : "grey");
 if (!isSpaceGroup) {
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine1", 0.1, pta00, pa1, "red");
-JS.SymmetryDesc.ptemp.add2(pa1, JS.SymmetryDesc.vtemp);
+JS.SymmetryDesc.ptemp.add2(pa1, vtemp);
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine2", 0.1, pt0, JS.SymmetryDesc.ptemp, "red");
-ptr.scaleAdd2(0.5, JS.SymmetryDesc.vtemp, pa1);
+ptr.scaleAdd2(0.5, vtemp, pa1);
 }} else {
 ptr.setT(pa1);
-if (!isOK) {
-if (!isSpecial && !isSpaceGroup) pa1.sub2(pa1, JS.SymmetryDesc.vtemp);
+if (!isRightHand) {
+if (!isSpecial && !isSpaceGroup) pa1.sub2(pa1, vtemp);
 }if (haveInversion) {
 opType = drawid + "rotinv";
 if (isSpaceGroup) {
-JS.SymmetryDesc.vtemp.normalize();
+vtemp.normalize();
 if (isccw === Boolean.TRUE) {
-JS.SymmetryDesc.vtemp.scale(-1);
+vtemp.scale(-1);
 }} else {
 if (pitch1 == 0) {
 ptr.setT(ipt);
-JS.SymmetryDesc.vtemp.scale(3 * scaleFactor);
+vtemp.scale(3 * scaleFactor);
 if (isSpecial) {
-JS.SymmetryDesc.ptemp.scaleAdd2(0.25, JS.SymmetryDesc.vtemp, pa1);
-pa1.scaleAdd2(-0.24, JS.SymmetryDesc.vtemp, pa1);
-ptr.scaleAdd2(0.31, JS.SymmetryDesc.vtemp, ptr);
+JS.SymmetryDesc.ptemp.scaleAdd2(0.25, vtemp, pa1);
+pa1.scaleAdd2(-0.24, vtemp, pa1);
+ptr.scaleAdd2(0.31, vtemp, ptr);
 color = "cyan";
 } else {
-JS.SymmetryDesc.ptemp.scaleAdd2(-1, JS.SymmetryDesc.vtemp, pa1);
+JS.SymmetryDesc.ptemp.scaleAdd2(-1, vtemp, pa1);
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine1", 0.1, pta00, ipt, "red");
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine2", 0.1, ptinv, ipt, "red");
-}} else {
-if (!isSpecial) {
+}} else if (!isSpecial) {
 scale = pta00.distance(ptr);
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine1", 0.1, pta00, ptr, "red");
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine2", 0.1, ptinv, ptr, "red");
-}}}} else {
+}}} else {
 opType = drawid + "rot";
-JS.SymmetryDesc.vtemp.scale(3 * scaleFactor);
+vtemp.scale(3 * scaleFactor);
 if (isSpecial) {
 } else {
 if (!isSpaceGroup) {
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine1", 0.1, pta00, ptr, "red");
 JS.SymmetryDesc.drawLine(draw1, drawid + "rotLine2", 0.1, pt0, ptr, "red");
 }}ptr.setT(pa1);
-if (pitch1 == 0 && isSpecial) ptr.scaleAdd2(0.25, JS.SymmetryDesc.vtemp, ptr);
+if (pitch1 == 0 && isSpecial) ptr.scaleAdd2(0.25, vtemp, ptr);
 }}if (!isSpaceGroup) {
 if (ang > 180) {
 ang = 180 - ang;
-}JS.SymmetryDesc.ptemp.add2(ptr, JS.SymmetryDesc.vtemp);
+}JS.SymmetryDesc.ptemp.add2(ptr, vtemp);
 draw1.append(drawid).append("rotRotArrow arrow width 0.1 scale " + JU.PT.escF(scale) + " arc ").append(JU.Escape.eP(ptr)).append(JU.Escape.eP(JS.SymmetryDesc.ptemp));
 JS.SymmetryDesc.ptemp.setT(pta00);
 if (JS.SymmetryDesc.ptemp.distance(pt0) < 0.1) JS.SymmetryDesc.ptemp.set(Math.random(), Math.random(), Math.random());
@@ -519,14 +518,14 @@ System.out.println("SD ignoring " + op.getOpTrans().length() + " " + op.getOpTit
 }var p2 = null;
 var wscale = 1;
 if (pitch1 == 0 && !haveInversion) {
-JS.SymmetryDesc.ptemp.scaleAdd2(0.5, JS.SymmetryDesc.vtemp, pa1);
-pa1.scaleAdd2(isSpaceGroup ? -0.5 : -0.45, JS.SymmetryDesc.vtemp, pa1);
+JS.SymmetryDesc.ptemp.scaleAdd2(0.5, vtemp, pa1);
+pa1.scaleAdd2(isSpaceGroup ? -0.5 : -0.45, vtemp, pa1);
 if (isSpaceGroupAll && (p2 = op.getOpPoint2()) != null) {
 ptr.setT(p2);
 uc.toCartesian(ptr, false);
-ptr.scaleAdd2(-0.5, JS.SymmetryDesc.vtemp, ptr);
+ptr.scaleAdd2(-0.5, vtemp, ptr);
 }if (isSpaceGroup) {
-this.scaleByOrder(JS.SymmetryDesc.vtemp, order, isccw);
+this.scaleByOrder(vtemp, order, isccw);
 }} else if (isSpaceGroupAll && pitch1 != 0 && !haveInversion && (d = op.getOpTrans().length()) > 0.4) {
 if (isccw === Boolean.TRUE) {
 } else if (isccw == null) {
@@ -534,16 +533,16 @@ if (isccw === Boolean.TRUE) {
 ignore = true;
 }} else if (isSpaceGroup && haveInversion) {
 p2 = pt1;
-JS.SymmetryDesc.vtemp.scale(-1.0);
-this.scaleByOrder(JS.SymmetryDesc.vtemp, order, isccw);
+vtemp.scale(-1.0);
+this.scaleByOrder(vtemp, order, isccw);
 wp = "80";
 }if (pitch1 > 0 && !haveInversion) {
-wp = "" + (90 - Clazz.floatToInt(JS.SymmetryDesc.vtemp.length() * wscale / pitch1 * 90));
+wp = "" + (90 - Clazz.floatToInt(vtemp.length() * wscale / pitch1 * 90));
 }if (!ignore) {
 var name = opType + order + "rotVector1";
-JS.SymmetryDesc.drawVector(draw1, drawid, name, "vector", "0.1" + wp, pa1, JS.SymmetryDesc.vtemp, isTimeReversed ? "gray" : color, title);
+JS.SymmetryDesc.drawVector(draw1, drawid, name, "vector", "0.1" + wp, pa1, vtemp, isTimeReversed ? "gray" : color, title);
 if (p2 != null) {
-JS.SymmetryDesc.drawVector(draw1, drawid, name + "b", "vector", "0.1" + wp, ptr, JS.SymmetryDesc.vtemp, isTimeReversed ? "gray" : color, title);
+JS.SymmetryDesc.drawVector(draw1, drawid, name + "b", "vector", "0.1" + wp, ptr, vtemp, isTimeReversed ? "gray" : color, title);
 }}} else if (isMirrorPlane) {
 JS.SymmetryDesc.ptemp.sub2(ptref, pta00);
 if (!isSpaceGroup && pta00.distance(ptref) > 0.2) JS.SymmetryDesc.drawVector(draw1, drawid, "planeVector", "vector", "0.05", pta00, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan", null);
@@ -585,7 +584,6 @@ JS.SymmetryDesc.drawFrameLine("Z", ptref, vt3, 0.15, JS.SymmetryDesc.ptemp, draw
 if (v != null) {
 var isCoincident = (isSpaceGroup && op.isCoincident);
 planeCenter =  new JU.P3();
-var pt = draw1.length();
 for (var i = v.size(); --i >= 0; ) {
 var pts = v.get(i);
 draw1.append(drawid).append(trans == null ? "m" : "g").append("planep").appendI(i).append(" ").append(JU.Escape.eP(pts[0])).append(JU.Escape.eP(pts[1]));
@@ -624,15 +622,15 @@ if (!isSpecial) {
 JS.SymmetryDesc.ptemp.sub2(pt0, ptinv);
 JS.SymmetryDesc.drawVector(draw1, drawid, "Arrow", "vector", "0.05", ptinv, JS.SymmetryDesc.ptemp, isTimeReversed ? "gray" : "cyan", null);
 }if (options != 1073742066) {
-JS.SymmetryDesc.vtemp.setT(vt1);
-JS.SymmetryDesc.vtemp.scale(-1);
-JS.SymmetryDesc.drawFrameLine("X", ptinv, JS.SymmetryDesc.vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "red");
-JS.SymmetryDesc.vtemp.setT(vt2);
-JS.SymmetryDesc.vtemp.scale(-1);
-JS.SymmetryDesc.drawFrameLine("Y", ptinv, JS.SymmetryDesc.vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "green");
-JS.SymmetryDesc.vtemp.setT(vt3);
-JS.SymmetryDesc.vtemp.scale(-1);
-JS.SymmetryDesc.drawFrameLine("Z", ptinv, JS.SymmetryDesc.vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "blue");
+vtemp.setT(vt1);
+vtemp.scale(-1);
+JS.SymmetryDesc.drawFrameLine("X", ptinv, vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "red");
+vtemp.setT(vt2);
+vtemp.scale(-1);
+JS.SymmetryDesc.drawFrameLine("Y", ptinv, vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "green");
+vtemp.setT(vt3);
+vtemp.scale(-1);
+JS.SymmetryDesc.drawFrameLine("Z", ptinv, vtemp, 0.15, JS.SymmetryDesc.ptemp, draw1, opType, "blue");
 }}}}if (trans != null) {
 if (isMirrorPlane && isSpaceGroup) {
 if (planeCenter != null) {
@@ -640,7 +638,7 @@ ptref = planeCenter;
 ptref.scale(1 / nPC);
 ptref.scaleAdd2(-0.5, trans, ptref);
 }} else if (ptref == null) {
-ptref = (isSpaceGroup ?  new JU.P3() : JU.P3.newP(pta00));
+ptref = (isSpaceGroup ? pta00 : JU.P3.newP(pta00));
 }if (ptref != null && !ignore) {
 JS.SymmetryDesc.drawVector(draw1, drawid, "transVector", "vector", (isTranslationOnly ? "0.1" : "0.05"), ptref, trans, isTimeReversed && !haveInversion && !isMirrorPlane && !isRotation ? "darkGray" : "gold", title);
 }}if (!isSpaceGroup) {
@@ -840,12 +838,6 @@ v = JS.SymmetryDesc.ptemp2;
 draw1.append(drawid).append(label).append(" diameter ").append(d).append(type).append(JU.Escape.eP(pt1)).append(JU.Escape.eP(v)).append(" color ").append(color);
 if (title != null) draw1.append(" \"" + title + "\"");
 }, "JU.SB,~S,~S,~S,~S,JU.T3,JU.T3,~S,~S");
-c$.setFractional = Clazz.defineMethod(c$, "setFractional", 
-function(uc, pt00, pt01, offset){
-pt01.setT(pt00);
-if (offset != null) uc.toUnitCell(pt01, offset);
-uc.toFractional(pt01, false);
-}, "J.api.SymmetryInterface,JU.T3,JU.P3,JU.P3");
 c$.rotTransCart = Clazz.defineMethod(c$, "rotTransCart", 
 function(op, uc, pt00, vtrans){
 var p0 = JU.P3.newP(pt00);
@@ -1056,7 +1048,7 @@ var iModel = (iAtom >= 0 ? this.modelSet.at[iAtom].mi : this.modelSet.vwr.am.cmi
 if (iModel < 0) return ret;
 var uc = this.modelSet.am[iModel].biosymmetry;
 if (uc == null && (uc = this.modelSet.getUnitCell(iModel)) == null) {
-uc =  new JS.Symmetry().setUnitCell(null, false, NaN);
+uc =  new JS.Symmetry().setUnitCellFromParams(null, false, NaN);
 }if (type != 135176 || op != 2147483647 && opList == null) {
 return this.getSymmetryInfo(iModel, iAtom, uc, xyz, op, translation, pt, pt2, id, type, scaleFactor, nth, options, false);
 }if (uc == null) return ret;
@@ -1211,11 +1203,10 @@ System.err.println("" + imin + " " + JS.SymmetryDesc.pta01.distance(JS.SymmetryD
 }return null;
 }, "JS.UnitCell,~A,JU.P3,JU.P3,~B");
 c$.keys =  Clazz.newArray(-1, ["xyz", "xyzOriginal", "label", null, "fractionalTranslation", "cartesianTranslation", "inversionCenter", null, "axisVector", "rotationAngle", "matrix", "unitTranslation", "centeringVector", "timeReversal", "plane", "_type", "id", "cif2", "xyzCanonical", "xyzNormalized"]);
-c$.vtemp =  new JU.V3();
 c$.ptemp =  new JU.P3();
 c$.ptemp2 =  new JU.P3();
 c$.pta01 =  new JU.P3();
 c$.pta02 =  new JU.P3();
 c$.vtrans =  new JU.V3();
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
