@@ -1,5 +1,5 @@
 Clazz.declarePackage("JS");
-Clazz.load(["JU.M4", "$.P3"], "JS.SymmetryOperation", ["java.util.HashSet", "$.Hashtable", "JU.Lst", "$.Matrix", "$.Measure", "$.P4", "$.PT", "$.SB", "$.V3", "JS.Symmetry", "JU.BoxInfo", "$.Logger", "$.Parser"], function(){
+Clazz.load(["JU.M4", "$.P3"], "JS.SymmetryOperation", ["java.util.Hashtable", "JU.Lst", "$.Matrix", "$.Measure", "$.P4", "$.PT", "$.SB", "$.V3", "JS.Symmetry", "JU.BoxInfo", "$.Logger", "$.Parser"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.xyzOriginal = null;
 this.xyzCanonical = null;
@@ -1116,13 +1116,13 @@ c$.getAdditionalOperations = Clazz.defineMethod(c$, "getAdditionalOperations",
 function(ops){
 var n = ops.length;
 var lst =  new JU.Lst();
-var xyzLst =  new java.util.HashSet();
+var xyzLst =  new JU.SB();
 var mapPlanes =  new java.util.Hashtable();
 for (var i = 0; i < n; i++) {
 var op = ops[i];
 lst.addLast(op);
 var s = op.getOpName(1);
-xyzLst.add(s + ";");
+xyzLst.append(s).appendC(';');
 if ((op.getOpType() & 8) != 0) JS.SymmetryOperation.addPlaneMap(mapPlanes, op);
 }
 for (var i = 1; i < n; i++) {
@@ -1149,7 +1149,7 @@ opTemp = null;
 }}
 }
 }
-}, "java.util.HashSet,JU.Lst,java.util.Map,~N,~N");
+}, "JU.SB,JU.Lst,java.util.Map,~N,~N");
 c$.addPlaneMap = Clazz.defineMethod(c$, "addPlaneMap", 
 function(mapPlanes, op){
 var s = op.getOpName(0);
@@ -1192,14 +1192,14 @@ this.isFinalized = true;
 this.setOpTypeAndOrder();
 if (!this.isIrrelevant && this.opType != 0 && this.opType != 1) {
 var s = this.getOpName(1) + ";";
-if (!xyzList.contains(s)) {
-xyzList.add(s);
+if (xyzList.indexOf(s) < 0) {
+xyzList.append(s);
 lst.addLast(this);
 this.isFinalized = true;
 this.xyz = JS.SymmetryOperation.getXYZFromMatrix(this, false, false, false);
 return true;
 }}return false;
-}, "JS.SymmetryOperation,JU.V3,~N,JU.V3,java.util.HashSet,JU.Lst,~N");
+}, "JS.SymmetryOperation,JU.V3,~N,JU.V3,JU.SB,JU.Lst,~N");
 c$.approx6Pt = Clazz.defineMethod(c$, "approx6Pt", 
 function(pt){
 if (pt != null) {
@@ -1274,4 +1274,4 @@ c$.C3codes =  Clazz.newIntArray(-1, [0x031112, 0x121301, 0x130112, 0x021311, 0x1
 c$.xneg = null;
 c$.opPlanes = null;
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
