@@ -1,5 +1,5 @@
 Clazz.declarePackage("JS");
-Clazz.load(["JU.SimpleUnitCell", "JU.P3", "JV.JC"], "JS.UnitCell", ["java.util.Hashtable", "JU.Lst", "$.M3", "$.M4", "$.P4", "$.PT", "$.Quat", "$.V3", "J.api.Interface", "JS.Symmetry", "JU.BoxInfo", "$.Escape"], function(){
+Clazz.load(["JU.SimpleUnitCell", "JU.P3", "JV.JC"], "JS.UnitCell", ["java.util.Hashtable", "JU.AU", "$.Lst", "$.M3", "$.M4", "$.P4", "$.PT", "$.Quat", "$.V3", "J.api.Interface", "JS.Symmetry", "JU.BoxInfo", "$.Escape"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.vertices = null;
 this.fractionalOffset = null;
@@ -94,7 +94,7 @@ var m = (multiplied ? this.getUnitCellMultiplied() : this);
 if (m !== this) return m.dumpInfo(isDebug, false);
 return "a=" + this.a + ", b=" + this.b + ", c=" + this.c + ", alpha=" + this.alpha + ", beta=" + this.beta + ", gamma=" + this.gamma + "\noabc=" + JU.Escape.eAP(this.getUnitCellVectors()) + "\nvolume=" + this.volume + (isDebug ? "\nfractional to cartesian: " + this.matrixFractionalToCartesian + "\ncartesian to fractional: " + this.matrixCartesianToFractional : "");
 }, "~B,~B");
-Clazz.defineMethod(c$, "fix", 
+Clazz.defineMethod(c$, "fix000", 
 function(x){
 return (Math.abs(x) < 0.001 ? 0 : x);
 }, "~N");
@@ -354,7 +354,7 @@ return this.unitCellMultiplier;
 Clazz.defineMethod(c$, "getUnitCellVectors", 
 function(){
 var m = this.matrixFractionalToCartesian;
-return  Clazz.newArray(-1, [JU.P3.newP(this.cartesianOffset), JU.P3.new3(this.fix(m.m00), this.fix(m.m10), this.fix(m.m20)), JU.P3.new3(this.fix(m.m01), this.fix(m.m11), this.fix(m.m21)), JU.P3.new3(this.fix(m.m02), this.fix(m.m12), this.fix(m.m22))]);
+return  Clazz.newArray(-1, [JU.P3.newP(this.cartesianOffset), JU.P3.new3(this.fix000(m.m00), this.fix000(m.m10), this.fix000(m.m20)), JU.P3.new3(this.fix000(m.m01), this.fix000(m.m11), this.fix000(m.m21)), JU.P3.new3(this.fix000(m.m02), this.fix000(m.m12), this.fix000(m.m22))]);
 });
 Clazz.defineMethod(c$, "getV0abc", 
 function(def, retMatrix){
@@ -367,10 +367,12 @@ pts[1] = JU.V3.new3(1, 0, 0);
 pts[2] = JU.V3.new3(0, 1, 0);
 pts[3] = JU.V3.new3(0, 0, 1);
 var m3 =  new JU.M3();
-if ((typeof(def)=='string')) {
+if (JU.AU.isAF(def)) {
+return JU.SimpleUnitCell.setAbcFromParams(def, pts);
+}if ((typeof(def)=='string')) {
 var sdef = def;
 var strans = "0,0,0";
-if (sdef.indexOf("a=") == 0) return JU.SimpleUnitCell.setOabc(sdef, null, pts);
+if (sdef.indexOf("a=") == 0) return JU.SimpleUnitCell.setAbc(sdef, null, pts);
 var ptc = sdef.indexOf(";");
 if (ptc >= 0) {
 strans = sdef.substring(ptc + 1);
@@ -457,7 +459,7 @@ for (var i = 8; --i >= 0; ) this.vertices[i] = this.matrixFractionalToCartesian.
 Clazz.defineMethod(c$, "isSameAs", 
 function(uc){
 if (uc.unitCellParams.length != this.unitCellParams.length) return false;
-for (var i = this.unitCellParams.length; --i >= 0; ) if (this.unitCellParams[i] != uc.unitCellParams[i] && !(Float.isNaN(this.unitCellParams[i]) && Float.isNaN(uc.unitCellParams[i]))) return false;
+for (var i = Math.min(this.unitCellParams.length, 26); --i >= 0; ) if (this.unitCellParams[i] != uc.unitCellParams[i] && !(Float.isNaN(this.unitCellParams[i]) && Float.isNaN(uc.unitCellParams[i]))) return false;
 
 return (this.fractionalOffset == null ? !uc.hasOffset() : uc.fractionalOffset == null ? !this.hasOffset() : this.fractionalOffset.distanceSquared(uc.fractionalOffset) == 0);
 }, "JS.UnitCell");
@@ -563,9 +565,9 @@ mf = JU.M3.newM3(primitiveToCrystal);
 if (toPrimitive) mf.invert();
 }for (var i = uc.length; --i >= offset; ) {
 var p = uc[i];
-this.toFractional(p, false);
+this.toFractional(p, true);
 mf.rotate(p);
-this.toCartesian(p, false);
+this.toCartesian(p, true);
 }
 return true;
 }, "~B,~S,~A,JU.M3");
@@ -613,7 +615,13 @@ var alpha = params[3];
 var beta = params[4];
 var gamma = params[5];
 var n = (sg == null || sg.intlTableNumber == null ? 0 : JU.PT.parseInt(sg.intlTableNumber));
-if (n > (allowSame ? 2 : 0)) {
+var toHex = (n != 0 && JS.UnitCell.isHexagonalSG(n, null));
+var isHex = (toHex && JS.UnitCell.isHexagonalSG(-1, params));
+var toRhom = (sg.axisChoice == 'r');
+var isRhom = (toRhom && JU.SimpleUnitCell.isRhombohedral(params));
+if (toHex && isHex || toRhom && isRhom) {
+allowSame = true;
+}if (n > (allowSame ? 2 : 0)) {
 var absame = JU.SimpleUnitCell.approx0(a - b);
 var bcsame = JU.SimpleUnitCell.approx0(b - c);
 var acsame = JU.SimpleUnitCell.approx0(c - a);
@@ -650,9 +658,9 @@ beta = alpha * 1.2;
 gamma = beta * 1.3;
 }if (algasame) {
 gamma = alpha * 1.4;
-}}if (JS.UnitCell.isHexagonalSG(n, null)) {
+}}if (toHex) {
 b = a;
-if (sg.axisChoice == 'r' ? JU.SimpleUnitCell.isRhombohedral(params) : JS.UnitCell.isHexagonalSG(-1, params)) {
+if (toRhom ? isRhom : isHex) {
 } else if (sg.axisChoice == 'r') {
 c = b = a;
 if (!allowSame && alpha > 85 && alpha < 95) alpha = 80;
@@ -699,4 +707,4 @@ return (n < 1 ? JU.SimpleUnitCell.isHexagonal(params) : n >= 143 && n <= 194);
 }, "~N,~A");
 c$.unitVectors =  Clazz.newArray(-1, [JV.JC.axisX, JV.JC.axisY, JV.JC.axisZ]);
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:52:23 CST 2024
