@@ -1,15 +1,17 @@
 Clazz.declarePackage("JS");
-Clazz.load(["java.util.Hashtable", "JU.P3", "$.V3"], "JS.WyckoffFinder", ["JU.JSJSONParser", "$.M4", "$.Measure", "$.P4", "$.PT", "$.Rdr", "$.SB", "JV.FileManager"], function(){
+Clazz.load(["java.util.Hashtable", "JU.P3", "$.V3"], "JS.WyckoffFinder", ["JU.JSJSONParser", "$.M4", "$.Measure", "$.P4", "$.PT", "$.Rdr", "$.SB", "JS.SymmetryOperation", "JV.FileManager"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.positions = null;
 this.npos = 0;
 this.ncent = 0;
 this.centerings = null;
 this.centeringStr = null;
+this.gpos = null;
 Clazz.instantialize(this, arguments);}, JS, "WyckoffFinder", null);
 /*LV!1824 unnec constructor*/Clazz.makeConstructor(c$, 
 function(map){
 if (map != null) {
+this.gpos = map.get("gp");
 var wpos = map.get("wpos");
 this.positions = wpos.get("pos");
 this.npos = this.positions.size();
@@ -37,11 +39,13 @@ JS.WyckoffFinder.helpers.put(sgname, JS.WyckoffFinder.nullHelper);
 Clazz.defineMethod(c$, "findPositionFor", 
 function(p, letter){
 if (this.positions != null) {
-for (var i = this.npos; --i >= 0; ) {
+var isGeneral = (letter.equals("G"));
+for (var i = isGeneral ? 1 : this.npos; --i >= 0; ) {
 var map = this.positions.get(i);
-if (map.get("label").equals(letter)) {
+var l = map.get("label");
+if (isGeneral || l.equals(letter)) {
 var coords = map.get("coord");
-if (coords != null) JS.WyckoffFinder.getWyckoffCoord(coords, 0, letter).project(p);
+if (coords != null) JS.WyckoffFinder.getWyckoffCoord(coords, 0, l).project(p);
 return p;
 }}
 }return null;
@@ -63,18 +67,22 @@ return sb.appendC('(').append(xyz).appendC(')');
 Clazz.defineMethod(c$, "createInfo", 
 function(uc, p, returnType){
 switch (returnType) {
+case 83:
+return this.getCenteringStr(-1, ' ', null).toString().trim();
+case 67:
+var ret =  new Array(this.centerings.length);
+for (var i = ret.length; --i >= 0; ) ret[i] = this.centerings[i];
+
+return ret;
 case 42:
 var sb =  new JU.SB();
-this.getCenteringStr(-1, sb);
+this.getCenteringStr(-1, '+', sb);
 for (var i = this.npos; --i >= 0; ) {
 var map = this.positions.get(i);
 var label = map.get("label");
 sb.appendC('\n').append(label);
-if (i == 0) {
-sb.append(" (x,y,z)");
-} else {
-JS.WyckoffFinder.getList(map.get("coord"), label, sb);
-}}
+JS.WyckoffFinder.getList(i == 0 ? this.gpos : map.get("coord"), label, sb, (i == 0 ? this.ncent : 0));
+}
 return sb.toString();
 case -1:
 case -2:
@@ -89,7 +97,11 @@ return label;
 case -2:
 return "(x,y,z)";
 case -3:
-return map.get("label") + "  (x,y,z)";
+var sbc =  new JU.SB();
+sbc.append(label).appendC(' ');
+this.getCenteringStr(-1, '+', sbc).appendC(' ');
+JS.WyckoffFinder.getList(this.gpos, label, sbc, this.ncent);
+return sbc.toString();
 }
 }var coords = map.get("coord");
 for (var c = 0, n = coords.size(); c < n; c++) {
@@ -103,8 +115,8 @@ return coord.asString(null, true).toString();
 case -3:
 var sbc =  new JU.SB();
 sbc.append(label).appendC(' ');
-this.getCenteringStr(-1, sbc).appendC(' ');
-JS.WyckoffFinder.getList(coords, label, sbc);
+this.getCenteringStr(-1, '+', sbc).appendC(' ');
+JS.WyckoffFinder.getList(coords, label, sbc, 0);
 return sbc.toString();
 }
 }}
@@ -112,10 +124,19 @@ return sbc.toString();
 break;
 default:
 var letter = "" + String.fromCharCode(returnType);
-for (var i = this.npos; --i >= 0; ) {
+var isGeneral = (returnType == 71);
+for (var i = isGeneral ? 1 : this.npos; --i >= 0; ) {
 var map = this.positions.get(i);
-if (map.get("label").equals(letter)) {
-return (i == 0 ? "(x,y,z)" : JS.WyckoffFinder.getList(map.get("coord"), letter, null).toString());
+if (isGeneral || map.get("label").equals(letter)) {
+var sbc =  new JU.SB();
+var coords = (i == 0 ? this.gpos : map.get("coord"));
+JS.WyckoffFinder.getList(coords, letter, sbc, 0);
+if (i > 0 && this.ncent > 0) {
+var tempOp =  new JU.M4();
+for (var j = 0; j < this.ncent; j++) {
+this.addCentering(coords, this.centerings[j], tempOp, sbc);
+}
+}return sbc.toString();
 }}
 break;
 }
@@ -139,28 +160,37 @@ return helper;
 }}}return null;
 }, "~O,JV.Viewer,~S");
 Clazz.defineMethod(c$, "getCenteringStr", 
-function(index, sb){
+function(index, sep, sb){
 if (sb == null) sb =  new JU.SB();
 if (this.ncent == 0) return sb;
 if (index >= 0) {
-sb.appendC('+');
+sb.appendC(sep);
 return JS.WyckoffFinder.wrap(this.centeringStr[index], sb);
 }for (var i = 0; i < this.ncent; i++) {
-sb.appendC('+');
+sb.appendC(sep);
 JS.WyckoffFinder.wrap(this.centeringStr[i], sb);
 }
 return sb;
-}, "~N,JU.SB");
+}, "~N,~S,JU.SB");
 c$.getList = Clazz.defineMethod(c$, "getList", 
-function(coords, letter, sb){
+function(coords, letter, sb, n){
 if (sb == null) sb =  new JU.SB();
-for (var c = 0, n = coords.size(); c < n; c++) {
+n = (n == 0 ? coords.size() : Clazz.doubleToInt(coords.size() / (n + 1)));
+for (var c = 0; c < n; c++) {
 var coord = JS.WyckoffFinder.getWyckoffCoord(coords, c, letter);
 sb.append(" ");
 coord.asString(sb, false);
 }
 return sb;
-}, "JU.Lst,~S,JU.SB");
+}, "JU.Lst,~S,JU.SB,~N");
+Clazz.defineMethod(c$, "addCentering", 
+function(coords, centering, tempOp, sb){
+for (var n = coords.size(), c = 0; c < n; c++) {
+var coord = coords.get(c);
+sb.append(" ");
+coord.asStringCentered(centering, tempOp, sb);
+}
+}, "JU.Lst,JU.P3,JU.M4,JU.SB");
 c$.getWyckoffCoord = Clazz.defineMethod(c$, "getWyckoffCoord", 
 function(coords, c, label){
 var coord = coords.get(c);
@@ -197,6 +227,16 @@ this.xyz = xyz;
 this.label = label;
 this.create(xyz);
 }, "~S,~S");
+Clazz.defineMethod(c$, "asStringCentered", 
+function(centering, tempOp, sb){
+tempOp.setM4(this.op);
+tempOp.add(centering);
+sb.appendC(' ');
+var s = "," + JS.SymmetryOperation.getXYZFromMatrix(tempOp, false, true, true) + ",";
+s = JU.PT.rep(s, ",,", ",0,");
+s = JU.PT.rep(s, ",+", ",");
+sb.appendC('(').append(s.substring(1, s.length - 1)).appendC(')');
+}, "JU.P3,JU.M4,JU.SB");
 Clazz.defineMethod(c$, "contains", 
 function(w, uc, p){
 var slop = uc.getPrecision();
@@ -275,7 +315,6 @@ return d < slop;
 Clazz.defineMethod(c$, "create", 
 function(p){
 var nxyz = (p.indexOf('x') >= 0 ? 1 : 0) + (p.indexOf('y') >= 0 ? 1 : 0) + (p.indexOf('z') >= 0 ? 1 : 0);
-if (nxyz == 1 || nxyz == 2) {
 var a =  Clazz.newFloatArray (16, 0);
 var v = JU.PT.split(this.xyz, ",");
 JS.WyckoffFinder.WyckoffCoord.getRow(v[0], a, 0);
@@ -283,7 +322,7 @@ JS.WyckoffFinder.WyckoffCoord.getRow(v[1], a, 4);
 JS.WyckoffFinder.WyckoffCoord.getRow(v[2], a, 8);
 a[15] = 1;
 this.op = JU.M4.newA16(a);
-}switch (nxyz) {
+switch (nxyz) {
 case 0:
 this.type = 1;
 this.point = JS.WyckoffFinder.toPoint(p);
@@ -389,4 +428,4 @@ c$.vt =  new JU.V3();
 c$.nullHelper = null;
 c$.helpers =  new java.util.Hashtable();
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 09:31:58 CST 2024
