@@ -82,4 +82,4 @@ if (++n == 100) break;
 }, "JSV.common.Parameters,~N,JSV.common.ScaleData");
 c$.HNMR_HEADER =  Clazz.newArray(-1, ["peak", "shift/ppm", "intens", "shift/hz", "diff/hz", "2-diff", "3-diff"]);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
