@@ -309,4 +309,4 @@ this.spectrumScaleFactor *= f;
 c$.NTICKS =  Clazz.newIntArray(-1, [2, 5, 10, 10]);
 c$.LOGTICKS =  Clazz.newDoubleArray(-1, [Math.log10(2), Math.log10(5), 0, 1]);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
