@@ -1,13 +1,11 @@
 Clazz.declarePackage("JU");
-Clazz.load(["javajs.api.JSONEncodable"], "JU.A4", ["JU.T3"], function(){
+Clazz.load(["JU.P3"], "JU.A4", ["JU.T3"], function(){
 var c$ = Clazz.decorateAsClass(function(){
-this.x = 0;
-this.y = 0;
-this.z = 0;
 this.angle = 0;
-Clazz.instantialize(this, arguments);}, JU, "A4", null, [javajs.api.JSONEncodable, java.io.Serializable]);
+Clazz.instantialize(this, arguments);}, JU, "A4", JU.P3);
 Clazz.makeConstructor(c$, 
 function(){
+Clazz.superConstructor (this, JU.A4, []);
 this.z = 1.0;
 });
 c$.new4 = Clazz.defineMethod(c$, "new4", 
@@ -86,4 +84,4 @@ function(){
 return "[" + this.x + "," + this.y + "," + this.z + "," + (this.angle * 180.0 / 3.141592653589793) + "]";
 });
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
