@@ -83,8 +83,14 @@ Clazz.defineMethod(c$, "ioRead",
 function(b, off, len){
 var m = 0;
 while (len > 0) {
-var n = this.stream.read(b, off, len);
-m += n;
+var n;
+{
+if (this.stream.readDIS) {
+n = this.stream.readDIS(b, off, len);
+} else {
+n = this.stream.read(b, off, len);
+}
+}m += n;
 if (n > 0 && this.out != null) this.out.write(b, off, n);
 if (n >= len) break;
 off += n;
@@ -217,4 +223,4 @@ function(b){
 this.isBigEndian = b;
 }, "~B");
 });
-;//5.0.1-v2 Fri Jan 26 13:48:25 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
