@@ -6,6 +6,11 @@ function(v){
 {
 return this.add1(v);
 }}, "~O");
+Clazz.overrideMethod(c$, "add", 
+function(pos, v){
+{
+return this.add2(pos, v);
+}}, "~N,~O");
 Clazz.defineMethod(c$, "removeItemAt", 
 function(location){
 {
@@ -17,4 +22,4 @@ function(v){
 return this._removeObject(v);
 }}, "~O");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
