@@ -178,4 +178,4 @@ return "[Modulation " + this.type + " " + JU.PT.toJSON(null, this.params) + "]";
 });
 c$.legendre =  Clazz.newArray(-1, [ Clazz.newDoubleArray(-1, [1]),  Clazz.newDoubleArray(-1, [0, 1])]);
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
