@@ -1,5 +1,5 @@
 Clazz.declarePackage("JU");
-Clazz.load(["JU.P3", "JV.Viewer"], "JU.SimpleUnitCell", ["JU.AU", "$.M4", "$.P4", "$.PT", "$.V3", "JU.Escape"], function(){
+Clazz.load(["JV.Viewer"], "JU.SimpleUnitCell", ["JU.AU", "$.M4", "$.P3", "$.P4", "$.PT", "$.V3", "JU.Escape"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.unitCellParams = null;
 this.slop = 0;
@@ -30,11 +30,9 @@ this.cB_ = 0;
 this.a_ = 0;
 this.b_ = 0;
 this.c_ = 0;
-this.fo = null;
 Clazz.instantialize(this, arguments);}, JU, "SimpleUnitCell", null);
 Clazz.prepareFields (c$, function(){
 this.slop = (JV.Viewer.isHighPrecision ? 1.0E-12 : 1.0E-4);
-this.fo =  new JU.P3();
 });
 Clazz.makeConstructor(c$, 
 function(){
@@ -70,10 +68,9 @@ Clazz.defineMethod(c$, "init",
 function(params){
 if (params == null) params =  Clazz.newFloatArray(-1, [1, 1, 1, 90, 90, 90]);
 if (!JU.SimpleUnitCell.isValid(params)) return;
-this.unitCellParams =  Clazz.newFloatArray (27, 0);
-for (var i = 0, n = params.length; i < 27; i++) this.unitCellParams[i] = (i < n ? params[i] : NaN);
-
+this.unitCellParams = JU.SimpleUnitCell.newParams(params, NaN);
 var rotateHex = false;
+this.dimension = JU.SimpleUnitCell.getDimensionFromParams(params);
 this.a = params[0];
 this.b = params[1];
 this.c = params[2];
@@ -160,8 +157,11 @@ var m = this.matrixFractionalToCartesian =  new JU.M4();
 m.setColumn4(0, params[6] * fa, params[7] * fa, params[8] * fa, 0);
 m.setColumn4(1, params[9] * fb, params[10] * fb, params[11] * fb, 0);
 m.setColumn4(2, params[12] * fc, params[13] * fc, params[14] * fc, 0);
+if (params.length > 17 && !Float.isNaN(params[17])) {
+m.setColumn4(3, params[15], params[16], params[17], 1);
+} else {
 m.setColumn4(3, 0, 0, 0, 1);
-this.matrixCartesianToFractional = JU.M4.newM4(this.matrixFractionalToCartesian).invert();
+}this.matrixCartesianToFractional = JU.M4.newM4(this.matrixFractionalToCartesian).invert();
 } else {
 var m = this.matrixFractionalToCartesian =  new JU.M4();
 if (rotateHex) {
@@ -176,6 +176,15 @@ this.matrixCartesianToFractional = JU.M4.newM4(this.matrixFractionalToCartesian)
 }this.matrixCtoFNoOffset = this.matrixCartesianToFractional;
 this.matrixFtoCNoOffset = this.matrixFractionalToCartesian;
 }, "~A");
+c$.newParams = Clazz.defineMethod(c$, "newParams", 
+function(params, slop){
+var p =  Clazz.newFloatArray (27, 0);
+var n = params.length;
+for (var i = 0; i < 27; i++) p[i] = (i < n ? params[i] : NaN);
+
+if (n < 27) p[26] = slop;
+return p;
+}, "~A,~N");
 c$.addVectors = Clazz.defineMethod(c$, "addVectors", 
 function(params){
 var c = JU.SimpleUnitCell.newA(params);
@@ -231,8 +240,7 @@ this.c_ = this.a * this.b * this.sinGamma / this.volume;
 });
 Clazz.defineMethod(c$, "getFractionalOrigin", 
 function(){
-this.fo.setT(this.fractionalOrigin);
-return this.fo;
+return this.fractionalOrigin;
 });
 Clazz.defineMethod(c$, "toSupercell", 
 function(fpt){
@@ -299,21 +307,24 @@ return NaN;
 }, "~N");
 c$.getReciprocal = Clazz.defineMethod(c$, "getReciprocal", 
 function(abc, ret, scale){
-if (scale == 0) scale = (6.283185307179586);
-var rabc =  new Array(4);
 var off = (abc.length == 4 ? 1 : 0);
+var rabc =  new Array(4);
 rabc[0] = (off == 1 ? JU.P3.newP(abc[0]) :  new JU.P3());
+if (scale == 0) scale = (6.283185307179586);
 for (var i = 0; i < 3; i++) {
 var v = rabc[i + 1] =  new JU.P3();
 v.cross(abc[((i + 1) % 3) + off], abc[((i + 2) % 3) + off]);
-v.scale(scale / abc[i + off].dot(v));
+var vol = abc[i + off].dot(v);
+if (scale == -1) scale = Math.sqrt(vol);
+v.scale(scale / vol);
 }
 if (ret == null) return rabc;
-for (var i = 0; i < 4; i++) ret[i] = rabc[i];
-
+for (var i = 0; i < 4; i++) {
+ret[i] = rabc[i];
+}
 return ret;
 }, "~A,~A,~N");
-c$.setOabc = Clazz.defineMethod(c$, "setOabc", 
+c$.setAbc = Clazz.defineMethod(c$, "setAbc", 
 function(abcabg, params, ucnew){
 if (abcabg != null) {
 if (params == null) params =  Clazz.newFloatArray (6, 0);
@@ -321,12 +332,16 @@ var tokens = JU.PT.split(abcabg.$replace(',', '='), "=");
 if (tokens.length >= 12) for (var i = 0; i < 6; i++) params[i] = JU.PT.parseFloat(tokens[i * 2 + 1]);
 
 }if (ucnew == null) return null;
+return JU.SimpleUnitCell.setAbcFromParams(params, ucnew);
+}, "~S,~A,~A");
+c$.setAbcFromParams = Clazz.defineMethod(c$, "setAbcFromParams", 
+function(params, ucnew){
 var f = JU.SimpleUnitCell.newA(params).getUnitCellAsArray(true);
 ucnew[1].set(f[0], f[1], f[2]);
 ucnew[2].set(f[3], f[4], f[5]);
 ucnew[3].set(f[6], f[7], f[8]);
 return ucnew;
-}, "~S,~A,~A");
+}, "~A,~A");
 Clazz.defineMethod(c$, "unitizeDim", 
 function(dimension, pt){
 switch (dimension) {
@@ -448,4 +463,4 @@ function(){
 return "[" + this.a + " " + this.b + " " + this.c + " " + this.alpha + " " + this.beta + " " + this.gamma + "]";
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
