@@ -137,5 +137,15 @@ Clazz.overrideMethod(c$, "toJSON",
 function(){
 return "[" + this.x + "," + this.y + "," + this.z + "]";
 });
+Clazz.defineMethod(c$, "setP", 
+function(t){
+this.set(t.x, t.y, t.z);
+return this;
+}, "JU.T3");
+Clazz.defineMethod(c$, "putP", 
+function(t){
+t.set(this.x, this.y, this.z);
+return t;
+}, "JU.T3");
 });
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
