@@ -39,9 +39,13 @@ if (!(Clazz.instanceOf(o,"JU.T3i"))) return false;
 var t = o;
 return (this.x == t.x && this.y == t.y && this.z == t.z);
 }, "~O");
-Clazz.overrideMethod(c$, "toString", 
+Clazz.defineMethod(c$, "asString", 
 function(){
 return "(" + this.x + ", " + this.y + ", " + this.z + ")";
 });
+Clazz.overrideMethod(c$, "toString", 
+function(){
+return this.asString();
+});
 })();
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
