@@ -114,6 +114,12 @@ this.loadShape(5);
 this.setShapeSizeBs(5, 0, null, bsSelection);
 }this.setShapePropertyBs(5, "label", strLabel, bsSelection);
 }, "~O,JU.BS");
+Clazz.defineMethod(c$, "setShapeProperties", 
+function(shapeID, values){
+this.vwr.setShapeErrorState(shapeID, "set properties");
+this.loadShape(shapeID).setProperties(values);
+this.vwr.setShapeErrorState(-1, null);
+}, "~N,~A");
 Clazz.defineMethod(c$, "setShapePropertyBs", 
 function(shapeID, propertyName, value, bsSelected){
 if (this.shapes == null || this.shapes[shapeID] == null) return;
@@ -376,4 +382,4 @@ this.vwr.selectStatus(bsSelected, false, 0, true, false);
 c$.hoverable =  Clazz.newIntArray(-1, [31, 20, 25, 24, 22, 36]);
 c$.clickableMax = JV.ShapeManager.hoverable.length - 1;
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
