@@ -820,7 +820,7 @@ return s;
 Clazz.defineMethod(c$, "getEchoState", 
 function(sb, t){
 var isScale = (t != null && t.barPixels > 0);
-var text = (t == null ? null : isScale ? t.textUnformatted : t.text);
+var text = (t == null ? null : isScale ? t.textUnformatted : t.getStateText());
 if (text == null || !t.isEcho || t.target.equals("error")) return;
 var isImage = (t.image != null);
 var strOff = null;
@@ -1121,4 +1121,4 @@ this.actionStates.removeItemAt(99);
 this.undoWorking = !clearRedo;
 }, "~N,~N,~B");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:57:27 CST 2024
