@@ -1,5 +1,5 @@
 Clazz.declarePackage("JV");
-Clazz.load(["java.util.Hashtable"], ["JV.Connection", "$.Scene", "$.StateManager", "$.Connections"], ["java.util.Arrays", "JU.BS", "$.Lst", "$.SB", "JM.Orientation", "JU.BSUtil"], function(){
+Clazz.load(["java.util.Hashtable"], ["JV.Connection", "$.Scene", "$.StateManager", "$.Connections"], ["java.util.Arrays", "JU.BS", "$.Lst", "$.SB", "JM.Orientation", "JU.BSUtil", "$.Escape"], function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.maxUndo = 20;
 this.vwr = null;
@@ -12,6 +12,7 @@ this.lastSelected = "";
 this.lastState = "";
 this.lastShape = "";
 this.lastCoordinates = "";
+this.lastUnitcell = "";
 this.undoStateStack = null;
 this.redoStateStack = null;
 Clazz.instantialize(this, arguments);}, JV, "StateManager", null);
@@ -158,6 +159,32 @@ return false;
 }this.vwr.selectStatus(bsSelected, false, 0, false, false);
 return true;
 }, "~S");
+Clazz.defineMethod(c$, "saveUnitCell", 
+function(saveName){
+if (saveName.equalsIgnoreCase("DELETE")) {
+this.deleteSavedType("Unitcell_");
+return;
+}saveName = this.lastUnitcell = "Unitcell_" + saveName;
+var uc = this.vwr.getCurrentUnitCell();
+if (uc != null) {
+var state = "UNITCELL " + JU.Escape.e(uc.getUnitCellVectors());
+this.saved.put(saveName, "unitcell reset;" + state);
+}}, "~S");
+Clazz.defineMethod(c$, "getSavedUnitCell", 
+function(saveName){
+var name = (saveName.length > 0 ? "Unitcell_" + saveName : this.lastUnitcell);
+var ucstate = JV.StateManager.getNoCase(this.saved, name);
+return ucstate;
+}, "~S");
+Clazz.defineMethod(c$, "restoreUnitCell", 
+function(saveName){
+var ucstate = this.getSavedUnitCell(saveName);
+if (ucstate == null) {
+this.vwr.setModelCagePts(-1, null, null);
+return false;
+}this.vwr.runScript(ucstate);
+return true;
+}, "~S");
 Clazz.defineMethod(c$, "saveState", 
 function(saveName){
 if (saveName.equalsIgnoreCase("DELETE")) {
@@ -418,4 +445,4 @@ this.energy = energy;
 this.shapeVisibilityFlags = shapeVisibilityFlags;
 }, "~N,~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
