@@ -165,7 +165,7 @@ this.$in = null;
 this.buf = null;
 });
 });
-;//5.0.1-v2 Mon Jan 22 13:18:57 CST 2024
+;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
 Clazz_load(["java.io.DataInput", "$.FilterInputStream"], "java.io.DataInputStream", ["java.io.PushbackInputStream"], function(){
 var c$ = Clazz_decorateAsClass(function(){
 this.bytearr = null;
@@ -178,10 +178,19 @@ this.bytearr =  Clazz_newByteArray (80, 0);
 this.chararr = String.fromCharCode( Clazz_newCharArray (80, '\0'));
 this.readBuffer =  Clazz_newByteArray (8, 0);
 });
-Clazz_defineMethod(c$, "read", 
+Clazz_overrideMethod(c$, "read", 
 function(b, off, len){
 return this.$in.read(b, off, len);
 }, "~A,~N,~N");
+Clazz_defineMethod(c$, "readDIS", 
+function(b, off, len){
+var is = this.$in;
+{
+if (is.readBIS) return is.readBIS(b, off, len);
+if (is.readBAIS)
+return is.readBAIS(b, off, len);
+}return is.read(b, off, len);
+}, "~A,~N,~N");
 Clazz_defineMethod(c$, "readFully", 
 function(b, off, len){
 if (len < 0) throw  new IndexOutOfBoundsException();
@@ -369,7 +378,7 @@ throw  new java.io.UTFDataFormatException("malformed input around byte " + count
 return  String.instantialize(chararr, 0, chararr_count);
 }, "java.io.DataInput,~N");
 });
-;//5.0.1-v2 Mon Jan 22 13:18:57 CST 2024
+;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
 Clazz_declarePackage("JU");
 (function(){
 var c$ = Clazz_declareType(JU, "BC", null);
@@ -443,7 +452,7 @@ return f * JU.BC.fracIEEE[i + 140];
 }, "~N,~N");
 c$.fracIEEE = null;
 })();
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
 Clazz_declarePackage("JU");
 Clazz_load(["javajs.api.GenericBinaryDocument", "JU.BC"], "JU.BinaryDocument", ["java.io.DataInputStream"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -529,8 +538,14 @@ Clazz_defineMethod(c$, "ioRead",
 function(b, off, len){
 var m = 0;
 while (len > 0) {
-var n = this.stream.read(b, off, len);
-m += n;
+var n;
+{
+if (this.stream.readDIS) {
+n = this.stream.readDIS(b, off, len);
+} else {
+n = this.stream.read(b, off, len);
+}
+}m += n;
 if (n > 0 && this.out != null) this.out.write(b, off, n);
 if (n >= len) break;
 off += n;
@@ -663,7 +678,7 @@ function(b){
 this.isBigEndian = b;
 }, "~B");
 });
-;//5.0.1-v2 Fri Jan 26 13:48:25 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
 })(Clazz
 ,Clazz.getClassName
 ,Clazz.newLongArray
