@@ -65,7 +65,7 @@ Clazz_declarePackage("JV");
 (function(){
 var c$ = Clazz_declareType(JV, "JmolStateCreator", null);
 })();
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
 Clazz_declarePackage("JV");
 Clazz_load(["JV.JmolStateCreator", "java.util.Hashtable"], "JV.StateCreator", ["java.util.Arrays", "$.Date", "JU.BS", "$.Lst", "$.P3", "$.PT", "$.SB", "J.c.PAL", "$.STR", "$.VDW", "JM.AtomCollection", "$.Bond", "$.BondSet", "JS.T", "J.shape.Shape", "JU.BSUtil", "$.C", "$.ColorEncoder", "$.Edge", "$.Escape", "$.Font", "$.Logger", "JV.GlobalSettings", "$.JC", "$.StateManager", "$.Viewer"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -888,7 +888,7 @@ return s;
 Clazz_defineMethod(c$, "getEchoState", 
 function(sb, t){
 var isScale = (t != null && t.barPixels > 0);
-var text = (t == null ? null : isScale ? t.textUnformatted : t.text);
+var text = (t == null ? null : isScale ? t.textUnformatted : t.getStateText());
 if (text == null || !t.isEcho || t.target.equals("error")) return;
 var isImage = (t.image != null);
 var strOff = null;
@@ -1189,7 +1189,7 @@ this.actionStates.removeItemAt(99);
 this.undoWorking = !clearRedo;
 }, "~N,~N,~B");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:57:27 CST 2024
 })(Clazz
 ,Clazz.getClassName
 ,Clazz.newLongArray
