@@ -52,7 +52,7 @@ JU.BSUtil.setMapBitSet(this.temp3,b,b,"set labelAlignment "+d)}null!=a.mads&&0>a
 f=a.paletteIDs,g=0;for(b=0;b<c;b++)if(null!=d[b]&&(null!=a.bsSizeSet&&a.bsSizeSet.get(b)&&(0>(g=d[b].madAtom)?JU.BSUtil.setMapBitSet(this.temp,b,b,"Spacefill on"):JU.BSUtil.setMapBitSet(this.temp,b,b,"Spacefill "+JU.PT.escF(g/2E3))),null!=a.bsColixSet&&a.bsColixSet.get(b))){var l=d[b].paletteID;(l!=J.c.PAL.CPK.id||JU.C.isColixTranslucent(d[b].colixAtom))&&JU.BSUtil.setMapBitSet(this.temp,b,b,J.shape.Shape.getColorCommand("atoms",l,d[b].colixAtom,a.translucentAllowed));null!=e&&b<e.length&&JU.BSUtil.setMapBitSet(this.temp2,
 b,b,J.shape.Shape.getColorCommand("balls",f[b],e[b],a.translucentAllowed))}b=this.getCommands(this.temp,this.temp2,"select");this.clearTemp();break;default:b=a.getShapeState()}return b},"J.shape.Shape");k(h,"getFontLineShapeState",function(a){var b=this.getFontState(a.myType,a.font3d);if(null==a.tickInfos)return b;var c=0<=b.indexOf(" off"),d=new JU.SB;d.append(b);for(b=0;4>b;b++)null!=a.tickInfos[b]&&this.appendTickInfo(a.myType,d,a.tickInfos[b]);c&&d.append("  "+a.myType+" off;\n");return d.toString()},
 "J.shape.FontLineShape");k(h,"getAxesState",function(a){var b=new JU.SB;b.append(this.getFontLineShapeState(a));return a.getAxesState(b)},"J.shape.Axes");m(h,"getAtomShapeState",function(a){if(!a.isActive)return"";this.clearTemp();var b=JV.JC.shapeClassBases[a.shapeID],c=18==a.shapeID,d;if(null!=a.bsSizeSet)for(var e=a.bsSizeSet.nextSetBit(0);0<=e;e=a.bsSizeSet.nextSetBit(e+1))JU.BSUtil.setMapBitSet(this.temp,e,e,b+" "+(0>(d=a.mads[e])?c&&-1>d?""+-d:"on":JU.PT.escF(d/2E3)));if(null!=a.bsColixSet)for(e=
-a.bsColixSet.nextSetBit(0);0<=e;e=a.bsColixSet.nextSetBit(e+1))JU.BSUtil.setMapBitSet(this.temp2,e,e,J.shape.Shape.getColorCommand(b,a.paletteIDs[e],a.colixes[e],a.translucentAllowed));a=this.getCommands(this.temp,this.temp2,"select");this.clearTemp();return a},"J.shape.AtomShape");k(h,"getEchoState",function(a,b){var c=null!=b&&0<b.barPixels,d=null==b?null:c?b.textUnformatted:b.text;if(!(null==d||!b.isEcho||b.target.equals("error"))){var e=null!=b.image,f=null,g="set echo ID "+JU.PT.esc(b.target);
+a.bsColixSet.nextSetBit(0);0<=e;e=a.bsColixSet.nextSetBit(e+1))JU.BSUtil.setMapBitSet(this.temp2,e,e,J.shape.Shape.getColorCommand(b,a.paletteIDs[e],a.colixes[e],a.translucentAllowed));a=this.getCommands(this.temp,this.temp2,"select");this.clearTemp();return a},"J.shape.AtomShape");k(h,"getEchoState",function(a,b){var c=null!=b&&0<b.barPixels,d=null==b?null:c?b.textUnformatted:b.getStateText();if(!(null==d||!b.isEcho||b.target.equals("error"))){var e=null!=b.image,f=null,g="set echo ID "+JU.PT.esc(b.target);
 switch(b.valign){case 3:f=2147483647==b.movableXPercent||2147483647==b.movableYPercent?(2147483647==b.movableXPercent?b.movableX+" ":b.movableXPercent+"% ")+(2147483647==b.movableYPercent?b.movableY+"":b.movableYPercent+"%"):"["+b.movableXPercent+" "+b.movableYPercent+"%]";case 4:null==f&&(f=JU.Escape.eP(b.xyz));a.append("  ").append(g).append(" ").append(f);4!=b.align&&a.append(";  ").append(g).append(" ").append(JV.JC.getHorizAlignmentName(b.align));break;default:a.append("  set echo ").append(JV.JC.getEchoName(b.valign)).append(" ").append(JV.JC.getHorizAlignmentName(b.align))}2147483647!=
 b.movableZPercent&&a.append(";  ").append(g).append(" depth ").appendI(b.movableZPercent);e?a.append("; ").append(g).append(" IMAGE /*file*/"):a.append("; echo ");a.append(JU.PT.esc(d));a.append(";\n");e&&1!=b.imageScale&&a.append("  ").append(g).append(" scale ").appendF(b.imageScale).append(";\n");null!=b.script&&a.append("  ").append(g).append(" script ").append(JU.PT.esc(b.script)).append(";\n");0<=b.modelIndex&&a.append("  ").append(g).append(" model ").append(this.vwr.getModelNumberDotted(b.modelIndex)).append(";\n");
 null!=b.pointerPt&&a.append("  ").append(g).append(" point ").append(r(b.pointerPt,"JM.Atom")?"({"+b.pointerPt.i+"})":JU.Escape.eP(b.pointerPt)).append(";\n");null!=b.pymolOffset&&a.append("  ").append(g).append(" offset ").append(JU.Escape.escapeFloatA(b.pymolOffset,!0)).append(";\n");b.appendFontCmd(a);a.append("; color echo");JU.C.isColixTranslucent(b.colix)&&a.append(" ").append(JU.C.getColixTranslucencyLabel(b.colix));a.append(" ").append(JU.C.getHexCode(b.colix));0!=b.bgcolix&&(a.append("; color echo background "),
