@@ -244,12 +244,6 @@ this.textHeight = this.lines.length * this.lineHeight;
 this.boxWidth = this.textWidth + (this.fontScale >= 2 ? 16 : 8);
 this.boxHeight = this.textHeight + (this.fontScale >= 2 ? 16 : 8);
 });
-Clazz_defineMethod(c$, "getPymolXYOffset", 
-function(x, width, ppa){
-var f = (x < -1 ? -1 : x > 1 ? 0 : (x - 1) / 2);
-var offset = (x < -1 || x > 1 ? x + (x < 0 ? 1 : -1) : 0);
-return f * width + offset * ppa;
-}, "~N,~N,~N");
 Clazz_defineMethod(c$, "setPosition", 
 function(scalePixelsPerMicron, imageFontScaling, isAbsolute, boxXY){
 if (boxXY == null) boxXY = this.boxXY;
@@ -274,7 +268,8 @@ this.yAdj = this.ascent - this.lineHeight + this.xAdj;
 if (!this.isEcho || this.pymolOffset != null) {
 boxXY[0] = this.movableX;
 boxXY[1] = this.movableY;
-if (this.pymolOffset != null && this.pymolOffset[0] != 2 && this.pymolOffset[0] != 3) {
+var isAng = !this.isPymolOffsetPixels();
+if (this.pymolOffset != null && isAng) {
 var pixelsPerAngstrom = this.vwr.tm.scaleToScreen(this.z, 1000);
 var pz = this.pymolOffset[3];
 var dz = (pz < 0 ? -1 : 1) * Math.max(pz == 0 ? 0.5 : 0, Math.abs(pz) - 1) * pixelsPerAngstrom;
@@ -313,6 +308,12 @@ if (this.adjustForWindow) this.setBoxOffsetsInWindow(0, this.isEcho ? 0 : 16 * t
 this.y0 = this.boxY + this.yAdj;
 if (this.isMeasure && this.align != 8) this.y0 += this.ascent + (this.lines.length - 1) / 2 * this.lineHeight;
 }, "~N,~N,~B,~A");
+Clazz_defineMethod(c$, "getPymolXYOffset", 
+function(x, width, ppa){
+var f = (x < -1 ? -1 : x > 1 ? 0 : (x - 1) / 2);
+var offset = (x < -1 || x > 1 ? x + (x < 0 ? 1 : -1) : 0);
+return f * width + offset * ppa;
+}, "~N,~N,~N");
 Clazz_defineMethod(c$, "setPos", 
 function(scale){
 var xLeft;
@@ -547,24 +548,38 @@ y <<= 1;
 }, "~B,~N,~N,JU.BS");
 Clazz_defineMethod(c$, "getPymolScreenOffset", 
 function(atomPt, screen, zSlab, pTemp, sppm){
-var mode = this.pymolOffset[0];
-if (atomPt != null && (Math.abs(mode) % 2) == 1) pTemp.setT(atomPt);
+var isPixel = this.isPymolOffsetPixels();
+var isRelative = this.isPymolOffsetRelative();
+if (atomPt != null && isRelative) pTemp.setT(atomPt);
  else pTemp.set(0, 0, 0);
 pTemp.add3(this.pymolOffset[4], this.pymolOffset[5], this.pymolOffset[6]);
 this.vwr.tm.transformPtScr(pTemp, screen);
-if (mode == 2 || mode == 3) {
+if (isPixel) {
 screen.x += this.pymolOffset[1];
 screen.y += this.pymolOffset[2];
 screen.z += this.pymolOffset[3];
 }this.setXYZs(screen.x, screen.y, screen.z, zSlab);
-this.setScalePixelsPerMicron(sppm);
 }, "JU.P3,JU.P3i,~N,JU.P3,~N");
+Clazz_defineMethod(c$, "isPymolOffsetRelative", 
+function(){
+var mode = (this.pymolOffset == null ? -1 : Clazz_floatToInt(this.pymolOffset[0]));
+return ((mode & 1) == 1);
+});
+Clazz_defineMethod(c$, "isPymolOffsetPixels", 
+function(){
+var mode = (this.pymolOffset == null ? -1 : Clazz_floatToInt(this.pymolOffset[0]));
+return (mode != -1 && ((mode & 2) == 2));
+});
+Clazz_defineMethod(c$, "getStateText", 
+function(){
+return (this.doFormatText ? JU.PT.rep(this.text, "@{", "\\@{") : this.text);
+});
 Clazz_overrideMethod(c$, "toString", 
 function(){
 return this.textUnformatted;
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:43:23 CST 2024
 Clazz_declarePackage("J.shape");
 Clazz_load(["J.shape.Shape", "java.util.Hashtable"], "J.shape.TextShape", ["JU.P3", "$.PT", "JU.C", "$.Logger"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -749,7 +764,7 @@ if (haveScripts) this.vwr.setCursor(0);
 return false;
 }, "~N,~N,JU.BS");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:43:24 CST 2024
 Clazz_declarePackage("J.shape");
 Clazz_load(["J.shape.AtomShape", "java.util.Hashtable", "JU.P3"], "J.shape.Labels", ["JU.AU", "$.BS", "$.PT", "J.c.PAL", "JM.LabelToken", "$.Text", "JS.SV", "JU.BSUtil", "$.C", "$.Font", "JV.JC"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -1271,7 +1286,7 @@ if (JU.C.isColixTranslucent(colix)) colix = JU.C.getColixTranslucent3(colix, fal
 }, "~N,JM.Atom,~B");
 c$.nullToken =  Clazz_newArray(-1, [null]);
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
 Clazz_declarePackage("J.shape");
 Clazz_load(["J.api.JmolMeasurementClient", "J.shape.AtomShape", "JU.Lst"], "J.shape.Measures", ["java.util.Hashtable", "JU.AU", "$.BS", "$.PT", "$.SB", "JM.Measurement", "$.MeasurementData", "JU.BSUtil", "$.C", "$.Escape"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -1827,7 +1842,7 @@ m.isVisible = true;
 }
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
 Clazz_declarePackage("J.shape");
 Clazz_load(["J.shape.TextShape"], "J.shape.Echo", ["java.util.Hashtable", "JU.Lst", "$.PT", "JM.Text", "JU.C"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -1922,9 +1937,10 @@ t.pointerPt = (value == null ? null : value);
 t.pointer = (value == null ? 0 : 1);
 }return;
 }if ("xyz" === propertyName) {
-if (this.currentObject != null && this.vwr.getBoolean(603979845)) {
+if (this.currentObject != null) {
+if (this.vwr.getBoolean(603979845)) {
 this.currentObject.setScalePixelsPerMicron(this.vwr.getScalePixelsPerAngstrom(false) * 10000);
-this.currentObject.setXYZ(value, true);
+}this.currentObject.setXYZ(value, true);
 }}if ("scale" === propertyName) {
 if (this.currentObject != null) {
 (this.currentObject).setScale((value).floatValue());
@@ -2037,7 +2053,7 @@ lst2.addLast(lst);
 return lst2;
 });
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 05:22:14 CST 2024
 Clazz_declarePackage("J.shape");
 Clazz_load(["J.shape.TextShape"], "J.shape.Hover", ["JU.AU", "JM.Text", "JU.C"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -2097,7 +2113,7 @@ return;
 }this.setPropTS(propertyName, value, null);
 }, "~S,~O,JU.BS");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:43:24 CST 2024
 Clazz_declarePackage("J.render");
 Clazz_load(null, "J.render.TextRenderer", ["JM.Text"], function(){
 var c$ = Clazz_declareType(J.render, "TextRenderer", null);
@@ -2206,7 +2222,7 @@ g3d.drawRect(x + 3, y + 3, z - 1, zSlab, boxWidth - 6, boxHeight - 6);
 g3d.drawRect(x + 1, y + 1, z - 1, zSlab, boxWidth - 2, boxHeight - 2);
 }}, "J.api.JmolRendererInterface,~N,~N,~N,~N,~N,~N,~N,~N,~B");
 });
-;//5.0.1-v2 Mon Jan 22 14:59:02 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:43:24 CST 2024
 Clazz_declarePackage("J.render");
 Clazz_load(["J.render.FontLineShapeRenderer", "JU.P3", "$.P3i"], "J.render.LabelsRenderer", ["JM.Text", "J.render.TextRenderer", "JU.Font", "JV.JC"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -2344,7 +2360,7 @@ J.render.TextRenderer.render(null, text, this.g3d, this.scalePixelsPerMicron, th
 return (newText ? text : null);
 }, "JM.Text,~S");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
 Clazz_declarePackage("J.render");
 Clazz_load(["J.render.LabelsRenderer"], "J.render.MeasuresRenderer", ["java.util.Hashtable", "JU.A4", "$.M3", "$.Measure", "$.P3", "J.render.FontLineShapeRenderer", "JU.Point3fi"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -2608,7 +2624,7 @@ if (this.dotsOrDashes && (this.dashDots == null || this.dashDots === J.render.Fo
 return this.drawLine2(this.g3d, x1, y1, z1, x2, y2, z2, diameter);
 }, "~N,~N,~N,~N,~N,~N,~N");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
 Clazz_declarePackage("J.render");
 Clazz_load(["J.render.LabelsRenderer"], "J.render.EchoRenderer", ["J.render.TextRenderer", "JU.C"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -2665,7 +2681,7 @@ var x = Clazz_doubleToInt(Math.floor(5 * this.imageFontScaling));
 this.g3d.drawStringNoSlab(frameTitle, null, x, y, 0, 0);
 }, "~S");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
 Clazz_declarePackage("J.render");
 Clazz_load(["J.render.ShapeRenderer"], "J.render.HoverRenderer", ["JU.P3", "J.render.TextRenderer"], function(){
 var c$ = Clazz_decorateAsClass(function(){
@@ -2704,7 +2720,7 @@ if (label == null || atom == null) return null;
 return (this.ms.isJmolDataFrameForModel(atom.mi) && label.equals("%U") ? "%W" : label);
 }, "JM.Atom,~S");
 });
-;//5.0.1-v2 Fri Jan 26 15:25:03 CST 2024
+;//5.0.1-v2 Mon Feb 26 04:43:24 CST 2024
 })(Clazz
 ,Clazz.getClassName
 ,Clazz.newLongArray
