@@ -16,7 +16,11 @@ Clazz.overrideMethod(c$, "readByteAsInt",
 function(){
 return (this.pos < this.count) ? (this.buf[this.pos++] & 0xff) : -1;
 });
-Clazz.defineMethod(c$, "read", 
+Clazz.overrideMethod(c$, "read", 
+function(b, off, len){
+return this.readBAIS(b, off, len);
+}, "~A,~N,~N");
+Clazz.defineMethod(c$, "readBAIS", 
 function(b, off, len){
 if (b == null) {
 throw  new NullPointerException();
@@ -64,4 +68,4 @@ Clazz.overrideMethod(c$, "close",
 function(){
 });
 });
-;//5.0.1-v2 Mon Jan 22 13:18:57 CST 2024
+;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
