@@ -11,7 +11,7 @@ Clazz.defineMethod(c$, "readByteAsInt",
 function(){
 return this.$in.readByteAsInt();
 });
-Clazz.defineMethod(c$, "read", 
+Clazz.overrideMethod(c$, "read", 
 function(b, off, len){
 return this.$in.read(b, off, len);
 }, "~A,~N,~N");
@@ -40,4 +40,4 @@ function(){
 return this.$in.markSupported();
 });
 });
-;//5.0.1-v2 Mon Jan 22 13:18:57 CST 2024
+;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
