@@ -8,11 +8,15 @@ this.modCount = 0;
 this.$keySet = null;
 this.$entrySet = null;
 this.$values = null;
-this.秘m = null;
-this.秘allowJS = false;
+this.__m = null;
+this.__allowJS = false;
 Clazz.instantialize(this, arguments);}, java.util, "Hashtable", java.util.Dictionary, [java.util.Map, Cloneable]);
 Clazz.makeConstructor(c$, 
 function(){
+this.initHT();
+});
+Clazz.defineMethod(c$, "initHT", 
+function(){
 var map = null;
 var capacity = 11;
 var loadFactor = 0.75;
@@ -22,9 +26,9 @@ loadFactor = arguments[1];
 if (typeof capacity == "object") {
 map = capacity;
 capacity = Math.max(2*t.size(), 11);
-this.秘allowJS = map.秘allowJS;
+this.__allowJS = map.__allowJS;
 } else {
-this.秘allowJS = true;
+this.__allowJS = true;
 }
 capacity = (capacity || 11);
 loadFactor = (loadFactor || 0.75);
@@ -34,14 +38,14 @@ if (capacity == 0) capacity = 1;
 this.loadFactor = loadFactor;
 this.table =  new Array(capacity);
 this.threshold = Clazz.floatToInt(Math.min(capacity * loadFactor, 2147483640));
-this.秘setJS();
+this.__setJS();
 if (map != null) this.putAll(map);
 });
 Clazz.overrideMethod(c$, "size", 
 function(){
 var c = this.count;
 {
-c = this.秘m && this.秘m.size || c;
+c = this.__m && this.__m.size || c;
 }return c;
 });
 Clazz.overrideMethod(c$, "isEmpty", 
@@ -61,8 +65,8 @@ function(value){
 if (value == null) {
 throw  new NullPointerException();
 }if (this.size() == 0) return false;
-if (java.util.Hashtable.秘isSimple(this)) {
-var m = this.秘m;
+if (java.util.Hashtable.__isSimple(this)) {
+var m = this.__m;
 {
 var iter = m.values();
 for (var n = iter.next(); !n.done; n = iter.next()) {
@@ -86,11 +90,11 @@ return this.contains(value);
 }, "~O");
 Clazz.overrideMethod(c$, "containsKey", 
 function(key){
-switch (java.util.Hashtable.秘hasKey(this, key)) {
+switch (java.util.Hashtable.__hasKey(this, key)) {
 case 0:
 break;
 case 1:
-java.util.Hashtable.秘ensureJavaMap(this);
+java.util.Hashtable.__ensureJavaMap(this);
 break;
 case 2:
 return false;
@@ -109,18 +113,18 @@ return false;
 Clazz.overrideMethod(c$, "get", 
 function(key){
 if (key == null) return null;
-switch (java.util.Hashtable.秘hasKey(this, key)) {
+switch (java.util.Hashtable.__hasKey(this, key)) {
 case 0:
 break;
 case 1:
-java.util.Hashtable.秘ensureJavaMap(this);
+java.util.Hashtable.__ensureJavaMap(this);
 break;
 case 2:
 return null;
 case 3:
 var v = null;
 {
-v = this.秘m.get(key);
+v = this.__m.get(key);
 }return v;
 }
 var tab = this.table;
@@ -171,22 +175,22 @@ Clazz.overrideMethod(c$, "put",
 function(key, value){
 if (value == null) {
 throw  new NullPointerException();
-}switch (java.util.Hashtable.秘hasKey(this, key)) {
+}switch (java.util.Hashtable.__hasKey(this, key)) {
 case 0:
 break;
 case 1:
-java.util.Hashtable.秘ensureJavaMap(this);
+java.util.Hashtable.__ensureJavaMap(this);
 break;
 case 2:
 {
-this.秘m.set(key, value);
+this.__m.set(key, value);
 }++this.modCount;
 return null;
 case 3:
 var v0 = null;
 {
-v0 = this.秘m.get(key);
-this.秘m.set(key, value);
+v0 = this.__m.get(key);
+this.__m.set(key, value);
 }++this.modCount;
 return v0;
 }
@@ -206,18 +210,18 @@ return null;
 Clazz.overrideMethod(c$, "remove", 
 function(key){
 if (key == null) throw  new NullPointerException("Hashtable key may not be null");
-switch (java.util.Hashtable.秘hasKey(this, key)) {
+switch (java.util.Hashtable.__hasKey(this, key)) {
 case 0:
 break;
 case 1:
-java.util.Hashtable.秘ensureJavaMap(this);
+java.util.Hashtable.__ensureJavaMap(this);
 break;
 case 2:
 return null;
 case 3:
 var v0 = null;
 {
-v0 = this.秘m.get(key); this.秘m["delete"](key);
+v0 = this.__m.get(key); this.__m["delete"](key);
 }++this.modCount;
 return v0;
 }
@@ -243,10 +247,10 @@ Clazz.overrideMethod(c$, "putAll",
 function(t){
 var key = null;
 var value = null;
-if (java.util.Hashtable.秘isSimple(t)) {
+if (java.util.Hashtable.__isSimple(t)) {
 var me = this;
 {
-t.秘m.forEach(function(value, key) { me.put(key, value); })
+t.__m.forEach(function(value, key) { me.put(key, value); })
 }return;
 }for (var e, $e = t.entrySet().iterator (); $e.hasNext()&& ((e = $e.next ()) || true);) this.put(e.getKey(), e.getValue());
 
@@ -255,10 +259,10 @@ Clazz.overrideMethod(c$, "clear",
 function(){
 var tab = this.table;
 this.modCount++;
-if (java.util.Hashtable.秘isSimple(this)) {
+if (java.util.Hashtable.__isSimple(this)) {
 {
-this.秘m.clear();
-}}this.秘setJS();
+this.__m.clear();
+}}this.__setJS();
 for (var index = tab.length; --index >= 0; ) tab[index] = null;
 
 this.count = 0;
@@ -275,15 +279,15 @@ t.$keySet = null;
 t.$entrySet = null;
 t.$values = null;
 t.modCount = 0;
-if (java.util.Hashtable.秘isSimple(this)) {
-t.秘setJS();
+if (java.util.Hashtable.__isSimple(this)) {
+t.__setJS();
 var me = this;
 {
-me.秘m.forEach(function(value, key) {
-t.秘m.set(key, value); t.modCount++;
+me.__m.forEach(function(value, key) {
+t.__m.set(key, value); t.modCount++;
 });
 }} else {
-t.秘m = null;
+t.__m = null;
 }return t;
 } catch (e) {
 if (Clazz.exceptionOf(e,"CloneNotSupportedException")){
@@ -293,22 +297,21 @@ throw e;
 }
 }
 });
-Clazz.defineMethod(c$, "toString", 
+Clazz.overrideMethod(c$, "toString", 
 function(){
 var max = this.size() - 1;
 if (max == -1) return "{}";
-var sb =  new StringBuilder();
 var it = this.entrySet().iterator();
-sb.append('{');
+var sb = "{";
 for (var i = 0; ; i++) {
 var e = it.next();
 var key = e.getKey();
 var value = e.getValue();
-sb.append(key === this ? "(this Map)" : key.toString());
-sb.append('=');
-sb.append(value === this ? "(this Map)" : value.toString());
-if (i == max) return sb.append('}').toString();
-sb.append(", ");
+sb += (key === this ? "(this Map)" : key.toString());
+sb += "=";
+sb += (value === this ? "(this Map)" : value.toString());
+if (i == max) return sb + '}';
+sb += ", ";
 }
 });
 Clazz.overrideMethod(c$, "equals", 
@@ -389,38 +392,47 @@ function(){
 if (this.$values == null) this.$values =  new java.util.Hashtable.ValueCollection(this);
 return this.$values;
 });
-Clazz.defineMethod(c$, "秘setJS", 
+Clazz.defineMethod(c$, "__setJS", 
 function(){
-if (this.秘allowJS && java.util.Hashtable.USE_SIMPLE) {
+if (this.__allowJS && java.util.Hashtable.USE_SIMPLE) {
 var m = null;
 {
 m = new Map();
-}this.秘m = m;
+}this.__m = m;
 } else {
-this.秘m = null;
+this.__m = null;
 }});
-c$.秘get = Clazz.defineMethod(c$, "秘get", 
+c$.__get = Clazz.defineMethod(c$, "__get", 
 function(map, key){
 {
-return map.秘m.get(key == null ? null : key + "")
+return map.__m.get(key == null ? null : key + "")
 }}, "~O,~O");
-c$.秘set = Clazz.defineMethod(c$, "秘set", 
+c$.__set = Clazz.defineMethod(c$, "__set", 
 function(map, key, value){
-}, "java.util.Map,~O,~O");
-c$.秘hasKey = Clazz.defineMethod(c$, "秘hasKey", 
+{
+map.__m.set(key == null ? null : key + "", value)
+}}, "java.util.Map,~O,~O");
+c$.__hasKey = Clazz.defineMethod(c$, "__hasKey", 
 function(map, key){
 {
-return (!map.秘m ? 0 : key != null && typeof key != "string"
-? 1 : map.秘m.has(key) ? 3 : 2);
+return (!map.__m ? 0 : key != null && typeof key != "string"
+? 1 : map.__m.has(key) ? 3 : 2);
 }}, "java.util.Map,~O");
-c$.秘isSimple = Clazz.defineMethod(c$, "秘isSimple", 
+c$.__isSimple = Clazz.defineMethod(c$, "__isSimple", 
 function(map){
 {
-return !!map.秘m;
+return !!map.__m;
 }}, "java.util.Map");
-c$.秘ensureJavaMap = Clazz.defineMethod(c$, "秘ensureJavaMap", 
+c$.__ensureJavaMap = Clazz.defineMethod(c$, "__ensureJavaMap", 
 function(map){
-}, "java.util.Map");
+{
+if (map.__m) {
+var m = map.__m;
+map.__m = null;
+m.forEach(function(value, key){map.put(key, value);});
+m.clear();
+}
+}}, "java.util.Map");
 /*if3*/;(function(){
 var c$ = Clazz.decorateAsClass(function(){
 this.hash = 0;
@@ -517,11 +529,11 @@ function(o){
 if (!(Clazz.instanceOf(o,"java.util.Map.Entry"))) return false;
 var entry = o;
 var key = entry.getKey();
-switch (java.util.Hashtable.秘hasKey(this.ht, key)) {
+switch (java.util.Hashtable.__hasKey(this.ht, key)) {
 case 0:
 break;
 case 1:
-java.util.Hashtable.秘ensureJavaMap(this.ht);
+java.util.Hashtable.__ensureJavaMap(this.ht);
 break;
 case 3:
 var value = entry.getValue();
@@ -542,11 +554,11 @@ function(o){
 if (!(Clazz.instanceOf(o,"java.util.Map.Entry"))) return false;
 var entry = o;
 var key = entry.getKey();
-switch (java.util.Hashtable.秘hasKey(this.ht, key)) {
+switch (java.util.Hashtable.__hasKey(this.ht, key)) {
 case 0:
 break;
 case 1:
-java.util.Hashtable.秘ensureJavaMap(this.ht);
+java.util.Hashtable.__ensureJavaMap(this.ht);
 break;
 case 3:
 var value = entry.getValue();
@@ -629,15 +641,15 @@ this.index = ht.table.length;
 this.type = type;
 this.isIterator = iterator;
 this.expectedModCount = ht.modCount;
-if (java.util.Hashtable.秘isSimple(ht)) {
-var m = ht.秘m;
+if (java.util.Hashtable.__isSimple(ht)) {
+var m = ht.__m;
 {
 this.jsMapIterator = m.entries();
 this.next_ = this.jsMapIterator.next();
 }}}, "java.util.Hashtable,~N,~B");
 Clazz.overrideMethod(c$, "hasMoreElements", 
 function(){
-if (java.util.Hashtable.秘isSimple(this.ht)) {
+if (java.util.Hashtable.__isSimple(this.ht)) {
 var b = false;
 {
 b = this.next_ && !this.next_.done
@@ -656,7 +668,7 @@ return e != null;
 Clazz.overrideMethod(c$, "nextElement", 
 function(){
 var node = this.next_;
-if (java.util.Hashtable.秘isSimple(this.ht)) {
+if (java.util.Hashtable.__isSimple(this.ht)) {
 var t = this.type;
 this.current = node;
 var n = null;
@@ -705,7 +717,7 @@ if (!this.isIterator) throw  new UnsupportedOperationException();
 var p = this.current;
 if (p == null) throw  new IllegalStateException("Hashtable Enumerator");
 if (this.ht.modCount != this.expectedModCount) throw  new java.util.ConcurrentModificationException();
-if (java.util.Hashtable.秘isSimple(this.ht)) {
+if (java.util.Hashtable.__isSimple(this.ht)) {
 var key = null;
 {
 key = p.value[0];
@@ -743,4 +755,4 @@ return v;
 /*eoif3*/})();
 c$.USE_SIMPLE = true;
 });
-;//5.0.1-v2 Mon Jan 22 13:18:57 CST 2024
+;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
