@@ -165,9 +165,9 @@ map.put(entry.getKey(), entry.getValue());
 }
 return map;
 });
-Clazz.overrideMethod(c$, "秘setJS", 
+Clazz.overrideMethod(c$, "__setJS", 
 function(){
-this.秘m = null;
+this.__m = null;
 });
 c$.$LinkedHashMap$1$=function(){
 /*if5*/;(function(){
@@ -335,4 +335,4 @@ entry.next = lnext.clone();
 });
 /*eoif3*/})();
 });
-;//5.0.1-v2 Mon Jan 22 13:18:57 CST 2024
+;//5.0.1-v2 Thu Feb 08 09:49:36 CST 2024
