@@ -1,3 +1,3 @@
 Clazz.declarePackage("javajs.api");
 Clazz.declareInterface(javajs.api, "GenericBinaryDocumentReader");
-;//5.0.1-v2 Fri Jan 26 13:48:25 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
