@@ -1,3 +1,3 @@
 Clazz.declarePackage("javajs.api.js");
 Clazz.declareInterface(javajs.api.js, "JSAppletObject");
-;//5.0.1-v2 Thu Jan 18 21:03:27 CST 2024
+;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
