@@ -5,6 +5,8 @@
 
 // see JSmolApi.js for public user-interface. All these are private functions
 
+// BH 2024.02.20 fixes dragging should not stop when mouse leaves applet
+// BH 2024.02.07 adding binary types BCIF 
 // BH 2023.01.19 Jmol._allowKeyboardFocus = true; can be set to false if page jumping is a problem.
 // BH 8/25/2022 fixes getFileData response "" from empty file returning "OK" instead of ""
 // BH 8/15/2022 adds .lut for binary
@@ -220,6 +222,7 @@ Jmol = (function(document) {
         ".x3dna.org": null,
         "rruff.geo.arizona.edu": null, 
         ".rcsb.org": null, 
+        		"chemapps.stolaf.edu/jmol/jsmol/": null,
 				"ftp.wwpdb.org": null,
 				"pdbe.org": null, 
 				"materialsproject.org": null, 
@@ -982,7 +985,7 @@ Jmol = (function(document) {
 		return true;  
 	}
 
-	Jmol._binaryTypes = ["mmtf",".gz",".bz2",".jpg",".gif",".png",".zip",".jmol",".bin",".smol",".spartan",".pmb",".mrc",".map",".ccp4",".dn6",".delphi",".omap",".pse",".dcd",".lut",".uk/pdbe/densities/"];
+	Jmol._binaryTypes = ["mmtf",".bcif",".gz",".bz2",".jpg",".gif",".png",".zip",".jmol",".bin",".smol",".spartan",".pmb",".mrc",".map",".ccp4",".dn6",".delphi",".omap",".pse",".dcd",".lut",".uk/pdbe/densities/"];
 
 	Jmol.isBinaryUrl = function(url) {
 		for (var i = Jmol._binaryTypes.length; --i >= 0;)
@@ -1859,7 +1862,7 @@ Jmol = (function(document) {
 		Jmol.$bind(canvas, 'mouseout', function(ev) {
       if (doIgnore(ev))
         return true;
-      if (Jmol._mouseOwner && !Jmol._mouseOwner.mouseMove) 
+      if (Jmol._mouseOwner && !Jmol._mouseOwner.mouseMove && !Jmol._mouseOwner.isDragging) 
         Jmol._setMouseOwner(null);
 			if (canvas.applet._appletPanel)
 				canvas.applet._appletPanel.startHoverWatcher(false);
